@@ -28,6 +28,31 @@
 #ifndef __CODEC_DEF_ENCODE_H__
 #define __CODEC_DEF_ENCODE_H__
 #include "mos_os.h"
+#include "codec_def_common.h"
+
+#define CODECHAL_VDENC_BRC_NUM_OF_PASSES        2
+#define CODECHAL_PAK_OBJ_EACH_CU                66
+#define CODECHAL_LPLA_NUM_OF_PASSES             2
+#define CODECHAL_ENCODE_BRC_KBPS                1000  // 1000bps for disk storage, aligned with industry usage
+
+//!
+//! \struct AtomicScratchBuffer
+//! \brief  The sturct of Atomic Scratch Buffer
+//!
+struct AtomicScratchBuffer
+{
+    MOS_RESOURCE                            resAtomicScratchBuffer;     //!> Handle of eStatus buffer
+    uint32_t                                *pData;                     //!> Pointer of the buffer of actual data
+    uint16_t                                wEncodeUpdateIndex;         //!> used for VDBOX update encode status
+    uint16_t                                wTearDownIndex;             //!> Reserved for future extension
+    uint32_t                                dwZeroValueOffset;          //!> Store the result of the ATOMIC_CMP
+    uint32_t                                dwOperand1Offset;           //!> Operand 1 of the ATOMIC_CMP
+    uint32_t                                dwOperand2Offset;           //!> Operand 2 of the ATOMIC_CMP
+    uint32_t                                dwOperand3Offset;           //!> Copy of the operand 1
+
+    uint32_t                                dwSize;                     //!> Size of the buffer
+    uint32_t                                dwOperandSetSize;           //!> Size of Operand set
+};
 
 //!
 //! \struct CodechalEncodeSeiData
@@ -41,6 +66,19 @@ struct CodechalEncodeSeiData
     uint8_t*   pSEIBuffer;
 };
 
+typedef struct _CODEC_ENCODE_MB_CONTROL
+{
+    union
+    {
+        struct
+        {
+            uint32_t        bForceIntra : 1;
+            uint32_t        Reserved : 31;
+        };
+        uint32_t            value;
+    } MBParams;
+} CODEC_ENCODE_MB_CONTROL, *PCODEC_ENCODE_MB_CONTROL;
+
 struct MetaDataOffset
 {
     uint32_t dwEncodeErrorFlags                         = 0;
@@ -172,6 +210,17 @@ struct EncoderParams
     MetaDataOffset                  metaDataOffset      = {};
     void *                          pSliceHeaderParams  = nullptr;          //!< [HEVC]
 
+    /*! \brief Specifies motion search modes that will be used.
+    *
+    *    SubPelMode is only valid when bEnableSubPelMode is true. Following are valid values of SubPelMode:
+    *    0:Integer mode searching
+    *    1:Half-pel mode searching
+    *    2:Reserved
+    *    3:Quarter-pel mode searching
+    */
+    bool                            bEnableSubPelMode = false;
+    uint8_t                         SubPelMode        = 0;
+
     PMOS_RESOURCE                   m_presPredication           = nullptr;      //! \brief [Predication] Resource for predication
     uint64_t                        m_predicationResOffset      = 0;            //! \brief [Predication] Offset for Predication resource
     bool                            m_predicationNotEqualZero   = false;        //! \brief [Predication] Predication mode
@@ -182,4 +231,132 @@ struct EncoderParams
     PMOS_RESOURCE                   m_presSetMarker             = nullptr;      //! \brief [SetMarker] Resource for SetMarker
 };
 
+//!
+//! \struct PerfTagSetting
+//! \brief  Setting of performance tags
+//!
+struct PerfTagSetting
+{
+    union
+    {
+        struct
+        {
+            uint16_t    PictureCodingType   : 2;
+            uint16_t    CallType            : 6;
+            uint16_t    Mode                : 4;
+            uint16_t                        : 4;
+        };
+        uint16_t        Value;
+    };
+};
+
+//!
+//! \enum   MbBrcSetting
+//! \brief  Indicate the MBBRC settings
+//!
+enum MbBrcSetting
+{
+    mbBrcInternal = 0,
+    mbBrcEnabled  = 1,
+    mbBrcDisabled = 2,
+};
+
+//!
+//! \struct VdencBrcPakMmio
+//! \brief  MMIO of BRC and PAK
+//!
+struct VdencBrcPakMmio
+{
+    uint32_t                dwReEncode[4];
+};
+
+//!
+//! \struct    EncodeStatusReadParams
+//! \brief     Read encode states parameters
+//!
+struct EncodeStatusReadParams
+{
+    bool          vdencBrcEnabled                          = false;
+    bool          waReadVDEncOverflowStatus                = false;
+    uint32_t      mode                                     = 0;
+
+    uint32_t      vdencBrcNumOfSliceOffset                 = 0;
+    PMOS_RESOURCE *resVdencBrcUpdateDmemBufferPtr          = nullptr;
+
+    PMOS_RESOURCE resBitstreamByteCountPerFrame            = nullptr;
+    uint32_t      bitstreamByteCountPerFrameOffset         = 0;
+
+    PMOS_RESOURCE resBitstreamSyntaxElementOnlyBitCount    = nullptr;
+    uint32_t      bitstreamSyntaxElementOnlyBitCountOffset = 0;
+
+    PMOS_RESOURCE resQpStatusCount                         = nullptr;
+    uint32_t      qpStatusCountOffset                      = 0;
+
+    PMOS_RESOURCE resNumSlices                             = nullptr;
+    uint32_t      numSlicesOffset                          = 0;
+
+    PMOS_RESOURCE resImageStatusMask                       = nullptr;
+    uint32_t      imageStatusMaskOffset                    = 0;
+
+    PMOS_RESOURCE resImageStatusCtrl                       = nullptr;
+    uint32_t      imageStatusCtrlOffset                    = 0;
+};
+
+//!
+//! \struct    FeiPreEncParams
+//! \brief     Fei pre-encode parameters
+//!
+struct FeiPreEncParams
+{
+    MOS_RESOURCE                    resMvPredBuffer;
+    MOS_RESOURCE                    resMbQpBuffer;
+    MOS_RESOURCE                    resMvBuffer;
+    MOS_RESOURCE                    resStatsBuffer;
+    MOS_RESOURCE                    resStatsBotFieldBuffer;
+
+    PMOS_SURFACE                    psCurrOriginalSurface;
+
+    bool                            bInterlaced;
+    uint32_t                        dwNumPastReferences;
+    uint32_t                        dwNumFutureReferences;
+
+    bool                            bCurPicUpdated;
+    CODEC_PICTURE                   CurrOriginalPicture;
+
+    CODEC_PICTURE                   PastRefPicture;
+    bool                            bPastRefUpdated;
+    MOS_SURFACE                     sPastRefSurface;
+    bool                            bPastRefStatsNeeded;
+    MOS_RESOURCE                    sPastRefStatsBuffer;
+    MOS_RESOURCE                    sPastRefStatsBotFieldBuffer;
+
+    CODEC_PICTURE                   FutureRefPicture;
+    bool                            bFutureRefUpdated;
+    MOS_SURFACE                     sFutureRefSurface;
+    bool                            bFutureRefStatsNeeded;
+    MOS_RESOURCE                    sFutureRefStatsBuffer;
+    MOS_RESOURCE                    sFutureRefStatsBotFieldBuffer;
+
+    uint32_t                        dwFrameQp;
+    uint32_t                        dwLenSP;
+    uint32_t                        dwSearchPath;
+    uint32_t                        dwSubMBPartMask;
+    uint32_t                        dwIntraPartMask;
+    uint32_t                        dwSubPelMode;
+    uint32_t                        dwInterSAD;
+    uint32_t                        dwIntraSAD;
+    bool                            bAdaptiveSearch;
+
+    uint32_t                        dwMVPredictorCtrl;
+    bool                            bMBQp;
+    bool                            bFTEnable;
+    uint32_t                        dwRefWidth;
+    uint32_t                        dwRefHeight;
+    uint32_t                        dwSearchWindow;
+    bool                            bDisableMVOutput;
+    bool                            bDisableStatisticsOutput;
+    bool                            bEnable8x8Statistics;
+    bool                            bInputUpdated;
+};
+
 #endif // !__CODEC_DEF_ENCODE_H__
