@@ -265,6 +265,11 @@ struct MHW_VDBOX_PIPE_MODE_SELECT_PARAMS
     bool                        bStreamObjectUsed = false;
     // No need to set protection settings
     bool                        disableProtectionSetting = false;
+    bool                        bFrameStatisticsStreamOutEnable = false;
+
+    MHW_VDBOX_HCP_PIPE_WORK_MODE      PipeWorkMode    = MHW_VDBOX_HCP_PIPE_WORK_MODE_LEGACY;
+    MHW_VDBOX_HCP_MULTI_ENGINE_MODE   MultiEngineMode = MHW_VDBOX_HCP_MULTI_ENGINE_MODE_FE_LEGACY;
+
     virtual ~MHW_VDBOX_PIPE_MODE_SELECT_PARAMS() {}
 };
 using PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS = MHW_VDBOX_PIPE_MODE_SELECT_PARAMS * ;
@@ -370,6 +375,7 @@ struct MHW_VDBOX_PIPE_BUF_ADDR_PARAMS
     bool                        isPFrame    = false;                     // Flag to indicate if it is P frame
     bool                        bIBCEnabled = false;
     uint8_t                     IBCRefIdxMask = 0;
+    bool                        bMmcEnabled   = false;
     PMOS_RESOURCE               presVdencCumulativeCuCountStreamoutSurface = nullptr;
     virtual ~MHW_VDBOX_PIPE_BUF_ADDR_PARAMS() {}
 };
@@ -622,4 +628,10 @@ typedef struct _MHW_VDBOX_GPUNODE_LIMIT
     uint32_t dwGpuNodeToUse;
 } MHW_VDBOX_GPUNODE_LIMIT, *PMHW_VDBOX_GPUNODE_LIMIT;
 
+typedef enum _MHW_VDBOX_AVC_DMV_OFFSET
+{
+    MHW_VDBOX_AVC_DMV_DEST_TOP    = 32,
+    MHW_VDBOX_AVC_DMV_DEST_BOTTOM = 33
+} MHW_VDBOX_AVC_DMV_OFFSET;
+
 #endif
