@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2020, Intel Corporation
+* Copyright (c) 2009-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -26,12 +26,11 @@
 
 #ifndef __MOS_OS_SPECIFIC_H__
 #define __MOS_OS_SPECIFIC_H__
-
+#include "mos_defs.h"
 #include "media_skuwa_specific.h"
 #include "GmmLib.h"
 #include "mos_resource_defs.h"
-#include "mos_defs.h"
-#include "mos_os_cp_interface_specific.h"
+#include "mos_os_hw.h"
 #ifdef ANDROID
 #include <utils/Log.h>
 #endif
@@ -157,6 +156,8 @@ typedef struct _MOS_INTERFACE      *PMOS_INTERFACE;
 typedef struct _MOS_COMMAND_BUFFER *PMOS_COMMAND_BUFFER;
 typedef struct _MOS_LOCK_PARAMS    *PMOS_LOCK_PARAMS;
 
+typedef void *MEDIAUMD_RESOURCE;
+
 //!
 //! \brief enum to video device operations 
 //!
@@ -295,6 +296,9 @@ struct _MOS_SPECIFIC_RESOURCE
     MOS_TILE_MODE_GMM   TileModeGMM;
     bool                bGMMTileEnabled;
 
+    // Compression track
+    bool                bUncompressedWriteNeeded; //!< set uncompressed write flag to trace media uncomrpessedwrite request
+
     MEMORY_OBJECT_CONTROL_STATE memObjCtrlState;
     MOS_HW_RESOURCE_DEF         mocsMosResUsageType;
 };
@@ -499,8 +503,8 @@ struct MOS_CONTEXT_OFFSET
 
 // APO related
 #define FUTURE_PLATFORM_MOS_APO   1234
-bool SetupApoMosSwitch(int32_t fd);
-bool SetupApoDdiSwitch(int32_t fd);
+bool SetupApoMosSwitch(int32_t fd, MediaUserSettingSharedPtr userSettingPtr);
+bool SetupApoDdiSwitch(int32_t fd, MediaUserSettingSharedPtr userSettingPtr);
 bool SetupMediaSoloSwitch();
 
 enum OS_SPECIFIC_RESOURCE_TYPE
@@ -522,80 +526,83 @@ typedef struct _MOS_OS_CONTEXT MOS_CONTEXT, *PMOS_CONTEXT, MOS_OS_CONTEXT, *PMOS
 struct _MOS_OS_CONTEXT
 {
     // Context must be freed by os emul layer
-    int32_t             bFreeContext;
+    int32_t             bFreeContext        = 0;
 
-    uint32_t            uIndirectStateSize;
+    uint32_t            uIndirectStateSize  = 0;
 
-    MOS_OS_GPU_CONTEXT  OsGpuContext[MOS_GPU_CONTEXT_MAX];
+    MOS_OS_GPU_CONTEXT OsGpuContext[MOS_GPU_CONTEXT_MAX] = {};
 
     // Buffer rendering
-    LARGE_INTEGER       Frequency;                //!< Frequency
-    LARGE_INTEGER       LastCB;                   //!< End time for last CB
+    LARGE_INTEGER       Frequency   = {};                //!< Frequency
+    LARGE_INTEGER       LastCB      = {};                   //!< End time for last CB
 
-    CMD_BUFFER_BO_POOL  CmdBufferPool;
+    CMD_BUFFER_BO_POOL CmdBufferPool = {};
 
     // Emulated platform, sku, wa tables
-    PLATFORM            platform;
-    MEDIA_FEATURE_TABLE   SkuTable;
-    MEDIA_WA_TABLE            WaTable;
-    MEDIA_SYSTEM_INFO      gtSystemInfo;
+    PLATFORM                  m_platform    = {};
+    MEDIA_FEATURE_TABLE       m_skuTable    = {};
+    MEDIA_WA_TABLE            m_waTable     = {};
+    MEDIA_SYSTEM_INFO         m_gtSystemInfo = {};
 
     // Controlled OS resources (for analysis)
-    MOS_BUFMGR       *bufmgr;
-    MOS_LINUX_CONTEXT   *intel_context;
-    int32_t             submit_fence;
-    uint32_t            uEnablePerfTag;           //!< 0: Do not pass PerfTag to KMD, perf data collection disabled;
-                                                  //!< 1: Pass PerfTag to MVP driver, perf data collection enabled;
-                                                  //!< 2: Pass PerfTag to DAPC driver, perf data collection enabled;
-    int32_t             bDisableKmdWatchdog;      //!< 0: Do not disable kmd watchdog, that is to say, pass I915_EXEC_ENABLE_WATCHDOG flag to KMD;
-                                                  //!< 1: Disable kmd watchdog, that is to say, DO NOT pass I915_EXEC_ENABLE_WATCHDOG flag to KMD;
-    PERF_DATA           *pPerfData;               //!< Add Perf Data for KMD to capture perf tag
+    MOS_BUFMGR          *bufmgr             = nullptr;
+    MOS_LINUX_CONTEXT   *intel_context      = nullptr;
+    int32_t             submit_fence        = 0;
+    uint32_t            uEnablePerfTag      = 0;        //!< 0: Do not pass PerfTag to KMD, perf data collection disabled;
+                                                        //!< 1: Pass PerfTag to MVP driver, perf data collection enabled;
+                                                        //!< 2: Pass PerfTag to DAPC driver, perf data collection enabled;
+    int32_t             bDisableKmdWatchdog = 0;        //!< 0: Do not disable kmd watchdog, that is to say, pass I915_EXEC_ENABLE_WATCHDOG flag to KMD;
+                                                        //!< 1: Disable kmd watchdog, that is to say, DO NOT pass I915_EXEC_ENABLE_WATCHDOG flag to KMD;
+    PERF_DATA           *pPerfData          = nullptr;  //!< Add Perf Data for KMD to capture perf tag
 
-    int32_t             bHybridDecoderRunningFlag;      //!< Flag to indicate if hybrid decoder is running
+    int32_t             bHybridDecoderRunningFlag = 0;  //!< Flag to indicate if hybrid decoder is running
 
-    int                 iDeviceId;
-    int                 wRevision;
-    int32_t             bIsAtomSOC;
-    int                 fd;                     //!< handle for /dev/dri/card0
+    int                 iDeviceId   = 0;
+    int                 wRevision   = 0;
+    int32_t             bIsAtomSOC  = 0;
+    int                 fd          = 0;                //!< handle for /dev/dri/card0
 
-    int32_t             bUse64BitRelocs;
-    bool                bUseSwSwizzling;
-    bool                bTileYFlag;
+    int32_t             bUse64BitRelocs = 0;
+    bool                bUseSwSwizzling = false;
+    bool                bTileYFlag      = false;
 
-    void                **ppMediaMemDecompState; //!<Media memory decompression data structure
-    void                **ppMediaCopyState;      //!<Media memory copy data structure
+    void                **ppMediaMemDecompState = nullptr;      //!<Media memory decompression data structure
+    void                **ppMediaCopyState      = nullptr;      //!<Media memory copy data structure
 
     // For modulized GPU context
-    void*               m_gpuContextMgr;
-    void*               m_cmdBufMgr;
-    MOS_DEVICE_HANDLE   m_osDeviceContext = nullptr;
+    void*               m_gpuContextMgr         = nullptr;
+    void*               m_cmdBufMgr             = nullptr;
+    MOS_DEVICE_HANDLE   m_osDeviceContext       = nullptr;
 
     //For 2VD box
-    int32_t             bKMDHasVCS2;
-    bool                bPerCmdBufferBalancing;
-    int32_t             semid;
-    int32_t             shmid;
-    void                *pShm;
+    int32_t             bKMDHasVCS2             = 0;
+    bool                bPerCmdBufferBalancing  = false;
+    int32_t             semid                   = 0;
+    int32_t             shmid                   = 0;
+    void                *pShm                   = nullptr;
 
-    uint32_t            *pTranscryptedKernels;     //!< The cached version for current set of transcrypted and authenticated kernels
-    uint32_t            uiTranscryptedKernelsSize; //!< Size in bytes of the cached version of transcrypted and authenticated kernels
-    void                *pLibdrmHandle;
+    uint32_t            *pTranscryptedKernels   = nullptr;     //!< The cached version for current set of transcrypted and authenticated kernels
+    uint32_t            uiTranscryptedKernelsSize   = 0;       //!< Size in bytes of the cached version of transcrypted and authenticated kernels
+    void                *pLibdrmHandle          = nullptr;
 
-    GMM_CLIENT_CONTEXT  *pGmmClientContext;   //UMD specific ClientContext object in GMM
-    AuxTableMgr         *m_auxTableMgr;
+    GMM_CLIENT_CONTEXT  *pGmmClientContext      = nullptr;   //UMD specific ClientContext object in GMM
+    AuxTableMgr         *m_auxTableMgr          = nullptr;
    
     // GPU Status Buffer
-    PMOS_RESOURCE   pGPUStatusBuffer;
+    PMOS_RESOURCE       pGPUStatusBuffer        = nullptr;
 
-    std::vector< struct MOS_CONTEXT_OFFSET> contextOffsetList;
+    std::vector<struct MOS_CONTEXT_OFFSET> contextOffsetList = {};
 
-    bool                bSimIsActive;   //!< To indicate if simulation environment
-    bool                m_apoMosEnabled;  //!< apo mos or not
+    bool                bSimIsActive            = false;   //!< To indicate if simulation environment
+    bool                m_apoMosEnabled         = false;   //!< apo mos or not
+    bool                m_protectedGEMContext   = false;   //!< Indicates to create protected GEM content
+
+    MediaUserSettingSharedPtr m_userSettingPtr  = nullptr;  // used to save user setting instance
 
     // Media memory decompression function
     void (* pfnMemoryDecompress)(
         PMOS_CONTEXT                pOsContext,
-        PMOS_RESOURCE               pOsResource);
+        PMOS_RESOURCE               pOsResource) = nullptr;
 
     //!
     //! \brief  the function ptr for surface copy function
@@ -604,7 +611,7 @@ struct _MOS_OS_CONTEXT
         PMOS_CONTEXT       pOsContext,
         PMOS_RESOURCE      pInputResource,
         PMOS_RESOURCE      pOutputResource,
-        bool               bOutputCompressed);
+        bool               bOutputCompressed) = nullptr;
 
     //!
     //! \brief  the function ptr for Media Memory 2D copy function
@@ -618,7 +625,7 @@ struct _MOS_OS_CONTEXT
         uint32_t           copyInputOffset,
         uint32_t           copyOutputOffset,
         uint32_t           bpp,
-        bool               bOutputCompressed);
+        bool               bOutputCompressed) = nullptr;
 
     //!
     //! \brief  the function ptr for Media copy function
@@ -628,60 +635,60 @@ struct _MOS_OS_CONTEXT
     void (* pfnDestroy)(
         struct _MOS_OS_CONTEXT      *pOsContext,
         int32_t                     MODSEnabled,
-        int32_t                     MODSForGpuContext);
+        int32_t                     MODSForGpuContext) = nullptr;
 
     int32_t (* pfnRefresh)(
-        struct _MOS_OS_CONTEXT      *pOsContext);
+        struct _MOS_OS_CONTEXT      *pOsContext) = nullptr;
 
     int32_t (* pfnGetCommandBuffer)(
         struct _MOS_OS_CONTEXT      *pOsContext,
         PMOS_COMMAND_BUFFER         pCmdBuffer,
-        int32_t                     iSize);
+        int32_t                     iSize) = nullptr;
 
     void (* pfnReturnCommandBuffer)(
         struct _MOS_OS_CONTEXT      *pOsContext,
         MOS_GPU_CONTEXT             GpuContext,
-        PMOS_COMMAND_BUFFER         pCmdBuffer);
+        PMOS_COMMAND_BUFFER         pCmdBuffer) = nullptr;
 
     int32_t (* pfnFlushCommandBuffer)(
         struct _MOS_OS_CONTEXT      *pOsContext,
-        MOS_GPU_CONTEXT             GpuContext);
+        MOS_GPU_CONTEXT             GpuContext) = nullptr;
 
     MOS_STATUS (* pfnInsertCmdBufferToPool)(
         struct _MOS_OS_CONTEXT      *pOsContext,
-        PMOS_COMMAND_BUFFER         pCmdBuffer);
+        PMOS_COMMAND_BUFFER         pCmdBuffer) = nullptr;
 
     MOS_STATUS (* pfnWaitAndReleaseCmdBuffer)(
         struct _MOS_OS_CONTEXT      *pOsContext,
-        int32_t                     index);
+        int32_t                     index) = nullptr;
 
     uint32_t (* GetDmaBufID ) (
-        struct _MOS_OS_CONTEXT      *pOsContext);
+        struct _MOS_OS_CONTEXT      *pOsContext) = nullptr;
 
     void (* SetDmaBufID ) (
         struct _MOS_OS_CONTEXT      *pOsContext,
-        uint32_t                    dwDmaBufID);
+        uint32_t                    dwDmaBufID) = nullptr;
 
     void (* SetPerfHybridKernelID ) (
         struct _MOS_OS_CONTEXT      *pOsContext,
-        uint32_t                    KernelID);
+        uint32_t                    KernelID) = nullptr;
 
     uint32_t (* pfnGetGpuCtxBufferTag)(
         PMOS_CONTEXT               pOsContext,
-        MOS_GPU_CONTEXT            GpuContext);
+        MOS_GPU_CONTEXT            GpuContext) = nullptr;
 
     void (* pfnIncGpuCtxBufferTag)(
         PMOS_CONTEXT               pOsContext,
-        MOS_GPU_CONTEXT            GpuContext);
+        MOS_GPU_CONTEXT            GpuContext) = nullptr;
 
     uint32_t (* GetGPUTag)(
         PMOS_INTERFACE             pOsInterface,
-        MOS_GPU_CONTEXT            GpuContext);
+        MOS_GPU_CONTEXT            GpuContext) = nullptr;
 
     GMM_CLIENT_CONTEXT* (* GetGmmClientContext)(
-        PMOS_CONTEXT               pOsContext);
+        PMOS_CONTEXT               pOsContext) = nullptr;
 
-    MosOcaInterface* (*GetOcaInterface)();
+    MosOcaInterface* (*GetOcaInterface)()      = nullptr;
 };
 
 //!
@@ -719,17 +726,6 @@ typedef struct _MOS_SPECIFIC_BUFFER
 extern "C" {
 #endif
 
-//!
-//! \brief    Check if OS resource is nullptr
-//! \details  Check if OS resource is nullptr
-//! \param    PMOS_RESOURCE pOsResource
-//!           [in] Pointer to OS Resource
-//! \return   int32_t
-//!           Return true if nullptr, otherwise false
-//!
-int32_t Mos_ResourceIsNull(
-    PMOS_RESOURCE pOsResource);
-
 //!
 //! \brief    Get Buffer Type
 //! \details  Returns the type of buffer, 1D, 2D or volume
@@ -740,17 +736,6 @@ int32_t Mos_ResourceIsNull(
 MOS_GFXRES_TYPE GetResType(
     PMOS_RESOURCE pOsResource);
 
-//!
-//! \brief    OS reset resource
-//! \details  Resets the OS resource
-//! \param    PMOS_RESOURCE pOsResource
-//!           [in] Pointer to OS Resource
-//! \return   void
-//!           Return NONE
-//!
-void Mos_ResetResource(
-    PMOS_RESOURCE pOsResource);
-
 //!
 //! \brief    Convert to MOS tile type
 //! \details  Convert from Linux to MOS tile type
@@ -932,12 +917,80 @@ MOS_STATUS Mos_Specific_IsResourceReleasable(
     PMOS_INTERFACE         pOsInterface,
     PMOS_RESOURCE          pOsResource);
 
+struct _MOS_SPECIFIC_VE_HINT_PARAMS;
+typedef struct _MOS_SPECIFIC_VE_HINT_PARAMS *PMOS_VIRTUALENGINE_HINT_PARAMS;
+struct _MOS_VIRTUALENGINE_INIT_PARAMS;
+typedef struct _MOS_VIRTUALENGINE_INIT_PARAMS MOS_VIRTUALENGINE_INIT_PARAMS, *PMOS_VIRTUALENGINE_INIT_PARAMS;
+
+//!
+//! \brief    Virtual Engine Init for media Scalability
+//! \details  
+//! \param    PMOS_INTERFACE pOsInterface
+//!           [in] Pointer to OS interface structure
+//! \param    MOS_VE_HANDLE pVeState
+//!           [out] Virtual Engine State
+//! \param    PMOS_VIRTUALENGINE_HINT_PARAMS veHitParams
+//!           [out] Pointer to Virtual Engine hint parameters
+//! \param    PMOS_VIRTUALENGINE_INTERFACE veInterface
+//!           [out] Pointer to Virtual Engine Interface
+//! \return   MOS_STATUS
+//!           MOS_STATUS_SUCCESS if succeeded, otherwise error code
+//!
+MOS_STATUS Mos_Specific_Virtual_Engine_Init(
+    PMOS_INTERFACE                  pOsInterface,
+    PMOS_VIRTUALENGINE_HINT_PARAMS* veHitParams,
+    MOS_VIRTUALENGINE_INIT_PARAMS&  veInParams);
+
+struct _MOS_VIRTUALENGINE_SET_PARAMS;
+typedef struct _MOS_VIRTUALENGINE_SET_PARAMS  MOS_VIRTUALENGINE_SET_PARAMS, *PMOS_VIRTUALENGINE_SET_PARAMS;
+
+//!
+//! \brief    Set hint parameters
+//! \details  
+//! \param    PMOS_INTERFACE pOsInterface
+//!           [in] Pointer to OS interface structure
+//! \param    MOS_VIRTUALENGINE_SET_PARAMS veParams
+//!           [out] VIRTUALENGINE SET PARAMS
+//! \return   MOS_STATUS
+//!           MOS_STATUS_SUCCESS if succeeded, otherwise error code
+//!
+MOS_STATUS Mos_Specific_SetHintParams(
+    PMOS_INTERFACE               pOsInterface,
+    PMOS_VIRTUALENGINE_SET_PARAMS veParams);
+
+typedef struct _MOS_VIRTUALENGINE_INTERFACE *PMOS_VIRTUALENGINE_INTERFACE;
+
+//!
+//! \brief    Destroy veInterface
+//! \details  
+//! \param    PMOS_VIRTUALENGINE_INTERFACE *veInterface
+//!           [in] Pointer to PMOS_VIRTUALENGINE_INTERFACE
+//! \return   MOS_STATUS
+//!           MOS_STATUS_SUCCESS if succeeded, otherwise error code
+//!
+MOS_STATUS Mos_Specific_DestroyVeInterface(
+    PMOS_VIRTUALENGINE_INTERFACE *veInterface);
+
 #if (_DEBUG || _RELEASE_INTERNAL)
 MOS_LINUX_BO * Mos_GetNopCommandBuffer_Linux(
     PMOS_INTERFACE        pOsInterface);
 
 MOS_LINUX_BO * Mos_GetBadCommandBuffer_Linux(
     PMOS_INTERFACE        pOsInterface);
+
+//!
+//! \brief    gpuCtxCreateOption Init for media Scalability
+//! \details  
+//! \param    PMOS_INTERFACE pOsInterface
+//!           [in] Pointer to OS interface structure
+//! \param    uint8_t id
+//!           [out] EngineLogicId
+//! \return   MOS_STATUS
+//!           MOS_STATUS_SUCCESS if succeeded, otherwise error code
+//!
+MOS_STATUS Mos_Specific_GetEngineLogicId(
+    PMOS_INTERFACE                 pOsInterface,
+    uint8_t&                       id);
 #endif
 
 #ifdef __cplusplus
