@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2018, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -388,6 +388,35 @@ MOS_STATUS CodechalDecodeAvc::SetAndAllocateDmvBufferIndex(
     return eStatus;
 }
 
+
+MOS_STATUS CodechalDecodeAvc::SetAndAllocateDmvBufferIndexMismatched(
+    uint8_t             frameIdx,
+    uint32_t            avcDmvBufferSize,
+    uint8_t            *dmvIdx,
+    MOS_RESOURCE       *avcDmvBuffers)
+{
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+    CODECHAL_DECODE_CHK_NULL_RETURN(dmvIdx);
+    CODECHAL_DECODE_CHK_NULL_RETURN(avcDmvBuffers);
+
+    uint8_t index = frameIdx;
+
+    if (Mos_ResourceIsNull(&avcDmvBuffers[index]))
+    {
+        // Allocate DMV buffer if it has not been allocated already.
+        CODECHAL_DECODE_CHK_STATUS_MESSAGE_RETURN(AllocateBuffer(
+                                                      &avcDmvBuffers[index],
+                                                      avcDmvBufferSize,
+                                                      "MvBuffer",
+                                                      true),
+            "Failed to allocate MV Buffer.");
+    }
+
+    *dmvIdx = index;
+    return eStatus;
+}
+
 MOS_STATUS CodechalDecodeAvc::InitMvcDummyDmvBuffer(
     uint32_t                    *mvcWaDummyDmvBuf,
     uint32_t                    size,
@@ -514,9 +543,30 @@ MOS_STATUS CodechalDecodeAvc::SetPictureStructs()
     m_avcRefList[currPic.FrameIdx]->resRefPic = m_destSurface.OsResource;
 
     // Override reference list with ref surface passed from DDI
-    for (i = 0; i < m_refSurfaceNum; i++)
+    uint8_t surfCount = 0;
+    uint8_t surfIndex = 0;
+    if (m_osInterface->pfnIsMismatchOrderProgrammingSupported())
     {
-        m_avcRefList[i]->resRefPic = m_refFrameSurface[i].OsResource;
+        while (surfIndex < CODEC_AVC_NUM_UNCOMPRESSED_SURFACE)
+        {
+            if (!Mos_ResourceIsNull(&m_refFrameSurface[surfIndex].OsResource))
+            {
+                m_avcRefList[surfIndex]->resRefPic = m_refFrameSurface[surfIndex].OsResource;
+            }
+            surfIndex++;
+        }
+    }
+    else
+    {
+        while (surfCount < m_refSurfaceNum && surfIndex < CODEC_AVC_NUM_UNCOMPRESSED_SURFACE)
+        {
+            if (!Mos_ResourceIsNull(&m_refFrameSurface[surfIndex].OsResource))
+            {
+                m_avcRefList[surfIndex]->resRefPic = m_refFrameSurface[surfIndex].OsResource;
+                surfCount++;
+            }
+            surfIndex++;
+        }
     }
 
     uint8_t index, duplicatedIdx;
@@ -593,19 +643,50 @@ MOS_STATUS CodechalDecodeAvc::SetPictureStructs()
 
     if (!m_isSecondField)
     {
-        CODECHAL_DECODE_CHK_STATUS_RETURN(SetAndAllocateDmvBufferIndex(
-            &m_avcDmvList[0],
-            (bool)picParams->pic_fields.reference_pic_flag,
-            currPic.FrameIdx,
-            m_avcDmvBufferSize,
-            &m_avcMvBufferIndex,
-            m_resAvcDmvBuffers));
+        if (m_osInterface->pfnIsMismatchOrderProgrammingSupported())
+        {
+            for (i = 0; i < CODEC_AVC_MAX_NUM_REF_FRAME; i++)
+            {
+                auto frameIdx = picParams->RefFrameList[i].FrameIdx;
+                if (frameIdx != CODECHAL_NUM_UNCOMPRESSED_SURFACE_HEVC)
+                {
+                    CODECHAL_DECODE_CHK_STATUS_RETURN(SetAndAllocateDmvBufferIndexMismatched(
+                        frameIdx,
+                        m_avcDmvBufferSize,
+                        &m_avcMvBufferIndex,
+                        m_resAvcDmvBuffers));
+                    dmvidx = m_avcMvBufferIndex;
+                    m_avcRefList[frameIdx]->ucDMVIdx[0] = dmvidx;
+                    m_avcRefList[frameIdx]->ucDMVIdx[1] = dmvidx;
+                }
+            }
+            CODECHAL_DECODE_CHK_STATUS_RETURN(SetAndAllocateDmvBufferIndexMismatched(
+                currPic.FrameIdx,
+                m_avcDmvBufferSize,
+                &m_avcMvBufferIndex,
+                m_resAvcDmvBuffers));
+            dmvidx = m_avcMvBufferIndex;
 
-        dmvidx = m_avcMvBufferIndex;
+            //first and second field will use the same DMV buffer in field mode
+            m_avcRefList[currPic.FrameIdx]->ucDMVIdx[0] = dmvidx;
+            m_avcRefList[currPic.FrameIdx]->ucDMVIdx[1] = dmvidx;
+        }
+        else
+        {
+            CODECHAL_DECODE_CHK_STATUS_RETURN(SetAndAllocateDmvBufferIndex(
+                &m_avcDmvList[0],
+                (bool)picParams->pic_fields.reference_pic_flag,
+                currPic.FrameIdx,
+                m_avcDmvBufferSize,
+                &m_avcMvBufferIndex,
+                m_resAvcDmvBuffers));
 
-        //first and second field will use the same DMV buffer in field mode
-        m_avcRefList[currPic.FrameIdx]->ucDMVIdx[0] = dmvidx;
-        m_avcRefList[currPic.FrameIdx]->ucDMVIdx[1] = dmvidx;
+            dmvidx = m_avcMvBufferIndex;
+
+            //first and second field will use the same DMV buffer in field mode
+            m_avcRefList[currPic.FrameIdx]->ucDMVIdx[0] = dmvidx;
+            m_avcRefList[currPic.FrameIdx]->ucDMVIdx[1] = dmvidx;
+        }
     }
     else
     {
@@ -678,7 +759,7 @@ MOS_STATUS CodechalDecodeAvc::SetPictureStructs()
             picIdx[i].bValid = true;
             picIdx[i].ucPicIdx = index;
 
-            if (!CodecHal_PictureIsInvalid(prevPic))
+            if (!CodecHal_PictureIsInvalid(prevPic) && !m_osInterface->pfnIsMismatchOrderProgrammingSupported())
             {
                 for (ii = 0; ii < m_avcRefList[prevPic.FrameIdx]->ucNumRef; ii++)
                 {
@@ -728,6 +809,14 @@ MOS_STATUS CodechalDecodeAvc::SetPictureStructs()
     m_avcRefList[currPic.FrameIdx]->usNonExistingFrameFlags = nonExistingFrameFlags;
     m_avcRefList[currPic.FrameIdx]->uiUsedForReferenceFlags = usedForReferenceFlags;
 
+    if (m_osInterface->pfnIsMismatchOrderProgrammingSupported())
+    {
+        for (uint32_t ii = 0; ii < CODEC_AVC_NUM_UNCOMPRESSED_SURFACE; ii++)
+        {
+            m_avcRefList[ii]->ucFrameId = 0x7f;
+        }
+    }
+
     SetFrameStoreIds(currPic.FrameIdx);
 
     // Store CurrFieldOrderCnt
@@ -917,7 +1006,10 @@ MOS_STATUS CodechalDecodeAvc::AllocateResourcesVariableSizes()
         (picHeightInMB > m_picHeightInMbLastMaxAlloced) ||
         (m_avcDmvBufferSize == 0))
     {
-        for (ctr = 0; ctr < CODEC_AVC_NUM_DMV_BUFFERS; ctr++)
+        uint32_t maxMvBuf = m_osInterface->pfnIsMismatchOrderProgrammingSupported() ?
+            CODEC_AVC_NUM_UNCOMPRESSED_SURFACE :
+            CODEC_AVC_NUM_DMV_BUFFERS;
+        for (ctr = 0; ctr < maxMvBuf; ctr++)
         {
             if (!Mos_ResourceIsNull(&m_resAvcDmvBuffers[ctr]))
             {
@@ -1033,7 +1125,8 @@ MOS_STATUS CodechalDecodeAvc::AllocateStandard(
         MOS_UserFeature_ReadValue_ID(
             nullptr,
             __MEDIA_USER_FEATURE_VALUE_DECODE_ENABLE_COMPUTE_CONTEXT_ID,
-            &userFeatureData);
+            &userFeatureData,
+            m_osInterface->pOsContext);
         isComputeContextEnabled = (userFeatureData.u32Data) ? true : false;
 #endif
 
@@ -1136,7 +1229,10 @@ CodechalDecodeAvc::~CodechalDecodeAvc()
             &m_resMonoPictureChromaBuffer);
     }
 
-    for (uint32_t ctr = 0; ctr < CODEC_AVC_NUM_DMV_BUFFERS; ctr++)
+    uint32_t maxMvBuf = m_osInterface->pfnIsMismatchOrderProgrammingSupported() ?
+        CODEC_AVC_NUM_UNCOMPRESSED_SURFACE :
+        CODEC_AVC_NUM_DMV_BUFFERS;
+    for (uint32_t ctr = 0; ctr < maxMvBuf; ctr++)
     {
         m_osInterface->pfnFreeResource(
             m_osInterface,
@@ -1240,10 +1336,10 @@ MOS_STATUS CodechalDecodeAvc::SetFrameStates()
         m_perfType = MIXED_TYPE;
     }
 #ifdef _DECODE_PROCESSING_SUPPORTED
-    auto decProcessingParams = (CODECHAL_DECODE_PROCESSING_PARAMS *)m_decodeParams.m_procParams;
+    auto decProcessingParams = (DecodeProcessingParams *)m_decodeParams.m_procParams;
     if (decProcessingParams != nullptr)
     {
-        if (!decProcessingParams->bIsReferenceOnlyPattern && m_downsamplingHinted)
+        if (!decProcessingParams->m_isReferenceOnlyPattern && m_downsamplingHinted)
         {
             CODECHAL_DECODE_CHK_NULL_RETURN(m_fieldScalingInterface);
         }
@@ -1259,7 +1355,7 @@ MOS_STATUS CodechalDecodeAvc::SetFrameStates()
              m_avcPicParams->seq_fields.mb_adaptive_frame_field_flag) &&
              (m_downsamplingHinted && m_fieldScalingInterface->IsFieldScalingSupported(decProcessingParams))) &&
              m_sfcState->m_sfcPipeOut == false &&
-            !decProcessingParams->bIsReferenceOnlyPattern)
+            !decProcessingParams->m_isReferenceOnlyPattern)
         {
             m_vdSfcSupported = false;
         }
@@ -1270,8 +1366,42 @@ MOS_STATUS CodechalDecodeAvc::SetFrameStates()
     }
 #endif
     m_crrPic = m_avcPicParams->CurrPic;
-    m_secondField =
-        CodecHal_PictureIsBottomField(m_avcPicParams->CurrPic);
+
+    if(m_fullFieldsFrame == (PICTURE_BOTTOM_FIELD | PICTURE_TOP_FIELD))
+    {
+        m_fullFieldsFrame = 0;
+    }
+
+    m_secondField = false;
+
+    if(CodecHal_PictureIsField(m_avcPicParams->CurrPic))
+    {
+       if(CodecHal_PictureIsTopField(m_avcPicParams->CurrPic))
+       {
+           m_fullFieldsFrame |= PICTURE_TOP_FIELD;
+       }
+       if (CodecHal_PictureIsBottomField(m_avcPicParams->CurrPic))
+       {
+           m_fullFieldsFrame |= PICTURE_BOTTOM_FIELD;
+       }
+    }
+    else
+    {
+        m_fullFieldsFrame = 0;
+    }
+
+    if(m_fullFieldsFrame == (PICTURE_BOTTOM_FIELD | PICTURE_TOP_FIELD))
+    {
+        m_secondField = true;
+    }
+
+    if (m_pCodechalOcaDumper)
+    {
+        m_pCodechalOcaDumper->SetAvcDecodeParam(
+            m_avcPicParams,
+            m_avcSliceParams,
+            m_numSlices);
+    }
 
     CODECHAL_DEBUG_TOOL(
         m_debugInterface->m_currPic     = m_crrPic;
@@ -1835,7 +1965,7 @@ MOS_STATUS CodechalDecodeAvc::DecodePrimitiveLevel()
                 }
             }
 
-            decodeStatusReport.m_secondField = CodecHal_PictureIsBottomField(m_avcPicParams->CurrPic);
+            decodeStatusReport.m_secondField = m_secondField;
             decodeStatusReport.m_frameType   = m_perfType;)
 
         CODECHAL_DECODE_CHK_STATUS_RETURN(EndStatusReport(decodeStatusReport, &cmdBuffer));
@@ -1871,7 +2001,9 @@ MOS_STATUS CodechalDecodeAvc::DecodePrimitiveLevel()
     //    m_debugInterface,
     //    &cmdBuffer));
     )
-    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+
+    HalOcaInterface::DumpCodechalParam(cmdBuffer, (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext, m_pCodechalOcaDumper, CODECHAL_AVC);
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_videoContextUsesNullHw));
 
@@ -1879,7 +2011,7 @@ MOS_STATUS CodechalDecodeAvc::DecodePrimitiveLevel()
         m_mmc->UpdateUserFeatureKey(&m_destSurface);)
 
 #ifdef _DECODE_PROCESSING_SUPPORTED
-    auto decProcessingParams = (CODECHAL_DECODE_PROCESSING_PARAMS *)m_decodeParams.m_procParams;
+    auto decProcessingParams = (DecodeProcessingParams *)m_decodeParams.m_procParams;
     if (decProcessingParams != nullptr && !m_sfcState->m_sfcPipeOut && (m_isSecondField || m_avcPicParams->seq_fields.mb_adaptive_frame_field_flag))
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_fieldScalingInterface->DoFieldScaling(
@@ -1914,7 +2046,7 @@ MOS_STATUS CodechalDecodeAvc::DecodePrimitiveLevel()
         {
             syncParams = g_cInitSyncParams;
             syncParams.GpuContext = m_renderContext;
-            syncParams.presSyncResource = &decProcessingParams->pOutputSurface->OsResource;
+            syncParams.presSyncResource = &decProcessingParams->m_outputSurface->OsResource;
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnResourceSignal(m_osInterface, &syncParams));
         }
@@ -1923,12 +2055,12 @@ MOS_STATUS CodechalDecodeAvc::DecodePrimitiveLevel()
 #ifdef _DECODE_PROCESSING_SUPPORTED
     CODECHAL_DEBUG_TOOL(
         // Dump out downsampling result
-        if (decProcessingParams && decProcessingParams->pOutputSurface)
+        if (decProcessingParams && decProcessingParams->m_outputSurface)
         {
             MOS_SURFACE dstSurface;
             MOS_ZeroMemory(&dstSurface, sizeof(dstSurface));
             dstSurface.Format = Format_NV12;
-            dstSurface.OsResource = decProcessingParams->pOutputSurface->OsResource;
+            dstSurface.OsResource = decProcessingParams->m_outputSurface->OsResource;
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalGetResourceInfo(
                 m_osInterface,
@@ -1980,7 +2112,7 @@ CodechalDecodeAvc::CodechalDecodeAvc(
     CodechalDecode(hwInterface, debugInterface, standardInfo)
 {
     m_mmc = nullptr;
-
+    m_hwInterface = hwInterface;
     // Parameters passed by application
     m_picWidthInMb                = 0;
     m_picHeightInMb               = 0;
@@ -2005,7 +2137,7 @@ CodechalDecodeAvc::CodechalDecodeAvc(
     MOS_ZeroMemory(&m_resMfdDeblockingFilterRowStoreScratchBuffer, sizeof(MOS_RESOURCE));
     MOS_ZeroMemory(&m_resBsdMpcRowStoreScratchBuffer, sizeof(MOS_RESOURCE));
     MOS_ZeroMemory(&m_resMprRowStoreScratchBuffer, sizeof(MOS_RESOURCE));
-    MOS_ZeroMemory(&m_resAvcDmvBuffers, (sizeof(MOS_RESOURCE) * CODEC_AVC_NUM_DMV_BUFFERS));
+    MOS_ZeroMemory(&m_resAvcDmvBuffers, (sizeof(MOS_RESOURCE) * CODEC_AVC_NUM_UNCOMPRESSED_SURFACE));
     MOS_ZeroMemory(&m_resInvalidRefBuffer, sizeof(MOS_RESOURCE));
     MOS_ZeroMemory(&m_resMvcDummyDmvBuffer, (sizeof(MOS_RESOURCE) * 2));
     MOS_ZeroMemory(&m_destSurface, sizeof(MOS_SURFACE));
