@@ -28,6 +28,7 @@
 #include "codechal_decode_jpeg.h"
 #include "codechal_mmc_decode_jpeg.h"
 #include "hal_oca_interface.h"
+#include "mos_interface.h"
 #if USE_CODECHAL_DEBUG_TOOL
 #include <sstream>
 #include "codechal_debug.h"
@@ -85,6 +86,10 @@ CodechalDecodeJpeg::CodechalDecodeJpeg(
     MOS_ZeroMemory(&m_resDataBuffer, sizeof(m_resDataBuffer));
     MOS_ZeroMemory(&m_resSyncObjectWaContextInUse, sizeof(m_resSyncObjectWaContextInUse));
     MOS_ZeroMemory(&m_resSyncObjectVideoContextInUse, sizeof(m_resSyncObjectVideoContextInUse));
+#if (_DEBUG || _RELEASE_INTERNAL)
+    m_reportFrameCrc = true;
+#endif
+    m_hwInterface = hwInterface;
 }
 
 MOS_STATUS CodechalDecodeJpeg::InitializeBeginFrame()
@@ -376,7 +381,7 @@ MOS_STATUS CodechalDecodeJpeg::CheckSupportedFormat(
     // real output format (ARGB8888) should also be from JPEG PPS; MSDK would handle the details of treating AYUV as ARGB.
     if (*format == Format_420O || *format == Format_AYUV)
     {
-        *format = m_osInterface->pfnFmt_OsToMos((MOS_OS_FORMAT)m_jpegPicParams->m_renderTargetFormat);
+        *format = MosInterface::OsFmtToMosFmt(m_jpegPicParams->m_renderTargetFormat);
     }
 
     //No support for RGBP/BGRP channel swap or YUV/RGB conversion!
@@ -546,7 +551,7 @@ MOS_STATUS CodechalDecodeJpeg::SetFrameStates()
                 &m_resDataBuffer,
                 CodechalDbgAttr::attrBitstream,
                 "_DEC",
-                m_dataSize,
+                (m_copiedDataBufferInUse ? m_nextCopiedDataOffset : m_dataSize),
                 0,
                 CODECHAL_NUM_MEDIA_STATES));
         })
