@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2012-2017, Intel Corporation
+* Copyright (c) 2012-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -186,15 +186,6 @@ public:
     //!
     virtual MOS_STATUS DetermineDecodePhase();
 
-    //!
-    //! \brief  Sets cenc decoder batch buffer
-    //! \param    [in] cmdBuffer
-    //!           Pointer of command buffer.
-    //! \return   MOS_STATUS
-    //!           MOS_STATUS_SUCCESS if success, else fail reason
-    //!
-    virtual MOS_STATUS SetCencBatchBuffer( PMOS_COMMAND_BUFFER cmdBuffer) override;
-
     // Parameters passed by application
     uint16_t                  m_usFrameWidthAlignedMinBlk;   //!< Picture Width aligned to minBlock
     uint16_t                  m_usFrameHeightAlignedMinBlk;  //!< Picture Height aligned to minBlock
