@@ -29,6 +29,7 @@
 #define _MHW_VDBOX_HCP_GENERIC_H_
 
 #include "mhw_vdbox_hcp_interface.h"
+#include "mhw_cp_interface.h"
 
 //!  MHW Vdbox Hcp generic interface
 /*!
@@ -69,6 +70,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(params);
         MHW_ASSERT(params->Mode != CODECHAL_UNSUPPORTED_MODE);
 
@@ -92,7 +94,7 @@ protected:
         cmd.DW2.YOffsetForUCbInPixel =
             MOS_ALIGN_CEIL(params->psSurface->UPlaneOffset.iYOffset, uvPlaneAlignment);
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return eStatus;
     }
@@ -105,6 +107,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(params);
         MHW_ASSERT(params->Mode != CODECHAL_UNSUPPORTED_MODE);
 
@@ -126,7 +129,7 @@ protected:
 
         cmd.DW2.YOffsetForUCbInPixel = params->psSurface->UPlaneOffset.iYOffset;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return eStatus;
     }
@@ -139,6 +142,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(params);
 
         MHW_RESOURCE_PARAMS resourceParams;
@@ -172,7 +176,7 @@ protected:
                 &resourceParams));
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return eStatus;
     }
@@ -185,6 +189,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -265,7 +270,7 @@ protected:
                             }
                         }
 
-                        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+                        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
                     }
                 }
             }
@@ -286,6 +291,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->pHevcPicParams);
 
@@ -339,7 +345,7 @@ protected:
         cmd.DW5.PcmSampleBitDepthChromaMinus1 = hevcPicParams->pcm_sample_bit_depth_chroma_minus1;
         cmd.DW5.PcmSampleBitDepthLumaMinus1   = hevcPicParams->pcm_sample_bit_depth_luma_minus1;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return eStatus;
     }
@@ -352,27 +358,13 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         typename THcpCmds::HCP_BSD_OBJECT_CMD   cmd;
 
         cmd.DW1.IndirectBsdDataLength = params->dwBsdDataLength;
         cmd.DW2.IndirectDataStartAddress = params->dwBsdDataStartOffset;
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-        if (MOS_GetTraceEventKeyword() & EVENT_DECODE_BUFFER_KEYWORD)
-        {
-            struct
-            {
-                uint32_t DW0_Value;
-                uint32_t DW1_Value;
-                uint32_t DW2_Value;
-                uint32_t DW1_IndirectBsdDataLength;
-                uint32_t DW2_IndirectDataStartAddress;
-            } eventData = {cmd.DW0.Value, cmd.DW1.Value, cmd.DW2.Value, cmd.DW1.IndirectBsdDataLength, cmd.DW2.IndirectDataStartAddress};
-            MOS_TraceEvent(EVENT_DECODE_CMD_HCP_BSDOBJECT, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-        }
-#endif
-
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return eStatus;
     }
@@ -387,6 +379,7 @@ protected:
 
         typename THcpCmds::HCP_TILE_STATE_CMD cmd;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->pTileColWidth);
         MHW_MI_CHK_NULL(params->pTileRowHeight);
@@ -477,7 +470,7 @@ protected:
             cmd.CtbRowPositionOfTileRow[5].DW0.Ctbpos1I = rowCumulativeValue;
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return eStatus;
     }
@@ -541,7 +534,7 @@ protected:
             return MOS_STATUS_INVALID_PARAMETER;
         }
 
-        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
 
         return eStatus;
     }
@@ -586,7 +579,7 @@ protected:
             return MOS_STATUS_INVALID_PARAMETER;
         }
 
-        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
 
         return eStatus;
     }
@@ -599,6 +592,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(hevcSliceState);
 
         typename THcpCmds::HCP_SLICE_STATE_CMD cmd;
@@ -755,7 +749,7 @@ protected:
 
         cmd.DW5.Sliceheaderlength = hevcSliceParams->ByteOffsetToSliceData;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return eStatus;
     }
@@ -768,6 +762,7 @@ protected:
 
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(m_osInterface);
         MHW_MI_CHK_NULL(hevcSliceState);
 
         typename THcpCmds::HCP_SLICE_STATE_CMD      cmd;
@@ -940,7 +935,7 @@ protected:
 
         cmd.DW5.Sliceheaderlength = hevcSliceParams->ByteOffsetToSliceData;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
         return eStatus;
     }
