@@ -45,10 +45,11 @@ RenderState::RenderState(
     PVPHAL_RNDR_PERF_DATA       pPerfData,
     MOS_STATUS                  *peStatus) :
     m_pOsInterface(pOsInterface),
-    m_pRenderHal(pRenderHal),
+    m_pRenderHal((PRENDERHAL_INTERFACE_LEGACY)pRenderHal),
     m_pSkuTable(nullptr),
     m_pWaTable(nullptr),
     m_bDisableRender(false),
+    m_bSingleSlice(false),
     m_pPerfData(pPerfData),
     m_reporting(nullptr)
 {
@@ -56,6 +57,11 @@ RenderState::RenderState(
 
     VPHAL_RENDER_CHK_NULL(pRenderHal);
 
+    if (m_pOsInterface)
+    {
+        m_userSettingPtr = pOsInterface->pfnGetUserSettingInstance(m_pOsInterface);
+    }
+
     // Connect renderer to other VPHAL components (HW/OS interfaces)
     m_pWaTable  = pRenderHal->pWaTable;
     m_pSkuTable = pRenderHal->pSkuTable;
@@ -85,6 +91,6 @@ void RenderState::SetStatusReportParams(
     bool bSurfIsRenderTarget = (pRenderParams->pTarget[0]->SurfType == SURF_OUT_RENDERTARGET);
     m_StatusTableUpdateParams.bReportStatus       = (pRenderParams->bReportStatus);
     m_StatusTableUpdateParams.bSurfIsRenderTarget = bSurfIsRenderTarget;
-    m_StatusTableUpdateParams.pStatusTable        = &pRenderer->StatusTable;
+    m_StatusTableUpdateParams.pStatusTable        = pRenderer->m_statusTable;
     m_StatusTableUpdateParams.StatusFeedBackID    = pRenderParams->StatusFeedBackID;
 }
