@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2020, Intel Corporation
+* Copyright (c) 2019-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -25,7 +25,9 @@
 //! \details
 //!
 #include "vphal_render_vebox_memdecomp.h"
+#include "mos_os_cp_interface_specific.h"
 #include "vphal_debug.h"
+#include "vp_utils.h"
 
 MediaVeboxDecompState::MediaVeboxDecompState():
     MediaMemDecompBaseState(),
@@ -200,7 +202,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
     targetSurface.Format     = Format_Invalid;
     targetSurface.OsResource = *outputResource;
 
-#if !defined(LINUX) && !defined(ANDROID) && !EMUL
+#if !defined(LINUX) && !defined(ANDROID) && !EMUL && !_VULKAN
     // for Double Buffer copy, clear the allocationInfo temply
     MOS_ZeroMemory(&targetSurface.OsResource.AllocationInfo, sizeof(SResidencyInfo));
 #endif
@@ -213,16 +215,11 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
 #if (_DEBUG || _RELEASE_INTERNAL)
     {
         // Read user feature key to force outputCompressed
-        MOS_USER_FEATURE_VALUE_DATA userFeatureData;
-        MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-        MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
-            nullptr,
-            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED_ID,
-            &userFeatureData,
-            m_osInterface ? m_osInterface->pOsContext : nullptr));
-
-        outputCompressed = userFeatureData.bData ? true : false;
-
+        ReadUserSettingForDebug(
+            m_userSettingPtr,
+            outputCompressed,
+            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED,
+            MediaUserSetting::Group::Sequence);
     }
 #endif
 
@@ -355,7 +352,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy2D(
     targetSurface.Format = Format_Invalid;
     targetSurface.OsResource = *outputResource;
 
-#if !defined(LINUX) && !defined(ANDROID) && !EMUL
+#if !defined(LINUX) && !defined(ANDROID) && !EMUL && !_VULKAN
     // for Double Buffer copy, clear the allocationInfo temply
     MOS_ZeroMemory(&targetSurface.OsResource.AllocationInfo, sizeof(SResidencyInfo));
 #endif
@@ -368,15 +365,11 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy2D(
 #if (_DEBUG || _RELEASE_INTERNAL)
     {
         // Read user feature key to Force outputCompressed
-        MOS_USER_FEATURE_VALUE_DATA userFeatureData;
-        MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-        MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
-            nullptr,
-            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED_ID,
-            &userFeatureData,
-            m_osInterface ? m_osInterface->pOsContext : nullptr));
-
-        outputCompressed = userFeatureData.bData ? true : false;
+        ReadUserSettingForDebug(
+            m_userSettingPtr,
+            outputCompressed,
+            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED,
+            MediaUserSetting::Group::Sequence);
     }
 #endif
 
@@ -470,7 +463,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryTileConvert(
     targetSurface.Format = Format_Invalid;
     targetSurface.OsResource = *outputResource;
 
-#if !defined(LINUX) && !defined(ANDROID) && !EMUL
+#if !defined(LINUX) && !defined(ANDROID) && !EMUL && !_VULKAN
     // for Double Buffer copy, clear the allocationInfo temply
     MOS_ZeroMemory(&targetSurface.OsResource.AllocationInfo, sizeof(SResidencyInfo));
 #endif
@@ -559,7 +552,7 @@ MOS_STATUS MediaVeboxDecompState::Initialize(
     MHW_VEBOX_GPUNODE_LIMIT     GpuNodeLimit;
     MOS_GPU_NODE                VeboxGpuNode;
     MOS_GPU_CONTEXT             VeboxGpuContext;
-    RENDERHAL_SETTINGS          RenderHalSettings;
+    RENDERHAL_SETTINGS_LEGACY   RenderHalSettings;
 
     eStatus = MOS_STATUS_SUCCESS;
 
@@ -573,6 +566,8 @@ MOS_STATUS MediaVeboxDecompState::Initialize(
     m_mhwMiInterface  = mhwMiInterface;
     m_veboxInterface  = veboxInterface;
 
+    m_userSettingPtr  = m_osInterface->pfnGetUserSettingInstance(m_osInterface);
+
     // Set-Up Vebox decompression enable or not
     IsVeboxDecompressionEnabled();
 
@@ -934,7 +929,9 @@ bool MediaVeboxDecompState::IsFormatSupported(PMOS_SURFACE surface)
         surface->dwHeight = surface->dwSize / surface->dwPitch;
     }
 
-    if (IS_RGB64_FLOAT_FORMAT(surface->Format) || IS_RGB64_FORMAT(surface->Format))
+    if (IS_RGB64_FLOAT_FORMAT(surface->Format) ||
+        IS_RGB64_FORMAT(surface->Format)       ||
+        surface->Format == Format_G32R32F)
     {
         surface->Format = Format_Y416;
     }
