@@ -63,7 +63,7 @@ CodechalDecodeVp9G11::CodechalDecodeVp9G11(
 
     CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(m_osInterface);
 
-    Mos_CheckVirtualEngineSupported(m_osInterface, true, true);
+    m_osInterface->pfnVirtualEngineSupported(m_osInterface, true, true);
 }
 
 MOS_STATUS CodechalDecodeVp9G11::SetGpuCtxCreatOption(
@@ -648,6 +648,7 @@ MOS_STATUS CodechalDecodeVp9G11 :: DecodePrimitiveLevel()
             m_scalabilityState,
             &scdryCmdBuffer,
             &cmdBufferInUse));
+        CodecHalDecodeScalability_DecPhaseToSubmissionType(m_scalabilityState,cmdBufferInUse);
     }
 
     // store CS ENGINE ID register
@@ -862,7 +863,7 @@ MOS_STATUS CodechalDecodeVp9G11 :: DecodePrimitiveLevel()
         HalOcaInterface::On1stLevelBBEnd(primCmdBuffer, *m_osInterface);
     }
 
-    if (submitCommand || m_osInterface->phasedSubmission)
+    if (submitCommand)
     {
         uint32_t renderingFlags = m_videoContextUsesNullHw;
 
@@ -876,7 +877,6 @@ MOS_STATUS CodechalDecodeVp9G11 :: DecodePrimitiveLevel()
             && MOS_VE_SUPPORTED(m_osInterface)
             && CodecHalDecodeScalabilityIsScalableMode(m_scalabilityState))
         {
-            CodecHalDecodeScalability_DecPhaseToSubmissionType(m_scalabilityState,cmdBufferInUse);
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
                 m_osInterface,
                 cmdBufferInUse,
