@@ -25,8 +25,8 @@
 //!
 #include "codechal_decoder.h"
 #include "codechal_decode_scalability_g12.h"
-#include "media_user_settings_mgr_g12.h"
 #include "mos_os_virtualengine_next.h"
+#include "mos_os_cp_interface_specific.h"
 
 //==<Functions>=======================================================
 //!
@@ -58,7 +58,8 @@ static MOS_STATUS CodecHalDecodeScalability_CalculateScdryCmdBufIndex_G12(
     if (pScalabilityState->HcpDecPhase == CODECHAL_HCP_DECODE_PHASE_REAL_TILE)
     {
         *pdwBufIdxPlus1 = pScalabilityState->u8RtCurPipe + 1;
-        if(pScalabilityStateBase->pHwInterface->GetOsInterface()->phasedSubmission)
+        if(pScalabilityStateBase->pHwInterface->GetOsInterface()->phasedSubmission
+        && !pScalabilityStateBase->pHwInterface->GetOsInterface()->bGucSubmission)
         {
             /*  3 tiles 2 pipe for example:
                 cur phase               cur pip
@@ -247,9 +248,12 @@ MOS_STATUS CodecHalDecodeScalability_GetCmdBufferToUse_G12(
 
     CODECHAL_DECODE_CHK_NULL(pScalabilityStateBase);
     CODECHAL_DECODE_CHK_NULL(ppCmdBufToUse);
+    CODECHAL_DECODE_CHK_NULL(pScalabilityStateBase->pHwInterface);
+    CODECHAL_DECODE_CHK_NULL(pScalabilityStateBase->pHwInterface->GetOsInterface());
 
     if (!CodecHalDecodeScalabilityIsFESeparateSubmission(pScalabilityState) ||
-        CodecHalDecodeScalabilityIsBEPhaseG12(pScalabilityState))
+        CodecHalDecodeScalabilityIsBEPhaseG12(pScalabilityState) ||
+        pScalabilityStateBase->pHwInterface->GetOsInterface()->bGucSubmission)
     {
         pScalabilityState->bUseSecdryCmdBuffer = true;
         CODECHAL_DECODE_CHK_STATUS(CodecHalDecodeScalability_GetVESecondaryCmdBuffer_G12(pScalabilityState, pScdryCmdBuf));
@@ -693,7 +697,9 @@ MOS_STATUS CodecHalDecodeScalability_FEBESync_G12(
     HcpDecPhase = pScalabilityStateBase->HcpDecPhase;
 
     //FE& BE0 Sync. to refine (ucNumVdbox > )for GT3
-    if (HcpDecPhase == CODECHAL_HCP_DECODE_PHASE_BE0 && pScalabilityState->pHwInterface->GetMfxInterface()->GetNumVdbox() > 2)
+    if (HcpDecPhase == CODECHAL_HCP_DECODE_PHASE_BE0
+        && pScalabilityState->pHwInterface->GetMfxInterface()->GetNumVdbox() > 2
+        && !pOsInterface->bGucSubmission)
     {
         if (pScalabilityState->bFESeparateSubmission)
         {
@@ -714,7 +720,7 @@ MOS_STATUS CodecHalDecodeScalability_FEBESync_G12(
     }
 
     if (CodecHalDecodeScalabilityIsBEPhaseG12(pScalabilityState) ||
-        CodecHalDecodeScalabilityIsFirstRealTilePhase(pScalabilityState))
+        (CodecHalDecodeScalabilityIsFirstRealTilePhase(pScalabilityState)))
     {
         // Stop Watchdog before BEs wait
         pMiInterface->AddWatchdogTimerStopCmd(pCmdBufferInUse);
@@ -927,10 +933,7 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     vdboxNum = vdboxMfxInterface->GetNumVdbox();
 
     if (vdboxNum < 2
-#if (_DEBUG || _RELEASE_INTERNAL)
-        || !osInterface->bHcpDecScalabilityMode
-#endif
-        )
+        || !osInterface->bHcpDecScalabilityMode)
     {
         eStatus = MOS_STATUS_INVALID_PARAMETER;
         CODECHAL_DECODE_ASSERTMESSAGE("not support scalability on this platform.");
@@ -1015,6 +1018,11 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
         pScalabilityState->bFESeparateSubmission = false;
     }
 
+    if(osInterface->bGucSubmission)
+    {
+        pScalabilityState->bFESeparateSubmission = false;
+    }
+
 #if (_DEBUG || _RELEASE_INTERNAL)
     if (osInterface->bEnableDbgOvrdInVE)
     {
@@ -1056,7 +1064,7 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     VEInitParms.ucMaxNumPipesInUse = CodecHalDecodeMaxNumPipesInUseG12(vdboxNum);
     VEInitParms.ucNumOfSdryCmdBufSets = CODECHAL_SCALABILITY_DECODE_SECONDARY_CMDBUFSET_NUM;
     VEInitParms.ucMaxNumOfSdryCmdBufInOneFrame = pScalabilityState->bFESeparateSubmission ? VEInitParms.ucMaxNumPipesInUse : (VEInitParms.ucMaxNumPipesInUse + 1);
-    CODECHAL_DECODE_CHK_STATUS(Mos_VirtualEngineInterface_Initialize(osInterface, &VEInitParms));
+    CODECHAL_DECODE_CHK_STATUS(osInterface->pfnVirtualEngineInterfaceInitialize(osInterface, &VEInitParms));
     pScalabilityState->pVEInterface = pVEInterface = osInterface->pVEInterf;
 
     if (pVEInterface->pfnVEGetHintParams)
@@ -1445,13 +1453,14 @@ MOS_STATUS CodecHalDecodeScalability_AllocateResources_VariableSizes_G12(
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalabilityState->pHwInterface->GetOsInterface());
     CODECHAL_DECODE_CHK_NULL_RETURN(pHcpBufSizeParam);
     CODECHAL_DECODE_CHK_NULL_RETURN(pAllocParam);
+    pOsInterface = pScalabilityState->pHwInterface->GetOsInterface();
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalDecodeScalability_AllocateResources_VariableSizes(pScalabilityState, pHcpBufSizeParam, pAllocParam));
 
     // for multi-pipe scalability mode
     if (pScalabilityState->ucNumVdbox > 2)
     {
-        if (pScalabilityState->bFESeparateSubmission)
+        if (pScalabilityState->bFESeparateSubmission && pOsInterface->bGucSubmission)
         {
             for (int i = 1; i < CODECHAL_HCP_STREAMOUT_BUFFER_MAX_NUM; i++)
             {
@@ -1559,6 +1568,56 @@ void CodecHalDecodeScalability_Destroy_G12(
     return;
 }
 
+bool CodecHalDecodeScalability_DecideEnableScala_G12(
+    PCODECHAL_DECODE_SCALABILITY_STATE       pScalState,
+    PCODECHAL_DECODE_SCALABILITY_INIT_PARAMS pInitParams,
+    bool                                     bCanEnableRealTile)
+{
+    bool    bEnableScala = false;
+
+    CODECHAL_DECODE_FUNCTION_ENTER;
+
+    PMOS_INTERFACE pOsInterface = pScalState->pHwInterface->GetOsInterface();
+
+    if (pInitParams->usingHistogram)
+    {
+        bEnableScala = false;
+    }
+    else if (bCanEnableRealTile && (!pOsInterface->osCpInterface->IsCpEnabled() || pOsInterface->bCanEnableSecureRt))
+    {
+        bEnableScala = true;
+    }
+    else
+    {
+        // NonRextFormat && >=5k - VT Scalability
+        if (CodechalDecodeNonRextFormat(pInitParams->format) &&
+            CodechalDecodeResolutionEqualLargerThan5k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
+        {
+            bEnableScala = true;
+        }
+
+        // RextFormat && >=4k - VT Scalability
+        if (!CodechalDecodeNonRextFormat(pInitParams->format) &&
+            CodechalDecodeResolutionEqualLargerThan4k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
+        {
+            bEnableScala = true;
+
+            if (MEDIA_IS_SKU(pScalState->pHwInterface->GetSkuTable(), FtrDecodeHEVC422VTScalaDisable))
+            {
+                // HEVC 422 8b/10b && <8k - Disable VT Sclability
+                if ((pScalState->Standard == CODECHAL_HEVC && (pInitParams->format == Format_YUY2 || pInitParams->format == Format_Y210)) &&
+                    (!CodechalDecodeResolutionEqualLargerThan8k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel)))
+                {
+                    bEnableScala = false;
+                    CODECHAL_DECODE_NORMALMESSAGE("HEVC 422 && Resolution < 8k - Disable VT Scalability ");
+                }
+            }         
+        }
+    }
+
+    return bEnableScala;
+}
+
 MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
     PCODECHAL_DECODE_SCALABILITY_STATE         pScalState,
     PCODECHAL_DECODE_SCALABILITY_INIT_PARAMS   pInitParams)
@@ -1587,13 +1646,14 @@ MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
     bCanEnableRealTile = !(static_cast<PCODECHAL_DECODE_SCALABILITY_STATE_G12>(pScalState))->bDisableRtMode;
     if (!pScalStateG12->bEnableRtMultiPhase)
         u8MaxTileColumn = 2;
+#endif
     if(!bCanEnableScalability
         && pOsInterface
         && (pOsInterface->bHcpDecScalabilityMode == MOS_SCALABILITY_ENABLE_MODE_USER_FORCE))
     {
         bCanEnableScalability = true;
     }
-#endif
+
     bCanEnableRealTile = bCanEnableRealTile && pInitParamsG12->bIsTileEnabled && (pInitParams->u8NumTileColumns > 1) &&
                          (pInitParams->u8NumTileColumns <= u8MaxTileColumn) && (pInitParams->u8NumTileRows <= HEVC_NUM_MAX_TILE_ROW) &&
                          pInitParamsG12->bHasSubsetParams;
@@ -1637,11 +1697,7 @@ MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
                         pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_2;
                     }
                 }
-                else if ((!pInitParams->usingHistogram) && ((!CodechalDecodeNonRextFormat(pInitParams->format)
-                                    && CodechalDecodeResolutionEqualLargerThan4k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
-                                || (CodechalDecodeNonRextFormat(pInitParams->format)
-                                    && CodechalDecodeResolutionEqualLargerThan5k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
-                                || (bCanEnableRealTile && (!pOsInterface->osCpInterface->IsCpEnabled() || pOsInterface->bCanEnableSecureRt))))
+                else if (CodecHalDecodeScalability_DecideEnableScala_G12(pScalState, pInitParams, bCanEnableRealTile))
                 {
                     pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_2;
                 }
@@ -1665,6 +1721,98 @@ MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
     return eStatus;
 }
 
+
+MOS_STATUS CodechalDecodeScalability_ConstructParmsForGpuCtxCreation_g12(
+    PCODECHAL_DECODE_SCALABILITY_STATE         pScalState,
+    PMOS_GPUCTX_CREATOPTIONS_ENHANCED          gpuCtxCreatOpts,
+    CodechalSetting *                          codecHalSetting)
+{
+    PMOS_INTERFACE                           pOsInterface;
+    CODECHAL_DECODE_SCALABILITY_INIT_PARAMS_G12  initParams;
+    MOS_STATUS                               eStatus = MOS_STATUS_SUCCESS;
+
+    CODECHAL_DECODE_FUNCTION_ENTER;
+
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalState);
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pHwInterface);
+    CODECHAL_DECODE_CHK_NULL_RETURN(gpuCtxCreatOpts);
+    CODECHAL_DECODE_CHK_NULL_RETURN(codecHalSetting);
+    bool sfcInUse = codecHalSetting->sfcInUseHinted && codecHalSetting->downsamplingHinted
+                       && (MEDIA_IS_SKU(pScalState->pHwInterface->GetSkuTable(), FtrSFCPipe)
+                       && !MEDIA_IS_SKU(pScalState->pHwInterface->GetSkuTable(), FtrDisableVDBox2SFC));
+    pOsInterface    = pScalState->pHwInterface->GetOsInterface();
+    MEDIA_FEATURE_TABLE *m_skuTable = pOsInterface->pfnGetSkuTable(pOsInterface);
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if (pOsInterface->bEnableDbgOvrdInVE)
+    {
+        PMOS_VIRTUALENGINE_INTERFACE pVEInterface = pScalState->pVEInterface;
+        CODECHAL_DECODE_CHK_NULL_RETURN(pVEInterface);
+        gpuCtxCreatOpts->DebugOverride      = true;
+        if (MEDIA_IS_SKU(m_skuTable, FtrSfcScalability))
+        {
+            gpuCtxCreatOpts->UsingSFC = false;// this param ignored when dbgoverride enabled
+        }
+        else
+        {
+            gpuCtxCreatOpts->UsingSFC = sfcInUse;  // this param ignored when dbgoverride enabled
+        }
+        CODECHAL_DECODE_CHK_STATUS_RETURN(pScalState->pfnDebugOvrdDecidePipeNum(pScalState));
+
+        if (pOsInterface->apoMosEnabled)
+        {
+            CODECHAL_DECODE_CHK_NULL_RETURN(pVEInterface->veInterface);
+            for (uint32_t i = 0; i < pVEInterface->veInterface->GetEngineCount(); i++)
+            {
+                gpuCtxCreatOpts->EngineInstance[i] = pVEInterface->veInterface->GetEngineLogicId(i);
+            }
+        }
+        else
+        {
+            for (uint32_t i = 0; i < pVEInterface->ucEngineCount; i++)
+            {
+                gpuCtxCreatOpts->EngineInstance[i] = pVEInterface->EngineLogicId[i];
+            }
+        }
+    }
+    else
+#endif
+    {
+        if (MEDIA_IS_SKU(m_skuTable, FtrSfcScalability))
+        {
+            gpuCtxCreatOpts->UsingSFC = false;
+        }
+        else
+        {
+            gpuCtxCreatOpts->UsingSFC = sfcInUse;
+        }
+
+        MOS_ZeroMemory(&initParams, sizeof(initParams));
+        initParams.u32PicWidthInPixel   = MOS_ALIGN_CEIL(codecHalSetting->width, 8);
+        initParams.u32PicHeightInPixel  = MOS_ALIGN_CEIL(codecHalSetting->height, 8);
+        if (((codecHalSetting->standard == CODECHAL_VP9) || (codecHalSetting->standard == CODECHAL_HEVC))
+                && (codecHalSetting->chromaFormat == HCP_CHROMA_FORMAT_YUV420))
+        {
+            initParams.format = Format_NV12;
+            if (codecHalSetting->lumaChromaDepth == CODECHAL_LUMA_CHROMA_DEPTH_10_BITS)
+            {
+                initParams.format = Format_P010;
+            }
+        }
+        initParams.usingSFC             = sfcInUse;
+        initParams.usingSecureDecode    = codecHalSetting->secureMode;
+        CODECHAL_DECODE_CHK_STATUS_RETURN(pScalState->pfnDecidePipeNum(
+            pScalState,
+            &initParams));
+    }
+
+    CODECHAL_DECODE_CHK_STATUS_RETURN(pScalState->pfnMapPipeNumToLRCACount(
+        pScalState,
+        &gpuCtxCreatOpts->LRCACount));
+
+    return eStatus;
+}
+
+
 MOS_STATUS CodechalDecodeScalability_MapPipeNumToLRCACount_G12(
     PCODECHAL_DECODE_SCALABILITY_STATE   pScalState,
     uint32_t                             *LRCACount)
@@ -1832,7 +1980,8 @@ void CodecHalDecodeScalability_DecPhaseToSubmissionType_G12(
                 pCmdBuffer->iSubmissionType |= ((pScalabilityState->u8RtCurPipe - 1) << SUBMISSION_TYPE_MULTI_PIPE_SLAVE_INDEX_SHIFT);
             }
 
-            if (pScalabilityState->u8RtCurPhase == pScalabilityState->u8RtPhaseNum - 1)
+            if (!(pScalabilityState->pHwInterface->GetOsInterface()->bGucSubmission)
+            && (pScalabilityState->u8RtCurPhase == pScalabilityState->u8RtPhaseNum - 1))
             {
                 if (pScalabilityState->u8RtCurPipe == pScalabilityState->u8RtPipeInLastPhase - 1)
                 {
