@@ -32,7 +32,6 @@ OTHER DEALINGS IN THE SOFTWARE.
 #include "mhw_vdbox_hcp_generic.h"
 #include "mhw_vdbox_hcp_hwcmd_g12_X.h"
 #include "mhw_vdbox_g12_X.h"
-#include "media_user_settings_mgr_g12.h"
 #include "codec_def_decode_hevc.h"
 
 //definition for row store cache offset on GEN12
@@ -278,6 +277,10 @@ struct MHW_VDBOX_PIPE_BUF_ADDR_PARAMS_G12 : public MHW_VDBOX_PIPE_BUF_ADDR_PARAM
     PMOS_RESOURCE               presIntraPredLeftReconColStoreBuffer = nullptr;
     PMOS_RESOURCE               presCABACSyntaxStreamOutBuffer = nullptr;
     PMOS_RESOURCE               presCABACSyntaxStreamOutMaxAddr = nullptr;
+
+    //Reference Mmc
+    bool                        bSpecificReferencedMmcRequired = false;
+    MOS_MEMCOMP_STATE           ReferencesMmcState = MOS_MEMCOMP_DISABLED;
 };
 using PMHW_VDBOX_PIPE_BUF_ADDR_PARAMS_G12 = MHW_VDBOX_PIPE_BUF_ADDR_PARAMS_G12 *;
 
@@ -392,7 +395,8 @@ protected:
     };
 
     bool       m_hevcRDOQPerfDisabled = false; //!< Flag to indicate if HEVC RDOQ Perf is disabled
-    uint32_t   m_watchDogTimerThreshold = 0; //!< For Watch Dog Timer threshold on Gen11+
+    uint32_t   m_watchDogTimerThreshold = 0;   //!< For Watch Dog Timer threshold on Gen11+
+    bool       m_disableTlbPrefetch = false;   //!< To disable TLB pre-fetch or not
 
     static const uint32_t   m_HevcSccPaletteSize = 96; //!< For HEVC SCC palette size on Gen12+
     static const uint32_t   m_hcpPakObjSize = MOS_BYTES_TO_DWORDS(sizeof(HcpPakObjectG12));   //!< hcp pak object size
@@ -454,6 +458,17 @@ public:
         }
 #endif
 
+        if (MEDIA_IS_WA(m_osInterface->pfnGetWaTable(m_osInterface), Wa_14012254246))
+        {
+            MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
+            MOS_UserFeature_ReadValue_ID(
+                nullptr,
+                __MEDIA_USER_FEATURE_VALUE_DISABLE_TLB_PREFETCH_ID,
+                &userFeatureData,
+                this->m_osInterface->pOsContext);
+            m_disableTlbPrefetch = userFeatureData.u32Data ? true : false;
+        }
+
         m_hevcEncCuRecordSize = sizeof(EncodeHevcCuDataG12);
         m_pakHWTileSizeRecordSize = sizeof(HCPPakHWTileSizeRecord_G12);
 
@@ -679,4 +694,4 @@ public:
         uint32_t                        *size);
 };
 
-#endif
+#endif
\ No newline at end of file
