@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2018, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -31,7 +31,7 @@
 #include "codechal_memdecomp.h"
 #include "media_ddi_decode_const.h"
 #include "media_ddi_factory.h"
-#include "media_interfaces.h"
+#include "media_factory.h"
 
 VAStatus DdiDecodeAVC::ParseSliceParams(
     DDI_MEDIA_CONTEXT           *mediaCtx,
@@ -62,7 +62,7 @@ VAStatus DdiDecodeAVC::ParseSliceParams(
     uint32_t sliceBaseOffset;
     sliceBaseOffset = GetBsBufOffset(m_groupIndex);
 
-    uint32_t i, slcCount;
+    uint32_t i, slcCount, refCount;
     for (slcCount = 0; slcCount < numSlices; slcCount++)
     {
         if (m_ddiDecodeCtx->bShortFormatInUse)
@@ -113,7 +113,8 @@ VAStatus DdiDecodeAVC::ParseSliceParams(
             avcSliceParams->slice_alpha_c0_offset_div2    = slc->slice_alpha_c0_offset_div2;
             avcSliceParams->slice_beta_offset_div2        = slc->slice_beta_offset_div2;
             // reference list 0
-            for (i = 0; i < CODEC_MAX_NUM_REF_FIELD; i++)
+            refCount = std::min(avcSliceParams->num_ref_idx_l0_active_minus1 + 1, CODEC_MAX_NUM_REF_FIELD);
+            for (i = 0; i < refCount; i++)
             {
                 SetupCodecPicture(
                     mediaCtx,
@@ -127,7 +128,8 @@ VAStatus DdiDecodeAVC::ParseSliceParams(
                 GetSlcRefIdx(&(avcPicParams->RefFrameList[0]), &(avcSliceParams->RefPicList[0][i]));
             }
             // reference list 1
-            for (i = 0; i < CODEC_MAX_NUM_REF_FIELD; i++)
+            refCount = std::min(avcSliceParams->num_ref_idx_l1_active_minus1 + 1, CODEC_MAX_NUM_REF_FIELD);
+            for (i = 0; i < refCount; i++)
             {
                 SetupCodecPicture(
                     mediaCtx,
@@ -170,6 +172,27 @@ VAStatus DdiDecodeAVC::ParseSliceParams(
         avcSliceParams->slice_id = 0;
         avcSliceParams++;
     }
+
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_SLICEPARAM))
+    {
+        if (m_ddiDecodeCtx->bShortFormatInUse)
+        {
+            DECODE_EVENTDATA_SLICEPARAM_AVC *pEventData = (DECODE_EVENTDATA_SLICEPARAM_AVC *)MOS_AllocMemory(numSlices * sizeof(DECODE_EVENTDATA_SLICEPARAM_AVC));
+            DecodeEventDataAVCSliceParamInit(pEventData, (PCODEC_AVC_SLICE_PARAMS)(m_ddiDecodeCtx->DecodeParams.m_sliceParams), numSlices);
+            MOS_TraceEvent(EVENT_DECODE_BUFFER_SLICEPARAM_AVC, EVENT_TYPE_INFO, &numSlices, sizeof(uint32_t), pEventData, numSlices * sizeof(DECODE_EVENTDATA_SLICEPARAM_AVC));
+            MOS_FreeMemory(pEventData);
+        }
+        else
+        {
+            DECODE_EVENTDATA_LONGSLICEPARAM_AVC *pEventData = (DECODE_EVENTDATA_LONGSLICEPARAM_AVC *)MOS_AllocMemory(numSlices * sizeof(DECODE_EVENTDATA_LONGSLICEPARAM_AVC));
+            DecodeEventDataAVCLongSliceParamInit(pEventData, (PCODEC_AVC_SLICE_PARAMS)(m_ddiDecodeCtx->DecodeParams.m_sliceParams), numSlices);
+            MOS_TraceEvent(EVENT_DECODE_BUFFER_LONGSLICEPARAM_AVC, EVENT_TYPE_INFO, &numSlices, sizeof(uint32_t), pEventData, numSlices * sizeof(DECODE_EVENTDATA_LONGSLICEPARAM_AVC));
+            MOS_FreeMemory(pEventData);
+        }
+    }
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -246,7 +269,7 @@ VAStatus DdiDecodeAVC::ParsePicParams(
 
     //Accoding to RecList, if the surface id is invalid, set PicFlags equal to PICTURE_INVALID
     for (i = 0; i < CODEC_MAX_NUM_REF_FRAME; i++)
-    {
+    {     
         //Check the surface id of reference list
         if (VA_INVALID_ID == m_ddiDecodeCtx->RecListSurfaceID[avcPicParams->RefFrameList[i].FrameIdx])
         {
@@ -303,6 +326,26 @@ VAStatus DdiDecodeAVC::ParsePicParams(
 
     avcPicParams->frame_num = picParam->frame_num;
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    // Picture Info
+    DECODE_EVENTDATA_INFO_PICTUREVA eventData = {0};
+    eventData.CodecFormat                   = m_ddiDecodeCtx->wMode;
+    eventData.FrameType                     = avcPicParams->pic_fields.IntraPicFlag == 1 ? I_TYPE : MIXED_TYPE;
+    eventData.PicStruct                     = avcPicParams->CurrPic.PicFlags;  // 1-Top; 2-Bottom; 3-Frame
+    eventData.Width                         = (avcPicParams->pic_width_in_mbs_minus1 + 1) * MACROBLOCK_WIDTH;
+    eventData.Height                        = (avcPicParams->pic_height_in_mbs_minus1 + 1) * MACROBLOCK_HEIGHT;
+    eventData.Bitdepth                      = avcPicParams->bit_depth_luma_minus8 + 8;
+    eventData.ChromaFormat                  = avcPicParams->seq_fields.chroma_format_idc;  // 0-4:0:0; 1-4:2:0; 2-4:2:2; 3-4:4:4
+    MOS_TraceEvent(EVENT_DECODE_INFO_PICTUREVA, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_PICPARAM))
+    {
+        DECODE_EVENTDATA_PICPARAM_AVC eventData;
+        DecodeEventDataAVCPicParamInit(&eventData, avcPicParams);
+        MOS_TraceEvent(EVENT_DECODE_BUFFER_PICPARAM_AVC, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -407,6 +450,33 @@ VAStatus DdiDecodeAVC::RenderPicture(
 
             DdiMedia_MediaBufferToMosResource(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index], &m_ddiDecodeCtx->BufMgr.resBitstreamBuffer);
             m_ddiDecodeCtx->DecodeParams.m_dataSize += dataSize;
+
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+            uint8_t * pDataBuf = (uint8_t *)DdiMediaUtil_LockBuffer(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index], MOS_LOCKFLAG_READONLY);
+            DDI_CHK_NULL(pDataBuf, "nullptr bitstream", VA_STATUS_ERROR_INVALID_BUFFER);
+
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM_INFO))
+            {
+                DECODE_EVENTDATA_BITSTREAM eventData;
+                for (int i = 0; i < 32; i++)
+                {
+                    eventData.Data[i] = pDataBuf[i];
+                }
+                MOS_TraceEvent(EVENT_DECODE_INFO_BITSTREAM, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+            }
+
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM))
+            {
+                MOS_TraceDataDump(
+                "Decode_Bitstream",
+                0,
+                pDataBuf,
+                m_ddiDecodeCtx->DecodeParams.m_dataSize);
+            }
+                
+            DdiMediaUtil_UnlockBuffer(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index]);
+#endif
+
             break;
         }
         case VASliceParameterBufferType:
@@ -429,6 +499,18 @@ VAStatus DdiDecodeAVC::RenderPicture(
         {
             VAIQMatrixBufferH264 *imxBuf = (VAIQMatrixBufferH264 *)data;
             DDI_CHK_RET(ParseIQMatrix(mediaCtx, imxBuf),"ParseIQMatrix failed!");
+
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_QMATRIX))
+            {
+                MOS_TraceDataDump(
+                    "Decode_QMatrix",
+                    0,
+                    imxBuf,
+                    sizeof(VAIQMatrixBufferH264));
+            }
+#endif
+
             break;
         }
         case VAPictureParameterBufferType:
@@ -469,13 +551,21 @@ VAStatus DdiDecodeAVC::SetDecodeParams()
     if (m_decProcessingType == VA_DEC_PROCESSING)
     {
         auto procParams = 
-            (PCODECHAL_DECODE_PROCESSING_PARAMS)m_ddiDecodeCtx->DecodeParams.m_procParams;
-        procParams->pInputSurface = (&m_ddiDecodeCtx->DecodeParams)->m_destSurface;
+            (DecodeProcessingParams *)m_ddiDecodeCtx->DecodeParams.m_procParams;
+        procParams->m_inputSurface = (&m_ddiDecodeCtx->DecodeParams)->m_destSurface;
         // codechal_decode_sfc.c expects Input Width/Height information.
-        procParams->pInputSurface->dwWidth    = procParams->pInputSurface->OsResource.iWidth;
-        procParams->pInputSurface->dwHeight = procParams->pInputSurface->OsResource.iHeight;
-        procParams->pInputSurface->dwPitch    = procParams->pInputSurface->OsResource.iPitch;
-        procParams->pInputSurface->Format    = procParams->pInputSurface->OsResource.Format;
+        procParams->m_inputSurface->dwWidth  = procParams->m_inputSurface->OsResource.iWidth;
+        procParams->m_inputSurface->dwHeight = procParams->m_inputSurface->OsResource.iHeight;
+        procParams->m_inputSurface->dwPitch  = procParams->m_inputSurface->OsResource.iPitch;
+        procParams->m_inputSurface->Format   = procParams->m_inputSurface->OsResource.Format;
+
+        if(m_requireInputRegion)
+        {
+            procParams->m_inputSurfaceRegion.m_x = 0;
+            procParams->m_inputSurfaceRegion.m_y = 0;
+            procParams->m_inputSurfaceRegion.m_width = procParams->m_inputSurface->dwWidth;
+            procParams->m_inputSurfaceRegion.m_height = procParams->m_inputSurface->dwHeight;
+        }
     }
 #endif
 
@@ -568,7 +658,6 @@ VAStatus DdiDecodeAVC::CodecHalInit(
     m_codechalSettings->shortFormatInUse = m_ddiDecodeCtx->bShortFormatInUse;
 
     CODECHAL_FUNCTION codecFunction = CODECHAL_FUNCTION_DECODE;
-    m_ddiDecodeCtx->pCpDdiInterface->SetCpParams(m_ddiDecodeAttr->uiEncryptionType, m_codechalSettings);
 
     CODECHAL_STANDARD_INFO standardInfo;
     memset(&standardInfo, 0, sizeof(standardInfo));
@@ -589,6 +678,8 @@ VAStatus DdiDecodeAVC::CodecHalInit(
     m_codechalSettings->mode     = CODECHAL_DECODE_MODE_AVCVLD;
     m_codechalSettings->standard = CODECHAL_AVC;
 
+    m_ddiDecodeCtx->pCpDdiInterface->SetCpParams(m_ddiDecodeAttr->uiEncryptionType, m_codechalSettings);
+
     m_ddiDecodeCtx->DecodeParams.m_iqMatrixBuffer = (void*)MOS_AllocAndZeroMemory(sizeof(CODEC_AVC_IQ_MATRIX_PARAMS));
     if (m_ddiDecodeCtx->DecodeParams.m_iqMatrixBuffer == nullptr)
     {
@@ -613,11 +704,11 @@ VAStatus DdiDecodeAVC::CodecHalInit(
 #ifdef _DECODE_PROCESSING_SUPPORTED
     if (m_decProcessingType == VA_DEC_PROCESSING)
     {
-        PCODECHAL_DECODE_PROCESSING_PARAMS procParams = nullptr;
+        DecodeProcessingParams *procParams = nullptr;
 
         m_codechalSettings->downsamplingHinted = true;
 
-        procParams = (PCODECHAL_DECODE_PROCESSING_PARAMS)MOS_AllocAndZeroMemory(sizeof(CODECHAL_DECODE_PROCESSING_PARAMS));
+        procParams = (DecodeProcessingParams *)MOS_AllocAndZeroMemory(sizeof(DecodeProcessingParams));
         if (procParams == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
@@ -625,8 +716,8 @@ VAStatus DdiDecodeAVC::CodecHalInit(
         }
 
         m_ddiDecodeCtx->DecodeParams.m_procParams = procParams;
-        procParams->pOutputSurface               = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
-        if (procParams->pOutputSurface == nullptr)
+        procParams->m_outputSurface               = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
+        if (procParams->m_outputSurface == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
             goto CleanUpandReturn;
@@ -672,8 +763,8 @@ CleanUpandReturn:
     if (m_ddiDecodeCtx->DecodeParams.m_procParams)
     {
         auto procParams = 
-            (PCODECHAL_DECODE_PROCESSING_PARAMS)m_ddiDecodeCtx->DecodeParams.m_procParams;
-        MOS_FreeMemory(procParams->pOutputSurface);
+            (DecodeProcessingParams *)m_ddiDecodeCtx->DecodeParams.m_procParams;
+        MOS_FreeMemory(procParams->m_outputSurface);
 
         MOS_FreeMemory(m_ddiDecodeCtx->DecodeParams.m_procParams);
         m_ddiDecodeCtx->DecodeParams.m_procParams = nullptr;
@@ -692,8 +783,20 @@ VAStatus DdiDecodeAVC::InitResourceBuffer()
     bufMgr->pSliceData = nullptr;
 
     bufMgr->ui64BitstreamOrder = 0;
-    bufMgr->dwMaxBsSize        = m_width *
-                          m_height * 3 / 2;
+
+    if(m_width * m_height < CODEC_720P_MAX_PIC_WIDTH * CODEC_720P_MAX_PIC_HEIGHT)
+    {
+        bufMgr->dwMaxBsSize = m_width * m_height * 3 / 2;
+    }
+    else if(m_width * m_height < CODEC_4K_MAX_PIC_WIDTH * CODEC_4K_MAX_PIC_HEIGHT)
+    {
+        bufMgr->dwMaxBsSize = m_width * m_height * 3 / 8;
+    }
+    else
+    {
+        bufMgr->dwMaxBsSize = m_width * m_height * 3 / 16;
+    }
+
     // minimal 10k bytes for some special case. Will refractor this later
     if (bufMgr->dwMaxBsSize < DDI_CODEC_MIN_VALUE_OF_MAX_BS_SIZE)
     {
@@ -834,8 +937,15 @@ void DdiDecodeAVC::SetupCodecPicture(
     if(vaPic.picture_id != DDI_CODEC_INVALID_FRAME_INDEX)
     {
         DDI_MEDIA_SURFACE *surface = DdiMedia_GetSurfaceFromVASurfaceID(mediaCtx, vaPic.picture_id);
-        vaPic.frame_idx    = GetRenderTargetID(rtTbl, surface);
-        codecHalPic->FrameIdx = (uint8_t)vaPic.frame_idx;
+        vaPic.frame_idx    = GetRenderTargetID(rtTbl, surface);    
+        if(vaPic.frame_idx == DDI_CODEC_INVALID_FRAME_INDEX)
+        {
+            codecHalPic->FrameIdx = CODEC_AVC_NUM_UNCOMPRESSED_SURFACE - 1;
+        }
+        else
+        {
+            codecHalPic->FrameIdx = (uint8_t)vaPic.frame_idx;
+        }
     }
     else
     {
