@@ -31,6 +31,74 @@
 #include "media_ddi_encode_const.h"
 #include "media_ddi_factory.h"
 #include "codechal_encoder_base.h"
+#include "codec_def_encode_hevc_trace.h"
+
+namespace
+{
+namespace APISticker
+{
+#define APIMAP_ELEM(e) {#e, __LINE__ - START_LINE}
+constexpr uint32_t START_LINE = __LINE__ + 2;
+const std::map<std::string, uint32_t> APIMap = {
+        APIMAP_ELEM(DdiEncodeHevc::ContextInitialize),
+        APIMAP_ELEM(RenderPicture),
+        APIMAP_ELEM(EncodeInCodecHal),
+        APIMAP_ELEM(ResetAtFrameLevel),
+        APIMAP_ELEM(ParseSeqParams),
+        APIMAP_ELEM(ParsePicParams),
+        APIMAP_ELEM(ParseSlcParams),
+        APIMAP_ELEM(Qmatrix),
+        APIMAP_ELEM(FindNalUnitStartCodes),
+        APIMAP_ELEM(ParsePackedHeaderParams),
+        APIMAP_ELEM(ParsePackedHeaderData),
+        APIMAP_ELEM(ParseMiscParams),
+};
+#undef APIMAP_ELEM
+
+inline void TraceEnter(const char *api)
+{
+    try
+    {
+        auto data = APIMap.at(api);
+
+        MOS_TraceEventExt(
+            TR_KEY_ENCODE_EVENT_API_STICKER,
+            MT_EVENT_LEVEL::ALWAYS,
+            EVENT_ENCODE_API_STICKER_HEVC,
+            EVENT_TYPE_START,
+            &data,
+            sizeof(data));
+    }
+    catch (...)
+    {
+        return;
+    }
+}
+
+inline void TraceExit(const char *api, VAStatus ret)
+{
+    try
+    {
+        uint32_t data[] = {APIMap.at(api), static_cast<uint32_t>(ret)};
+
+        MOS_TraceEventExt(
+            TR_KEY_ENCODE_EVENT_API_STICKER,
+            MT_EVENT_LEVEL::CRITICAL,
+            EVENT_ENCODE_API_STICKER_HEVC,
+            EVENT_TYPE_END,
+            data,
+            sizeof(data));
+    }
+    catch (...)
+    {
+        return;
+    }
+}
+
+#define API_STICKER_TRACE_ENTER() APISticker::TraceEnter(__func__)
+#define API_STICKER_TRACE_EXIT(ret) APISticker::TraceExit(__func__, ret)
+}
+}
 
 extern template class MediaDdiFactoryNoArg<DdiEncodeBase>;
 
@@ -77,6 +145,9 @@ DdiEncodeHevc::~DdiEncodeHevc()
     MOS_FreeMemory(m_encodeCtx->pSliceHeaderData);
     m_encodeCtx->pSliceHeaderData = nullptr;
 
+    MOS_FreeMemory(m_encodeCtx->pQmatrixParams);
+    m_encodeCtx->pQmatrixParams = nullptr;
+
     if (m_encodeCtx->pbsBuffer)
     {
         MOS_FreeMemory(m_encodeCtx->pbsBuffer->pBase);
@@ -90,6 +161,8 @@ DdiEncodeHevc::~DdiEncodeHevc()
 VAStatus DdiEncodeHevc::ContextInitialize(
     CodechalSetting *codecHalSettings)
 {
+    API_STICKER_TRACE_ENTER();
+
     DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx.", VA_STATUS_ERROR_INVALID_CONTEXT);
     DDI_CHK_NULL(m_encodeCtx->pCpDdiInterface, "nullptr m_encodeCtx->pCpDdiInterface.", VA_STATUS_ERROR_INVALID_CONTEXT);
     DDI_CHK_NULL(codecHalSettings, "nullptr codecHalSettings.", VA_STATUS_ERROR_INVALID_CONTEXT);
@@ -186,6 +259,10 @@ VAStatus DdiEncodeHevc::ContextInitialize(
     m_encodeCtx->pSEIFromApp = (CodechalEncodeSeiData *)MOS_AllocAndZeroMemory(sizeof(CodechalEncodeSeiData));
     DDI_CHK_NULL(m_encodeCtx->pSEIFromApp, "nullptr m_encodeCtx->pSEIFromApp.", VA_STATUS_ERROR_ALLOCATION_FAILED);
 
+    // Allocate Qmatrix structure
+    m_encodeCtx->pQmatrixParams = (void *)MOS_AllocAndZeroMemory(sizeof(CODECHAL_HEVC_IQ_MATRIX_PARAMS));
+    DDI_CHK_NULL(m_encodeCtx->pQmatrixParams, "nullptr QMatrixParams", VA_STATUS_ERROR_ALLOCATION_FAILED);
+
     // for slice header from application
     m_encodeCtx->pSliceHeaderData = (CODEC_ENCODER_SLCDATA *)MOS_AllocAndZeroMemory(m_encodeCtx->wPicHeightInMB * m_encodeCtx->wPicWidthInMB * sizeof(CODEC_ENCODER_SLCDATA));
     DDI_CHK_NULL(m_encodeCtx->pSliceHeaderData, "nullptr m_encodeCtx->pSliceHeaderData.", VA_STATUS_ERROR_ALLOCATION_FAILED);
@@ -198,11 +275,13 @@ VAStatus DdiEncodeHevc::ContextInitialize(
     m_encodeCtx->pbsBuffer->pBase      = (uint8_t *)MOS_AllocAndZeroMemory(m_encodeCtx->pbsBuffer->BufferSize);
     DDI_CHK_NULL(m_encodeCtx->pbsBuffer->pBase, "nullptr m_encodeCtx->pbsBuffer->pBase.", VA_STATUS_ERROR_ALLOCATION_FAILED);
 
+    API_STICKER_TRACE_EXIT(eStatus);
     return eStatus;
 }
 
 VAStatus DdiEncodeHevc::RenderPicture(VADriverContextP ctx, VAContextID context, VABufferID *buffers, int32_t numBuffers)
 {
+    API_STICKER_TRACE_ENTER();
     VAStatus vaStatus = VA_STATUS_SUCCESS;
 
     DDI_FUNCTION_ENTER();
@@ -233,6 +312,10 @@ VAStatus DdiEncodeHevc::RenderPicture(VADriverContextP ctx, VAContextID context,
 
         switch (buf->uiType)
         {
+        case VAQMatrixBufferType:
+            DDI_CHK_STATUS(Qmatrix(data), VA_STATUS_ERROR_INVALID_BUFFER);
+            break;
+
         case VAEncSequenceParameterBufferType:
             DDI_CHK_STATUS(ParseSeqParams(data), VA_STATUS_ERROR_INVALID_BUFFER);
             m_encodeCtx->bNewSeq = true;
@@ -277,11 +360,13 @@ VAStatus DdiEncodeHevc::RenderPicture(VADriverContextP ctx, VAContextID context,
     }
 
     DDI_FUNCTION_EXIT(vaStatus);
+    API_STICKER_TRACE_EXIT(vaStatus);
     return vaStatus;
 }
 
 VAStatus DdiEncodeHevc::EncodeInCodecHal(uint32_t numSlices)
 {
+    API_STICKER_TRACE_ENTER();
     DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(m_encodeCtx->pCodecHal, "nullptr m_encodeCtx->pCodecHal", VA_STATUS_ERROR_INVALID_PARAMETER);
 
@@ -340,11 +425,15 @@ VAStatus DdiEncodeHevc::EncodeInCodecHal(uint32_t numSlices)
     }
 
     PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS hevcSeqParams = (PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS)((uint8_t *)m_encodeCtx->pSeqParams);
-    hevcSeqParams->TargetUsage = m_encodeCtx->targetUsage;
-    encodeParams.pSeqParams   = m_encodeCtx->pSeqParams;
-    encodeParams.pVuiParams   = m_encodeCtx->pVuiParams;
-    encodeParams.pPicParams   = m_encodeCtx->pPicParams;
-    encodeParams.pSliceParams = m_encodeCtx->pSliceParams;
+    if (m_encodeCtx->bNewSeq)
+    {
+        hevcSeqParams->TargetUsage = m_encodeCtx->targetUsage;
+    }
+    encodeParams.pSeqParams      = m_encodeCtx->pSeqParams;
+    encodeParams.pVuiParams      = m_encodeCtx->pVuiParams;
+    encodeParams.pPicParams      = m_encodeCtx->pPicParams;
+    encodeParams.pSliceParams    = m_encodeCtx->pSliceParams;
+    encodeParams.pIQMatrixBuffer = m_encodeCtx->pQmatrixParams;
 
     // Sequence data
     encodeParams.bNewSeq = m_encodeCtx->bNewSeq;
@@ -359,13 +448,11 @@ VAStatus DdiEncodeHevc::EncodeInCodecHal(uint32_t numSlices)
     encodeParams.bNewQmatrixData = m_encodeCtx->bNewQmatrixData;
     encodeParams.bPicQuant       = m_encodeCtx->bPicQuant;
     encodeParams.ppNALUnitParams = m_encodeCtx->ppNALUnitParams;
+    encodeParams.uiNumNalUnits   = m_encodeCtx->indexNALUnit;
     encodeParams.pSeiData        = m_encodeCtx->pSEIFromApp;
     encodeParams.pSeiParamBuffer = m_encodeCtx->pSEIFromApp->pSEIBuffer;
     encodeParams.dwSEIDataOffset = 0;
 
-    CODECHAL_HEVC_IQ_MATRIX_PARAMS hevcIqMatrixParams;
-    encodeParams.pIQMatrixBuffer = &hevcIqMatrixParams;
-
     // whether driver need to pack slice header
     if (m_encodeCtx->bHavePackedSliceHdr)
     {
@@ -394,11 +481,13 @@ VAStatus DdiEncodeHevc::EncodeInCodecHal(uint32_t numSlices)
         return VA_STATUS_ERROR_ENCODING_ERROR;
     }
 
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
     return VA_STATUS_SUCCESS;
 }
 
 VAStatus DdiEncodeHevc::ResetAtFrameLevel()
 {
+    API_STICKER_TRACE_ENTER();
     DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx", VA_STATUS_ERROR_INVALID_PARAMETER);
 
     // Assume there is only one SPS parameter
@@ -425,11 +514,13 @@ VAStatus DdiEncodeHevc::ResetAtFrameLevel()
     m_encodeCtx->bLastPackedHdrIsSlice = false;
     m_encodeCtx->bMBQpEnable           = false;
 
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
     return VA_STATUS_SUCCESS;
 }
 
 VAStatus DdiEncodeHevc::ParseSeqParams(void *ptr)
 {
+    API_STICKER_TRACE_ENTER();
     DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(ptr, "nullptr ptr", VA_STATUS_ERROR_INVALID_PARAMETER);
 
@@ -494,6 +585,9 @@ VAStatus DdiEncodeHevc::ParseSeqParams(void *ptr)
         hevcSeqParams->motion_vector_resolution_control_idc = 0;
     }
 
+    CodecDefEncodeHevcTrace::TraceDDI(*hevcSeqParams);
+
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
     return VA_STATUS_SUCCESS;
 }
 
@@ -501,6 +595,7 @@ VAStatus DdiEncodeHevc::ParsePicParams(
     DDI_MEDIA_CONTEXT *mediaCtx,
     void              *ptr)
 {
+    API_STICKER_TRACE_ENTER();
     DDI_CHK_NULL(mediaCtx, "nullptr mediaCtx", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(ptr, "nullptr ptr", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx", VA_STATUS_ERROR_INVALID_PARAMETER);
@@ -524,6 +619,7 @@ VAStatus DdiEncodeHevc::ParsePicParams(
         || m_encodeCtx->vaProfile == VAProfileHEVCMain422_10
         || m_encodeCtx->vaProfile == VAProfileHEVCMain422_12
         || m_encodeCtx->vaProfile == VAProfileHEVCMain10
+        || m_encodeCtx->vaProfile == VAProfileHEVCMain12
         || m_encodeCtx->vaProfile == VAProfileHEVCSccMain10
         || m_encodeCtx->vaProfile == VAProfileHEVCSccMain444
         || m_encodeCtx->vaProfile == VAProfileHEVCSccMain444_10)
@@ -580,6 +676,9 @@ VAStatus DdiEncodeHevc::ParsePicParams(
     /* picParams->coding_type; App is always setting this to 0 */
     hevcPicParams->CodingType = picParams->pic_fields.bits.coding_type;
 
+    /* CodingType may be updated in slice processing. Do below to save pyramid level info */
+    hevcPicParams->ppsCodingType = picParams->pic_fields.bits.coding_type;
+
     hevcPicParams->HierarchLevelPlus1 = picParams->hierarchical_level_plus1;
 
     /* Reset it to zero now */
@@ -595,6 +694,7 @@ VAStatus DdiEncodeHevc::ParsePicParams(
     hevcPicParams->weighted_bipred_flag           = picParams->pic_fields.bits.weighted_bipred_flag;
     hevcPicParams->loop_filter_across_slices_flag = picParams->pic_fields.bits.pps_loop_filter_across_slices_enabled_flag;
     hevcPicParams->loop_filter_across_tiles_flag  = picParams->pic_fields.bits.loop_filter_across_tiles_enabled_flag;
+    hevcPicParams->scaling_list_data_present_flag = picParams->pic_fields.bits.scaling_list_data_present_flag;
     hevcPicParams->bLastPicInSeq                  = (picParams->last_picture & HEVC_LAST_PICTURE_EOSEQ) ? 1 : 0;
     hevcPicParams->bLastPicInStream               = (picParams->last_picture & HEVC_LAST_PICTURE_EOSTREAM) ? 1 : 0;
     hevcPicParams->bUseRawPicForRef               = false;
@@ -613,6 +713,9 @@ VAStatus DdiEncodeHevc::ParsePicParams(
     hevcPicParams->slice_pic_parameter_set_id       = picParams->slice_pic_parameter_set_id;
     hevcPicParams->nal_unit_type                    = picParams->nal_unit_type;
     hevcPicParams->no_output_of_prior_pics_flag     = picParams->pic_fields.bits.no_output_of_prior_pics_flag;
+#if VA_CHECK_VERSION(1, 10, 0)
+    hevcPicParams->bEnableGPUWeightedPrediction     = picParams->pic_fields.bits.enable_gpu_weighted_prediction;
+#endif
     hevcPicParams->bDisplayFormatSwizzle            = NeedDisapayFormatSwizzle(rtTbl->pCurrentRT, rtTbl->pCurrentReconTarget);
 
     // Correct Input color space of Sequence parameter here
@@ -688,6 +791,9 @@ VAStatus DdiEncodeHevc::ParsePicParams(
     RemoveFromStatusReportQueue(buf);
     DdiMedia_MediaBufferToMosResource(buf, &(m_encodeCtx->resBitstreamBuffer));
 
+    CodecDefEncodeHevcTrace::TraceDDI(*hevcPicParams);
+
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
     return VA_STATUS_SUCCESS;
 }
 
@@ -696,6 +802,7 @@ VAStatus DdiEncodeHevc::ParseSlcParams(
     void              *ptr,
     uint32_t          numSlices)
 {
+    API_STICKER_TRACE_ENTER();
     DDI_CHK_NULL(mediaCtx, "nullptr mediaCtx", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(ptr, "nullptr ptr", VA_STATUS_ERROR_INVALID_PARAMETER);
@@ -749,6 +856,10 @@ VAStatus DdiEncodeHevc::ParseSlcParams(
         hevcSlcParams->MaxNumMergeCand                     = vaEncSlcParamsHEVC->max_num_merge_cand;
         hevcSlcParams->luma_log2_weight_denom              = vaEncSlcParamsHEVC->luma_log2_weight_denom;
         hevcSlcParams->delta_chroma_log2_weight_denom      = vaEncSlcParamsHEVC->delta_chroma_log2_weight_denom;
+#if VA_CHECK_VERSION(1, 10, 0)
+        hevcSlcParams->PredWeightTableBitOffset            = vaEncSlcParamsHEVC->pred_weight_table_bit_offset;
+        hevcSlcParams->PredWeightTableBitLength            = vaEncSlcParamsHEVC->pred_weight_table_bit_length;
+#endif
         hevcSlcParams->slice_id                            = hevcPicParams->NumSlices + slcCount;
         hevcSlcParams->BitLengthSliceHeaderStartingPortion = 40;
 
@@ -827,12 +938,44 @@ VAStatus DdiEncodeHevc::ParseSlcParams(
             }
         }
 
+        CodecDefEncodeHevcTrace::TraceDDI(*hevcSlcParams);
+
         vaEncSlcParamsHEVC++;
     }
 
     hevcPicParams->NumSlices += numSlices;
     m_encodeCtx->dwNumSlices = hevcPicParams->NumSlices;
 
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
+    return VA_STATUS_SUCCESS;
+}
+
+VAStatus DdiEncodeHevc::Qmatrix(void *ptr)
+{
+    API_STICKER_TRACE_ENTER();
+    DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx", VA_STATUS_ERROR_INVALID_PARAMETER);
+    DDI_CHK_NULL(ptr, "nullptr ptr", VA_STATUS_ERROR_INVALID_PARAMETER);
+
+    PCODECHAL_HEVC_IQ_MATRIX_PARAMS QmatrixParams = (PCODECHAL_HEVC_IQ_MATRIX_PARAMS)(m_encodeCtx->pQmatrixParams);
+    DDI_CHK_NULL(QmatrixParams, "nullptr hevcPicParams", VA_STATUS_ERROR_INVALID_PARAMETER);
+
+    VAQMatrixBufferHEVC *vaQMatrixHEVC = (VAQMatrixBufferHEVC *)ptr;
+
+    MOS_SecureMemcpy((void *)&QmatrixParams->ucScalingLists0[0][0], sizeof(QmatrixParams->ucScalingLists0),
+        (void *)&vaQMatrixHEVC->scaling_lists_4x4[0][0][0], sizeof(vaQMatrixHEVC->scaling_lists_4x4));
+    MOS_SecureMemcpy((void *)&QmatrixParams->ucScalingLists1[0][0], sizeof(QmatrixParams->ucScalingLists1),
+        (void *)&vaQMatrixHEVC->scaling_lists_8x8[0][0][0], sizeof(vaQMatrixHEVC->scaling_lists_8x8));
+    MOS_SecureMemcpy((void *)&QmatrixParams->ucScalingLists2[0][0], sizeof(QmatrixParams->ucScalingLists2),
+        (void *)&vaQMatrixHEVC->scaling_lists_16x16[0][0][0], sizeof(vaQMatrixHEVC->scaling_lists_16x16));
+    MOS_SecureMemcpy((void *)&QmatrixParams->ucScalingLists3[0][0], sizeof(QmatrixParams->ucScalingLists3),
+        (void *)&vaQMatrixHEVC->scaling_lists_32x32[0][0], sizeof(vaQMatrixHEVC->scaling_lists_32x32));
+
+    MOS_SecureMemcpy((void *)&QmatrixParams->ucScalingListDCCoefSizeID2[0], sizeof(QmatrixParams->ucScalingListDCCoefSizeID2),
+        (void *)&vaQMatrixHEVC->scaling_list_dc_16x16[0][0], sizeof(QmatrixParams->ucScalingListDCCoefSizeID2));
+    MOS_SecureMemcpy((void *)&QmatrixParams->ucScalingListDCCoefSizeID3[0], sizeof(QmatrixParams->ucScalingListDCCoefSizeID3),
+        (void *)&vaQMatrixHEVC->scaling_list_dc_32x32[0], sizeof(QmatrixParams->ucScalingListDCCoefSizeID3));
+
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
     return VA_STATUS_SUCCESS;
 }
 
@@ -842,6 +985,7 @@ VAStatus DdiEncodeHevc::FindNalUnitStartCodes(
     uint32_t * startCodesOffset,
     uint32_t * startCodesLength)
 {
+    API_STICKER_TRACE_ENTER();
     uint8_t i = 0;
 
     while (((i + 3) < size) &&
@@ -876,11 +1020,13 @@ VAStatus DdiEncodeHevc::FindNalUnitStartCodes(
         *startCodesLength = 3;
     }
 
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
     return VA_STATUS_SUCCESS;
 }
 
 VAStatus DdiEncodeHevc::ParsePackedHeaderParams(void *ptr)
 {
+    API_STICKER_TRACE_ENTER();
     DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx.", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(ptr, "nullptr ptr.", VA_STATUS_ERROR_INVALID_PARAMETER);
 
@@ -913,11 +1059,13 @@ VAStatus DdiEncodeHevc::ParsePackedHeaderParams(void *ptr)
         m_encodeCtx->ppNALUnitParams[m_encodeCtx->indexNALUnit]->uiOffset                  = 0;
     }
 
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
     return VA_STATUS_SUCCESS;
 }
 
 VAStatus DdiEncodeHevc::ParsePackedHeaderData(void *ptr)
 {
+    API_STICKER_TRACE_ENTER();
     DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx.", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(ptr, "nullptr ptr.", VA_STATUS_ERROR_INVALID_PARAMETER);
 
@@ -1004,11 +1152,13 @@ VAStatus DdiEncodeHevc::ParsePackedHeaderData(void *ptr)
     bsBuffer->SliceOffset += hdrDataSize;
     bsBuffer->BitSize += hdrDataSize * 8;
 
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
     return VA_STATUS_SUCCESS;
 }
 
 VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
 {
+    API_STICKER_TRACE_ENTER();
     DDI_CHK_NULL(m_encodeCtx, "nullptr m_encodeCtx", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(ptr, "nullptr ptr", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(m_encodeCtx->pSeqParams, "nullptr m_encodeCtx->pSeqParams", VA_STATUS_ERROR_INVALID_PARAMETER);
@@ -1093,7 +1243,10 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
         // Assume only one SPS here, modify when enable multiple SPS support
         VAEncMiscParameterRateControl *vaEncMiscParamRC = (VAEncMiscParameterRateControl *)miscParamBuf->data;
 
-        seqParams->TargetBitRate = MOS_ROUNDUP_DIVIDE(vaEncMiscParamRC->bits_per_second, CODECHAL_ENCODE_BRC_KBPS);
+        if(vaEncMiscParamRC->bits_per_second > 0)
+        {
+            seqParams->TargetBitRate = MOS_ROUNDUP_DIVIDE(vaEncMiscParamRC->bits_per_second, CODECHAL_ENCODE_BRC_KBPS);
+        }
         seqParams->MBBRC         = (vaEncMiscParamRC->rc_flags.bits.mb_rate_control <= mbBrcDisabled) ? vaEncMiscParamRC->rc_flags.bits.mb_rate_control : 0;
         //enable parallelBRC for Android and Linux
         seqParams->ParallelBRC = vaEncMiscParamRC->rc_flags.bits.enable_parallel_brc;
@@ -1102,6 +1255,9 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
         {
             picParams->BRCMaxQp  = (vaEncMiscParamRC->max_qp == 0) ? 51 : (uint8_t)CodecHal_Clip3(1, 51, (int8_t)vaEncMiscParamRC->max_qp);
             picParams->BRCMinQp = (vaEncMiscParamRC->min_qp == 0) ? 1 : (uint8_t)CodecHal_Clip3(1, picParams->BRCMaxQp, (int8_t)vaEncMiscParamRC->min_qp);
+#if VA_CHECK_VERSION(1, 10, 0)
+            picParams->TargetFrameSize = vaEncMiscParamRC->target_frame_size;
+#endif
         }
         else
         {
@@ -1278,8 +1434,8 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
         VAEncMiscParameterBufferDirtyRect *vaEncMiscDirtyRect = (VAEncMiscParameterBufferDirtyRect *)miscParamBuf->data;
 
         uint8_t blockSize  = (m_encodeCtx->bVdencActive) ? vdencRoiBlockSize : CODECHAL_MACROBLOCK_WIDTH;
-        uint32_t frameWidth = (seqParams->wFrameWidthInMinCbMinus1 + 1) << (seqParams->log2_min_coding_block_size_minus3 + 3);
-        uint32_t frameHeight = (seqParams->wFrameHeightInMinCbMinus1 + 1) << (seqParams->log2_min_coding_block_size_minus3 + 3);
+        uint32_t rightBorder = CODECHAL_GET_WIDTH_IN_BLOCKS(m_encodeCtx->dwFrameWidth, blockSize) - 1;
+        uint32_t bottomBorder = CODECHAL_GET_HEIGHT_IN_BLOCKS(m_encodeCtx->dwFrameHeight, blockSize) - 1;
 
          DDI_CHK_NULL(vaEncMiscDirtyRect->roi_rectangle, "nullptr dirty rect", VA_STATUS_ERROR_INVALID_PARAMETER);
         if(vaEncMiscDirtyRect->num_roi_rectangle > ENCODE_VDENC_HEVC_MAX_DIRTYRECT_G10)
@@ -1311,21 +1467,10 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
             {
                 auto &rect    = picParams->pDirtyRect[i];
                 auto &va_rect = vaEncMiscDirtyRect->roi_rectangle[i];
-
-                // Check and adjust if rect not within frame boundaries
-                rect.Left   = MOS_MIN(va_rect.x, frameWidth - 1);
-                rect.Top    = MOS_MIN(va_rect.y, frameHeight - 1);
-                rect.Right  = MOS_MIN(va_rect.x + va_rect.width, frameWidth - 1);
-                rect.Bottom = MOS_MIN(va_rect.y + va_rect.height, frameHeight - 1);
-
-                if( rect.Left > rect.Right ||  rect.Top > rect.Bottom)
-                {
-                    DDI_ASSERTMESSAGE("Invalid rect region parameter.");
-                    return VA_STATUS_ERROR_INVALID_PARAMETER;
-                }
-
-                rect.Right  = MOS_ALIGN_CEIL(rect.Right, blockSize);
-                rect.Bottom = MOS_ALIGN_CEIL(rect.Bottom, blockSize);
+                rect.Left   = va_rect.x;
+                rect.Top    = va_rect.y;
+                rect.Right  = va_rect.x + va_rect.width - 1;
+                rect.Bottom = va_rect.y + va_rect.height - 1;
 
                 // Convert from pixel units to block units
                 rect.Left /= blockSize;
@@ -1333,6 +1478,16 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
                 rect.Top /= blockSize;
                 rect.Bottom /= blockSize;
 
+                // Check and adjust if rect not within frame boundaries
+                rect.Left = MOS_MIN(rect.Left, rightBorder);
+                rect.Right = MOS_MIN(rect.Right, rightBorder);
+                rect.Top = MOS_MIN(rect.Top, bottomBorder);
+                rect.Bottom = MOS_MIN(rect.Bottom, bottomBorder);
+                if (rect.Left > rect.Right || rect.Top > rect.Bottom)
+                {
+                    DDI_ASSERTMESSAGE("Invalid rect region parameter.");
+                    return VA_STATUS_ERROR_INVALID_PARAMETER;
+                }
                 picParams->NumDirtyRects ++;
             }
         }
@@ -1356,7 +1511,7 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
     {
         VAEncMiscParameterMaxSliceSize *vaEncMiscParamMaxSliceSize = (VAEncMiscParameterMaxSliceSize *)miscParamBuf->data;
         m_encodeCtx->EnableSliceLevelRateCtrl                      = true;
-        seqParams->SliceSizeControl                                = true;
+        seqParams->SliceSizeControl                                = (vaEncMiscParamMaxSliceSize->max_slice_size > 0) ? true : false;;
         picParams->MaxSliceSizeInBytes                             = vaEncMiscParamMaxSliceSize->max_slice_size;
         break;
     }
@@ -1378,6 +1533,7 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
         return VA_STATUS_ERROR_INVALID_PARAMETER;
     }
 
+    API_STICKER_TRACE_EXIT(VA_STATUS_SUCCESS);
     return VA_STATUS_SUCCESS;
 }
 
@@ -1426,6 +1582,7 @@ void DdiEncodeHevc::GetSlcRefIdx(CODEC_PICTURE *picReference, CODEC_PICTURE *slc
         if (numMaxRefFrame == i)
         {
             slcReference->FrameIdx = CODECHAL_NUM_UNCOMPRESSED_SURFACE_HEVC;
+            slcReference->PicFlags = PICTURE_INVALID;
             slcReference->PicEntry = 0xFF;
         }
     }
@@ -1497,4 +1654,4 @@ bool DdiEncodeHevc::IsSccProfile()
            || m_encodeCtx->vaProfile==VAProfileHEVCSccMain10
            || m_encodeCtx->vaProfile==VAProfileHEVCSccMain444
            || m_encodeCtx->vaProfile==VAProfileHEVCSccMain444_10);
-}
\ No newline at end of file
+}
