@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2018, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -272,6 +272,10 @@ MOS_STATUS OsContextSpecific::CreateIPC()
     m_semId = MOS_LINUX_IPC_INVALID_ID;
     m_shmId = MOS_LINUX_IPC_INVALID_ID;
     m_shm   = MOS_LINUX_SHM_INVALID;
+    if (m_apoMosEnabled)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
 
     struct semid_ds buf;
     MOS_ZeroMemory(&buf, sizeof(buf));
@@ -294,7 +298,7 @@ MOS_STATUS OsContextSpecific::CreateIPC()
             break;
         }
 
-        MOS_Sleep(1); //wait and retry
+        MosUtilities::MosSleep(1);  //wait and retry
     }
 
     LockSemaphore(m_semId);
@@ -308,6 +312,11 @@ finish:
 
 void OsContextSpecific::DestroyIPC()
 {
+    if (m_apoMosEnabled)
+    {
+        return;
+    }
+
     if (MOS_LINUX_IPC_INVALID_ID != m_semId)
     {
         int16_t iAttachedNum = 0;
@@ -337,12 +346,19 @@ MOS_STATUS OsContextSpecific::CreateSSEUIPC()
     m_sseuSemId = MOS_LINUX_IPC_INVALID_ID;
     m_sseuShmId = MOS_LINUX_IPC_INVALID_ID;
     m_sseuShm   = MOS_LINUX_SHM_INVALID;
-
+    if (m_apoMosEnabled)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
     return eStatus;
 }
 
 void OsContextSpecific::DestroySSEUIPC()
 {
+    if (m_apoMosEnabled)
+    {
+        return;
+    }
     if (MOS_LINUX_IPC_INVALID_ID != m_sseuSemId)
     {
         short iAttachedNum = 0;
@@ -373,6 +389,23 @@ void OsContextSpecific::SetSliceCount(uint32_t *pSliceCount)
 
 #endif //#ifndef ANDROID
 
+void OsContextSpecific::GetGpuPriority(int32_t* pPriority)
+{
+    uint64_t priority = 0;
+    mos_get_context_param(m_intelContext, 0, I915_CONTEXT_PARAM_PRIORITY, &priority);
+    *pPriority = (int32_t)priority;
+}
+
+void OsContextSpecific::SetGpuPriority(int32_t priority)
+{
+    int ret = 0;
+    ret = mos_set_context_param(m_intelContext, 0, I915_CONTEXT_PARAM_PRIORITY,(uint64_t)priority);
+    if (ret != 0)
+    {
+        MOS_OS_NORMALMESSAGE("Warning: failed to set the gpu priority, errno is %d", ret);
+    }
+}
+
 MOS_STATUS OsContextSpecific::Init(PMOS_CONTEXT pOsDriverContext)
 {
     uint32_t      iDeviceId = 0;
@@ -392,7 +425,7 @@ MOS_STATUS OsContextSpecific::Init(PMOS_CONTEXT pOsDriverContext)
             MOS_OS_ASSERT(false);
             return MOS_STATUS_INVALID_HANDLE;
         }
-    
+        m_apoMosEnabled = pOsDriverContext->m_apoMosEnabled;
         m_bufmgr        = pOsDriverContext->bufmgr;
         m_gpuContextMgr = static_cast<GpuContextMgr *>(pOsDriverContext->m_gpuContextMgr);
         m_cmdBufMgr     = static_cast<CmdBufMgr *>(pOsDriverContext->m_cmdBufMgr);
@@ -415,7 +448,7 @@ MOS_STATUS OsContextSpecific::Init(PMOS_CONTEXT pOsDriverContext)
             MOS_ZeroMemory(&skuTable, sizeof(skuTable));
             MOS_ZeroMemory(&waTable, sizeof(waTable));
             MOS_ZeroMemory(&gtSystemInfo, sizeof(gtSystemInfo));
-            eStatus = HWInfo_GetGfxInfo(pOsDriverContext->fd, &platformInfo, &skuTable, &waTable, &gtSystemInfo);
+            eStatus = HWInfo_GetGfxInfo(pOsDriverContext->fd, pOsDriverContext->bufmgr, &platformInfo, &skuTable, &waTable, &gtSystemInfo, pOsDriverContext->m_userSettingPtr);
             if (eStatus != MOS_STATUS_SUCCESS)
             {
                 MOS_OS_ASSERTMESSAGE("Fatal error - unsuccesfull Sku/Wa/GtSystemInfo initialization");
@@ -429,10 +462,10 @@ MOS_STATUS OsContextSpecific::Init(PMOS_CONTEXT pOsDriverContext)
             m_skuTable = skuTable;
             m_waTable  = waTable;
     
-            pOsDriverContext->SkuTable       = skuTable;
-            pOsDriverContext->WaTable        = waTable;
-            pOsDriverContext->gtSystemInfo   = gtSystemInfo;
-            pOsDriverContext->platform       = platformInfo;
+            pOsDriverContext->m_skuTable       = skuTable;
+            pOsDriverContext->m_waTable        = waTable;
+            pOsDriverContext->m_gtSystemInfo   = gtSystemInfo;
+            pOsDriverContext->m_platform       = platformInfo;
     
             MOS_OS_NORMALMESSAGE("DeviceID was created DeviceID = %d, platform product %d", iDeviceId, platformInfo.eProductFamily);
         }
@@ -440,20 +473,22 @@ MOS_STATUS OsContextSpecific::Init(PMOS_CONTEXT pOsDriverContext)
         {
             // pOsDriverContext's parameters were passed by CmCreateDevice.
             // Get SkuTable/WaTable/systemInfo/platform from OSDriver directly.
-            MOS_SecureMemcpy(&m_platformInfo, sizeof(PLATFORM), &(pOsDriverContext->platform), sizeof(PLATFORM));
-            MOS_SecureMemcpy(&m_gtSystemInfo, sizeof(MEDIA_SYSTEM_INFO), &(pOsDriverContext->gtSystemInfo), sizeof(MEDIA_SYSTEM_INFO));
+            MOS_SecureMemcpy(&m_platformInfo, sizeof(PLATFORM), &(pOsDriverContext->m_platform), sizeof(PLATFORM));
+            MOS_SecureMemcpy(&m_gtSystemInfo, sizeof(MEDIA_SYSTEM_INFO), &(pOsDriverContext->m_gtSystemInfo), sizeof(MEDIA_SYSTEM_INFO));
     
-            m_skuTable = pOsDriverContext->SkuTable;
-            m_waTable  = pOsDriverContext->WaTable;
+            m_skuTable = pOsDriverContext->m_skuTable;
+            m_waTable  = pOsDriverContext->m_waTable;
         }
 
         m_use64BitRelocs = true;
         m_useSwSwizzling = pOsDriverContext->bSimIsActive || MEDIA_IS_SKU(&m_skuTable, FtrUseSwSwizzling);
         m_tileYFlag      = MEDIA_IS_SKU(&m_skuTable, FtrTileY);
-    
-        if (!Mos_Solo_IsEnabled() && MEDIA_IS_SKU(&m_skuTable,FtrContextBasedScheduling))
+
+        MOS_TraceEventExt(EVENT_GPU_CONTEXT_CREATE, EVENT_TYPE_START,
+                          &eStatus, sizeof(eStatus), nullptr, 0);
+        if (!Mos_Solo_IsEnabled(nullptr) && MEDIA_IS_SKU(&m_skuTable,FtrContextBasedScheduling))
         {
-            m_intelContext = mos_gem_context_create_ext(pOsDriverContext->bufmgr,0);
+            m_intelContext = mos_gem_context_create_ext(pOsDriverContext->bufmgr,0, pOsDriverContext->m_protectedGEMContext);
             if (m_intelContext)
             {
                 m_intelContext->vm = mos_gem_vm_create(pOsDriverContext->bufmgr);
@@ -472,6 +507,9 @@ MOS_STATUS OsContextSpecific::Init(PMOS_CONTEXT pOsDriverContext)
                m_intelContext->vm = nullptr;
            }
         }
+        MOS_TraceEventExt(EVENT_GPU_CONTEXT_CREATE, EVENT_TYPE_END,
+                          &m_intelContext, sizeof(void *),
+                          &eStatus, sizeof(eStatus));
 
         if (m_intelContext == nullptr)
         {
@@ -501,7 +539,7 @@ MOS_STATUS OsContextSpecific::Init(PMOS_CONTEXT pOsDriverContext)
                 return eStatus;
             }
         }
-    
+
         eStatus = CreateSSEUIPC();
         if (eStatus != MOS_STATUS_SUCCESS)
         {
@@ -534,11 +572,7 @@ MOS_STATUS OsContextSpecific::Init(PMOS_CONTEXT pOsDriverContext)
         m_usesGfxAddress            = false;
     
         m_inlineCodecStatusUpdate   = true;
-    
-    #if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
-        CommandBufferDumpInit();
-    #endif
-    
+
         SetOsContextValid(true);
     }
     return eStatus;
@@ -551,7 +585,7 @@ void OsContextSpecific::Destroy()
     if (GetOsContextValid() == true)
     {
         // APO MOS will destory each stream's GPU context at different place
-        if (!g_apoMosEnabled)
+        if (!m_apoMosEnabled)
         {
             for (auto i = 0; i < MOS_GPU_CONTEXT_MAX; i++)
             {
@@ -582,6 +616,8 @@ void OsContextSpecific::Destroy()
      #endif
         m_skuTable.reset();
         m_waTable.reset();
+        MOS_TraceEventExt(EVENT_GPU_CONTEXT_DESTROY, EVENT_TYPE_START,
+                          &m_intelContext, sizeof(void *), nullptr, 0);
         if (m_intelContext && m_intelContext->vm)
         {
             mos_gem_vm_destroy(m_intelContext->bufmgr, m_intelContext->vm);
@@ -590,6 +626,8 @@ void OsContextSpecific::Destroy()
         {
             mos_gem_context_destroy(m_intelContext);
         }
+        MOS_TraceEventExt(EVENT_GPU_CONTEXT_DESTROY, EVENT_TYPE_END,
+                          nullptr, 0, nullptr, 0);
         SetOsContextValid(false);
     }
 }
