@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020, Intel Corporation
+* Copyright (c) 2020-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -59,7 +59,8 @@ static struct LinuxCodecInfo iclCodecInfo =
 
 static bool InitIclMediaSku(struct GfxDeviceInfo *devInfo,
                              MediaFeatureTable *skuTable,
-                             struct LinuxDriverInfo *drvInfo)
+                             struct LinuxDriverInfo *drvInfo,
+                             MediaUserSettingSharedPtr userSettingPtr)
 {
     if ((devInfo == nullptr) || (skuTable == nullptr) || (drvInfo == nullptr))
     {
@@ -190,6 +191,8 @@ static bool InitIclMediaSku(struct GfxDeviceInfo *devInfo,
 
     MEDIA_WR_SKU(skuTable, FtrUseSwSwizzling, 1);
 
+    MEDIA_WR_SKU(skuTable, FtrHDR, 1);
+
     return true;
 }
 
@@ -223,6 +226,8 @@ static bool InitIclMediaWa(struct GfxDeviceInfo *devInfo,
     /*software wa to prevent error propagation for vertical intra refresh on H264 VDEnc*/
     MEDIA_WR_WA(waTable, Wa_18011246551, 1);
 
+    MEDIA_WR_WA(waTable, WaDisableSetObjectCapture, 0);
+
     return true;
 }
 
@@ -264,7 +269,8 @@ static struct LinuxCodecInfo ehlCodecInfo =
 
 static bool InitEhlMediaSku(struct GfxDeviceInfo *devInfo,
                              MediaFeatureTable *skuTable,
-                             struct LinuxDriverInfo *drvInfo)
+                             struct LinuxDriverInfo *drvInfo,
+                             MediaUserSettingSharedPtr userSettingPtr)
 {
     if ((devInfo == nullptr) || (skuTable == nullptr) || (drvInfo == nullptr))
     {
