@@ -31,7 +31,7 @@
 #include "linux_media_skuwa.h"
 #include "mos_utilities.h"
 #include "mos_os_specific.h"
-#include "media_user_setting.h"
+#include "media_user_setting_specific.h"
 
 static constexpr uint32_t singleVeboxSubSliceNumMax = 24;
 
@@ -65,7 +65,8 @@ static struct LinuxCodecInfo tglCodecInfo =
 
 static bool InitTglMediaSku(struct GfxDeviceInfo *devInfo,
                              MediaFeatureTable *skuTable,
-                             struct LinuxDriverInfo *drvInfo)
+                             struct LinuxDriverInfo *drvInfo,
+                             MediaUserSettingSharedPtr userSettingPtr)
 {
     if ((devInfo == nullptr) || (skuTable == nullptr) || (drvInfo == nullptr))
     {
@@ -280,15 +281,17 @@ static bool InitTglMediaSku(struct GfxDeviceInfo *devInfo,
 
     bool compressibleSurfaceEnable = false;
 
-    ReadUserSetting(nullptr,
+    ReadUserSetting(userSettingPtr,
         compressibleSurfaceEnable,
         "Enable Compressible Surface Creation",
         MediaUserSetting::Group::Device);
-
+        
+#ifdef _MMC_SUPPORTED
     if (compressibleSurfaceEnable)
     {
         MEDIA_WR_SKU(skuTable, FtrCompressibleSurfaceDefault, 1);
     }
+#endif
 
     MEDIA_WR_SKU(skuTable, FtrHDR, 1);
 
@@ -361,16 +364,19 @@ static bool InitTglMediaWa(struct GfxDeviceInfo *devInfo,
     /*software wa to use huc copy for init aux table for MFX*/
     MEDIA_WR_WA(waTable, Wa_22010493002, 1);
 
+    MEDIA_WR_WA(waTable, Wa_Vp9UnalignedHeight, 1);
+    MEDIA_WR_WA(waTable, WaDisableSetObjectCapture, 0);
     return true;
 }
 
 
 #ifdef IGFX_GEN12_DG1_SUPPORTED
 static bool InitDG1MediaSku(struct GfxDeviceInfo *devInfo,
-                              MediaFeatureTable *skuTable,
-                           struct LinuxDriverInfo *drvInfo)
+                            MediaFeatureTable *skuTable,
+                            struct LinuxDriverInfo *drvInfo,
+                            MediaUserSettingSharedPtr userSettingPtr)
 {
-    if (!InitTglMediaSku(devInfo, skuTable, drvInfo))
+    if (!InitTglMediaSku(devInfo, skuTable, drvInfo, userSettingPtr))
     {
         return false;
     }
@@ -453,9 +459,10 @@ static bool dg1DeviceRegister = DeviceInfoFactory<LinuxDeviceInit>::
 #ifdef IGFX_GEN12_RKL_SUPPORTED
 static bool InitRKLMediaSku(struct GfxDeviceInfo *devInfo,
     MediaFeatureTable *                           skuTable,
-    struct LinuxDriverInfo *                      drvInfo)
+    struct LinuxDriverInfo                       *drvInfo,
+    MediaUserSettingSharedPtr                     userSettingPtr)
 {
-    if (!InitTglMediaSku(devInfo, skuTable, drvInfo))
+    if (!InitTglMediaSku(devInfo, skuTable, drvInfo, userSettingPtr))
     {
         return false;
     }
@@ -500,9 +507,10 @@ static bool rklDeviceRegister = DeviceInfoFactory<LinuxDeviceInit>::
 #ifdef IGFX_GEN12_ADLS_SUPPORTED
 static bool InitAdlsMediaSku(struct GfxDeviceInfo *devInfo,
                              MediaFeatureTable *skuTable,
-                             struct LinuxDriverInfo *drvInfo)
+                             struct LinuxDriverInfo *drvInfo,
+                             MediaUserSettingSharedPtr userSettingPtr)
 {
-    if (!InitTglMediaSku(devInfo, skuTable, drvInfo))
+    if (!InitTglMediaSku(devInfo, skuTable, drvInfo, userSettingPtr))
     {
         return false;
     }
@@ -519,6 +527,7 @@ static bool InitAdlsMediaSku(struct GfxDeviceInfo *devInfo,
 
     // Disable HEVC 422 Virtual Tile Scalability
     MEDIA_WR_SKU(skuTable, FtrDecodeHEVC422VTScalaDisable, 1);
+    MEDIA_WR_SKU(skuTable, FtrE2ECompression, 1);
 
     return true;
 }
@@ -535,6 +544,10 @@ static bool InitAdlsMediaWa(struct GfxDeviceInfo* devInfo,
     //ADL-S not need this
     MEDIA_WR_WA(waTable, Wa_1409820462, 0);
 
+    //ADL-S need enable MMC for all stepping
+    MEDIA_WR_WA(waTable, WaDisableCodecMmc, 0);
+    MEDIA_WR_WA(waTable, WaDisableVPMmc, 0);
+
     return true;
 }
 
@@ -553,9 +566,10 @@ static bool adlsDeviceRegister = DeviceInfoFactory<LinuxDeviceInit>::
 #ifdef IGFX_GEN12_ADLP_SUPPORTED
 static bool InitAdlpMediaSku(struct GfxDeviceInfo *devInfo,
     MediaFeatureTable *                            skuTable,
-    struct LinuxDriverInfo *                       drvInfo)
+    struct LinuxDriverInfo                        *drvInfo,
+    MediaUserSettingSharedPtr                      userSettingPtr)
 {
-    if (!InitTglMediaSku(devInfo, skuTable, drvInfo))
+    if (!InitTglMediaSku(devInfo, skuTable, drvInfo, userSettingPtr))
     {
         return false;
     }
@@ -601,9 +615,10 @@ static bool adlpDeviceRegister = DeviceInfoFactory<LinuxDeviceInit>::
 #ifdef IGFX_GEN12_ADLN_SUPPORTED
 static bool InitAdlnMediaSku(struct GfxDeviceInfo *devInfo,
     MediaFeatureTable *                            skuTable,
-    struct LinuxDriverInfo *                       drvInfo)
+    struct LinuxDriverInfo                        *drvInfo,
+    MediaUserSettingSharedPtr                      userSettingPtr)
 {
-    if (!InitTglMediaSku(devInfo, skuTable, drvInfo))
+    if (!InitTglMediaSku(devInfo, skuTable, drvInfo, userSettingPtr))
     {
         return false;
     }
@@ -616,6 +631,7 @@ static bool InitAdlnMediaSku(struct GfxDeviceInfo *devInfo,
     MEDIA_WR_SKU(skuTable, FtrAV1VLDLSTDecoding, 1);
     MEDIA_WR_SKU(skuTable, FtrGucSubmission, 1);
     MEDIA_WR_SKU(skuTable, FtrDecodeHEVC422VTScalaDisable, 1);
+    MEDIA_WR_SKU(skuTable, FtrE2ECompression, 1);
 
     return true;
 }
@@ -632,6 +648,10 @@ static bool InitAdlnMediaWa(struct GfxDeviceInfo *devInfo,
     //ADL-N keeps below setting same as ADL-S/ADL-P
     MEDIA_WR_WA(waTable, Wa_1409820462, 0);
 
+    //ADL-N need enable MMC for all stepping
+    MEDIA_WR_WA(waTable, WaDisableCodecMmc, 0);
+    MEDIA_WR_WA(waTable, WaDisableVPMmc, 0);
+
     return true;
 }
 
