@@ -27,7 +27,12 @@
 
 #include "media_blt_copy_xe_hpm.h"
 #include "mhw_cp_interface.h"
-#include "mos_os_specific_next.h"
+#include "media_copy.h"
+#include "mhw_mi.h"
+#include "mos_os.h"
+#include "mos_util_debug.h"
+#include "mos_utilities.h"
+class MhwInterfaces;
 
 //!
 //! \brief    BltState_Xe_Hpm constructor
@@ -143,7 +148,7 @@ MOS_STATUS BltState_Xe_Hpm::CopyProtectSurface(
     BLT_CHK_NULL_RETURN(m_miInterface);
     BLT_CHK_NULL_RETURN(m_cpInterface);
 
-    MOS_GPUCTX_CREATOPTIONS createOption;
+    MOS_GPUCTX_CREATOPTIONS_ENHANCED createOption = {};
     BLT_CHK_STATUS_RETURN(m_osInterface->pfnCreateGpuContext(
         m_osInterface,
         MOS_GPU_CONTEXT_VIDEO,
@@ -613,7 +618,8 @@ MOS_STATUS BltState_Xe_Hpm::SubmitCMD(
     MOS_COMMAND_BUFFER           cmdBuffer;
     MHW_FAST_COPY_BLT_PARAM      fastCopyBltParam;
     MHW_CTRL_SURF_COPY_BLT_PARAM ctrlSurfCopyBltParam;
-    MOS_GPUCTX_CREATOPTIONS      createOption = {};
+    MOS_GPUCTX_CREATOPTIONS_ENHANCED createOption = {};
+    int                          planeNum = 1;
     PMHW_BLT_INTERFACE_XE_HP     pbltInterface = dynamic_cast<PMHW_BLT_INTERFACE_XE_HP>(m_bltInterface);
 
     BLT_CHK_NULL(pbltInterface);
@@ -631,12 +637,29 @@ MOS_STATUS BltState_Xe_Hpm::SubmitCMD(
     MOS_ZeroMemory(&cmdBuffer, sizeof(MOS_COMMAND_BUFFER));
     BLT_CHK_STATUS_RETURN(m_osInterface->pfnGetCommandBuffer(m_osInterface, &cmdBuffer, 0));
 
+    MOS_SURFACE       srcResDetails;
+    MOS_SURFACE       dstResDetails;
+    MOS_ZeroMemory(&srcResDetails, sizeof(MOS_SURFACE));
+    MOS_ZeroMemory(&dstResDetails, sizeof(MOS_SURFACE));
+    srcResDetails.Format = Format_Invalid;
+    dstResDetails.Format = Format_Invalid;
+    BLT_CHK_STATUS_RETURN(m_osInterface->pfnGetResourceInfo(m_osInterface, pBltStateParam->pSrcSurface, &srcResDetails));
+    BLT_CHK_STATUS_RETURN(m_osInterface->pfnGetResourceInfo(m_osInterface, pBltStateParam->pDstSurface, &dstResDetails));
+
+    if (srcResDetails.Format != dstResDetails.Format)
+    {
+        MCPY_ASSERTMESSAGE("BLT copy can't support CSC copy. input format = %d, output format = %d", srcResDetails.Format, dstResDetails.Format);
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+    planeNum = GetPlaneNum(dstResDetails.Format);
+
     if (pBltStateParam->bCopyMainSurface)
     {
-        BLT_CHK_STATUS_RETURN(SetupFastCopyBltParam(
+        BLT_CHK_STATUS_RETURN(SetupBltCopyParam(
             &fastCopyBltParam,
             pBltStateParam->pSrcSurface,
-            pBltStateParam->pDstSurface));
+            pBltStateParam->pDstSurface,
+            0));
 
         MHW_MI_LOAD_REGISTER_IMM_PARAMS RegisterDwParams;
         MOS_ZeroMemory(&RegisterDwParams, sizeof(RegisterDwParams));
@@ -657,7 +680,42 @@ MOS_STATUS BltState_Xe_Hpm::SubmitCMD(
 
         BLT_CHK_STATUS_RETURN(m_bltInterface->AddFastCopyBlt(
             &cmdBuffer,
-            &fastCopyBltParam));
+            &fastCopyBltParam,
+            srcResDetails.YPlaneOffset.iSurfaceOffset,
+            dstResDetails.YPlaneOffset.iSurfaceOffset));
+
+        if (planeNum >= 2)
+        {
+            BLT_CHK_STATUS_RETURN(SetupBltCopyParam(
+             &fastCopyBltParam,
+             pBltStateParam->pSrcSurface,
+             pBltStateParam->pDstSurface,
+             1));
+            BLT_CHK_STATUS_RETURN(m_bltInterface->AddFastCopyBlt(
+                 &cmdBuffer,
+                 &fastCopyBltParam,
+                 srcResDetails.UPlaneOffset.iSurfaceOffset,
+                 dstResDetails.UPlaneOffset.iSurfaceOffset));
+
+              if (planeNum == 3)
+              {
+                  BLT_CHK_STATUS_RETURN(SetupBltCopyParam(
+                      &fastCopyBltParam,
+                      pBltStateParam->pSrcSurface,
+                      pBltStateParam->pDstSurface,
+                      2));
+                  BLT_CHK_STATUS_RETURN(m_bltInterface->AddFastCopyBlt(
+                      &cmdBuffer,
+                      &fastCopyBltParam,
+                      srcResDetails.VPlaneOffset.iSurfaceOffset,
+                      dstResDetails.VPlaneOffset.iSurfaceOffset));
+              }
+              else if (planeNum > 3)
+              {
+                  MCPY_ASSERTMESSAGE("illegal usage");
+                  return MOS_STATUS_INVALID_PARAMETER;
+              }
+         }
 
     }
 
