@@ -28,10 +28,27 @@
 //!
 
 #include "media_render_copy_xe_hpm.h"
+#include "hal_kerneldll.h"
+#include "hal_kerneldll_next.h"
+#include "media_common_defs.h"
+#include "media_copy.h"
+#include "mhw_render.h"
+#include "mhw_state_heap.h"
+#include "mos_defs_specific.h"
+#include "mos_os.h"
+#include "mos_resource_defs.h"
+#include "mos_utilities.h"
+#include "renderhal.h"
+#include "umKmInc/UmKmDmaPerfTimer.h"
+#include "vp_common.h"
+#include "vphal.h"
+#include "vphal_render_common.h"
+#include "vpkrnheader.h"
 #if defined(ENABLE_KERNELS) && !defined(_FULL_OPEN_SOURCE)
 #include "igvpkrn_xe_hpg.h"
 #endif
 
+class MhwInterfaces;
 RenderCopy_Xe_Hpm::RenderCopy_Xe_Hpm(PMOS_INTERFACE  osInterface, MhwInterfaces *mhwInterfaces):
     RenderCopyState(osInterface, mhwInterfaces)
 {
@@ -106,7 +123,7 @@ MOS_STATUS RenderCopy_Xe_Hpm::SubmitCMD( )
     PMHW_WALKER_PARAMS          pWalkerParams = nullptr;
     MHW_GPGPU_WALKER_PARAMS     ComputeWalkerParams = {0};
     PMHW_GPGPU_WALKER_PARAMS    pComputeWalkerParams = nullptr;
-    MOS_GPUCTX_CREATOPTIONS     createOption;
+    MOS_GPUCTX_CREATOPTIONS_ENHANCED createOption = {};
 
     pRenderHal   = pRenderCopy->m_renderHal;
     pOsInterface = pRenderCopy->m_osInterface;
@@ -117,6 +134,11 @@ MOS_STATUS RenderCopy_Xe_Hpm::SubmitCMD( )
         MOS_GPU_NODE_COMPUTE,
         &createOption));
 
+    // Register context with the Batch Buffer completion event
+    MCPY_CHK_STATUS_RETURN(m_osInterface->pfnRegisterBBCompleteNotifyEvent(
+        m_osInterface,
+        MOS_GPU_CONTEXT_COMPUTE));
+
     // Set GPU Context to Render Engine
     MCPY_CHK_STATUS_RETURN(pOsInterface->pfnSetGpuContext(pOsInterface, MOS_GPU_CONTEXT_COMPUTE));
 
@@ -356,3 +378,109 @@ MOS_STATUS RenderCopy_Xe_Hpm::SetupKernel(
 
     return eStatus;
 }
+
+//!
+ //! \brief    Render copy omputer walker setup
+ //! \details  Computer walker setup for render copy
+ //! \param    PMHW_WALKER_PARAMS pWalkerParams
+ //!           [in/out] Pointer to Walker params
+ //! \return   MOS_STATUS
+ //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+ //!
+ MOS_STATUS RenderCopy_Xe_Hpm::RenderCopyComputerWalker(
+ PMHW_GPGPU_WALKER_PARAMS    pWalkerParams)
+{
+    MOS_STATUS                              eStatus = MOS_STATUS_SUCCESS;
+    PMEDIACOPY_RENDER_DATA                  pRenderData = &m_RenderData;
+    RECT                                    AlignedRect;
+    int32_t                                 iBytePerPixelPerPlane = GetBytesPerPixelPerPlane(m_Target.Format);
+
+    MCPY_CHK_NULL_RETURN(pRenderData);
+
+
+    uint32_t   WalkerWidthBlockSize = 128;
+    uint32_t   WalkerHeightBlockSize = 8;
+
+    if ((iBytePerPixelPerPlane < 1) || (iBytePerPixelPerPlane > 8))
+    {
+        MCPY_ASSERTMESSAGE("RenderCopyComputerWalker wrong pixel size.");
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+
+    if ((m_Target.Format == Format_YUY2) || (m_Target.Format == Format_Y210) || (m_Target.Format == Format_Y216)
+        || (m_Target.Format == Format_AYUV) || (m_Target.Format == Format_Y410) || (m_Target.Format == Format_Y416)
+        || (m_Target.Format == Format_A8R8G8B8))
+    {
+        if ((m_currKernelId == KERNEL_CopyKernel_1D_to_2D_Packed) || (m_currKernelId == KERNEL_CopyKernel_2D_to_1D_Packed))
+        {
+            WalkerHeightBlockSize = 32;
+        }
+        else if (m_currKernelId == KERNEL_CopyKernel_2D_to_2D_Packed)
+        {
+            WalkerHeightBlockSize = 8;
+        }
+        else
+        {
+            MCPY_ASSERTMESSAGE("RenderCopyComputerWalker wrong kernel file.");
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+    }
+    else
+    {
+        WalkerHeightBlockSize = 8;
+    }
+
+    if ((m_currKernelId == KERNEL_CopyKernel_2D_to_1D_Packed) ||
+        (m_currKernelId == KERNEL_CopyKernel_2D_to_1D_NV12) ||
+        (m_currKernelId == KERNEL_CopyKernel_2D_to_1D_Planar))
+    {
+        WalkerWidthBlockSize = 16;
+    }
+    else
+    {
+        WalkerWidthBlockSize = 128;
+    }
+    // Set walker cmd params - Rasterscan
+    MOS_ZeroMemory(pWalkerParams, sizeof(*pWalkerParams));
+
+
+    AlignedRect.left   = 0;
+    AlignedRect.top    = 0;
+    AlignedRect.right  = (m_Source.dwPitch < m_Target.dwPitch) ? m_Source.dwPitch : m_Target.dwPitch;
+    AlignedRect.bottom = (m_Source.dwHeight < m_Target.dwHeight) ? m_Source.dwHeight : m_Target.dwHeight;
+    // Calculate aligned output area in order to determine the total # blocks
+   // to process in case of non-16x16 aligned target.
+    AlignedRect.right += WalkerWidthBlockSize - 1;
+    AlignedRect.bottom += WalkerHeightBlockSize - 1;
+    AlignedRect.left -= AlignedRect.left % WalkerWidthBlockSize;
+    AlignedRect.top -= AlignedRect.top % WalkerHeightBlockSize;
+    AlignedRect.right -= AlignedRect.right % WalkerWidthBlockSize;
+    AlignedRect.bottom -= AlignedRect.bottom % WalkerHeightBlockSize;
+
+    pWalkerParams->InterfaceDescriptorOffset = pRenderData->iMediaID;
+
+    pWalkerParams->GroupStartingX = (AlignedRect.left / WalkerWidthBlockSize);
+    pWalkerParams->GroupStartingY = (AlignedRect.top / WalkerHeightBlockSize);
+
+    // Set number of blocks
+    pRenderData->iBlocksX =
+        ((AlignedRect.right - AlignedRect.left) + WalkerWidthBlockSize - 1) / WalkerWidthBlockSize;
+    pRenderData->iBlocksY =
+        ((AlignedRect.bottom - AlignedRect.top) + WalkerHeightBlockSize -1)/ WalkerHeightBlockSize;
+
+    // Set number of blocks, block size is WalkerWidthBlockSize x WalkerHeightBlockSize.
+    pWalkerParams->GroupWidth = pRenderData->iBlocksX;
+    pWalkerParams->GroupHeight = pRenderData->iBlocksY; // hight/WalkerWidthBlockSize
+
+    pWalkerParams->ThreadWidth = 1;
+    pWalkerParams->ThreadHeight = 1;
+    pWalkerParams->ThreadDepth = 1;
+    pWalkerParams->IndirectDataStartAddress = pRenderData->iCurbeOffset;
+    // Indirect Data Length is a multiple of 64 bytes (size of L3 cacheline). Bits [5:0] are zero.
+    pWalkerParams->IndirectDataLength = MOS_ALIGN_CEIL(pRenderData->iCurbeLength, 1 << MHW_COMPUTE_INDIRECT_SHIFT);
+    pWalkerParams->BindingTableID = pRenderData->iBindingTable;
+    MCPY_NORMALMESSAGE("this = % p, WidthBlockSize %d, HeightBlockSize %d, Widththreads %d, Heightthreads %d",
+        this, WalkerWidthBlockSize, WalkerHeightBlockSize, pWalkerParams->GroupWidth, pWalkerParams->GroupHeight);
+
+    return eStatus;
+}
\ No newline at end of file
