@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2021, Intel Corporation
+* Copyright (c) 2019-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -388,9 +388,19 @@ MOS_STATUS HevcDecodePicPktXe_M_Base::SetHcpRefSurfaceParams(
 #ifdef _MMC_SUPPORTED
     HevcDecodeMemComp *hevcDecodeMemComp = dynamic_cast<HevcDecodeMemComp *>(m_mmcState);
     DECODE_CHK_NULL(hevcDecodeMemComp);
-    DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcState(refSurfaceParams.psSurface, &refSurfaceParams.mmcState));
-    DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcFormat(refSurfaceParams.psSurface, &refSurfaceParams.dwCompressionFormat));
-    DECODE_CHK_STATUS(hevcDecodeMemComp->SetRefSurfaceMask(*m_hevcBasicFeature, pipeBufAddrParams, refSurfaceParams));
+    // Set refSurfaceParams mmcState as MOS_MEMCOMP_MC to satisfy MmcEnable in AddHcpSurfaceCmd
+    // The actual mmcstate is recorded by refSurfaceParams.mmcSkipMask
+    if (m_mmcState->IsMmcEnabled())
+    {
+        refSurfaceParams.mmcState = MOS_MEMCOMP_MC;
+        DECODE_CHK_STATUS(hevcDecodeMemComp->SetRefSurfaceMask(*m_hevcBasicFeature, pipeBufAddrParams.presReferences, refSurfaceParams.mmcSkipMask));
+        DECODE_CHK_STATUS(hevcDecodeMemComp->SetRefSurfaceCompressionFormat(*m_hevcBasicFeature, pipeBufAddrParams.presReferences, refSurfaceParams.dwCompressionFormat));
+    }
+    else
+    {
+        refSurfaceParams.mmcState            = MOS_MEMCOMP_DISABLED;
+        refSurfaceParams.dwCompressionFormat = 0;
+    }
 #endif
 
     return MOS_STATUS_SUCCESS;
@@ -574,7 +584,12 @@ MOS_STATUS HevcDecodePicPktXe_M_Base::SetHcpPipeBufAddrParams(MHW_VDBOX_PIPE_BUF
         })
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    if (MOS_GetTraceEventKeyword() & EVENT_DECODE_REFYUV_KEYWORD)
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_MV))
+    {
+        TraceDataDumpMV(pipeBufAddrParams);
+    }
+    
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_REFYUV))
     {
         TraceDataDumpReferences(pipeBufAddrParams);
     }
@@ -584,16 +599,58 @@ MOS_STATUS HevcDecodePicPktXe_M_Base::SetHcpPipeBufAddrParams(MHW_VDBOX_PIPE_BUF
 }
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-MOS_STATUS HevcDecodePicPktXe_M_Base::TraceDataDumpReferences(MHW_VDBOX_PIPE_BUF_ADDR_PARAMS &pipeBufAddrParams)
+MOS_STATUS HevcDecodePicPktXe_M_Base::TraceDataDumpMV(MHW_VDBOX_PIPE_BUF_ADDR_PARAMS &pipeBufAddrParams)
 {
-    bool        bReport     = false;
     auto        mvBuffers   = &(m_hevcBasicFeature->m_mvBuffers);
     PMOS_BUFFER curMvBuffer = mvBuffers->GetCurBuffer();
     DECODE_CHK_NULL(curMvBuffer);
 
     for (uint32_t n = 0; n < CODECHAL_MAX_CUR_NUM_REF_FRAME_HEVC; n++)
     {
-        if (pipeBufAddrParams.presReferences[n] != nullptr)
+        if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presReferences[n]))
+        {
+            if (pipeBufAddrParams.presColMvTempBuffer[n] != nullptr)
+            {
+                ResourceAutoLock resLock(m_allocator, pipeBufAddrParams.presColMvTempBuffer[n]);
+                auto             pData = (uint8_t *)resLock.LockResourceForRead();
+                DECODE_CHK_NULL(pData);
+
+                MOS_TraceDataDump(
+                    "Decode_HevcColMvTempBuffer",
+                    n,
+                    pData,
+                    curMvBuffer->size);
+                
+                m_allocator->UnLock(pipeBufAddrParams.presColMvTempBuffer[n]);
+            }
+        }
+    }
+
+    if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presCurMvTempBuffer))
+    {
+        ResourceAutoLock resLock(m_allocator, pipeBufAddrParams.presCurMvTempBuffer);
+        auto             pData = (uint8_t *)resLock.LockResourceForRead();
+        DECODE_CHK_NULL(pData);
+
+        MOS_TraceDataDump(
+                    "Decode_HevcCurMvTempBuffer",
+                    0,
+                    pData,
+                    curMvBuffer->size);
+        
+        m_allocator->UnLock(pipeBufAddrParams.presCurMvTempBuffer);
+    }
+    
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS HevcDecodePicPktXe_M_Base::TraceDataDumpReferences(MHW_VDBOX_PIPE_BUF_ADDR_PARAMS &pipeBufAddrParams)
+{
+    bool        bReport     = false;
+
+    for (uint32_t n = 0; n < CODECHAL_MAX_CUR_NUM_REF_FRAME_HEVC; n++)
+    {
+        if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presReferences[n]))
         {
             bool        bAllocate = false;
             MOS_SURFACE dstSurface;
@@ -601,27 +658,6 @@ MOS_STATUS HevcDecodePicPktXe_M_Base::TraceDataDumpReferences(MHW_VDBOX_PIPE_BUF
             dstSurface.OsResource = *(pipeBufAddrParams.presReferences[n]);
             DECODE_CHK_STATUS(m_allocator->GetSurfaceInfo(&dstSurface));
 
-            if (bReport)
-            {
-                DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
-                    {
-                        PICTURE_FRAME,
-                        dstSurface.dwOffset,
-                        dstSurface.YPlaneOffset.iYOffset,
-                        dstSurface.dwPitch,
-                        dstSurface.dwWidth,
-                        dstSurface.dwHeight,
-                        (uint32_t)dstSurface.Format,
-                        dstSurface.UPlaneOffset.iLockSurfaceOffset,
-                        dstSurface.VPlaneOffset.iLockSurfaceOffset,
-                        dstSurface.UPlaneOffset.iSurfaceOffset,
-                        dstSurface.VPlaneOffset.iSurfaceOffset,
-                    };
-                MOS_TraceEvent(EVENT_DECODE_SURFACE_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-
-                bReport = true;
-            }
-
             if (!m_allocator->ResourceIsNull(&dstSurface.OsResource))
             {
                 if (m_tempRefSurf == nullptr || m_allocator->ResourceIsNull(&m_tempRefSurf->OsResource))
@@ -662,37 +698,42 @@ MOS_STATUS HevcDecodePicPktXe_M_Base::TraceDataDumpReferences(MHW_VDBOX_PIPE_BUF
                     &m_tempRefSurf->OsResource,
                     false));
 
+                if (!bReport)
+                {
+                    DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
+                    {
+                        PICTURE_FRAME,
+                        0,
+                        m_tempRefSurf->dwOffset,
+                        m_tempRefSurf->YPlaneOffset.iYOffset,
+                        m_tempRefSurf->dwPitch,
+                        m_tempRefSurf->dwWidth,
+                        m_tempRefSurf->dwHeight,
+                        (uint32_t)m_tempRefSurf->Format,
+                        m_tempRefSurf->UPlaneOffset.iLockSurfaceOffset,
+                        m_tempRefSurf->VPlaneOffset.iLockSurfaceOffset,
+                        m_tempRefSurf->UPlaneOffset.iSurfaceOffset,
+                        m_tempRefSurf->VPlaneOffset.iSurfaceOffset,
+                    };
+                    MOS_TraceEvent(EVENT_DECODE_DUMPINFO_REF, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+
+                    bReport = true;
+                }
+
                 ResourceAutoLock resLock(m_allocator, &m_tempRefSurf->OsResource);
                 auto             pData = (uint8_t *)resLock.LockResourceForRead();
+                DECODE_CHK_NULL(pData);
 
                 MOS_TraceDataDump(
                     "Decode_HEVCRefSurf",
                     n,
                     pData,
                     (uint32_t)m_tempRefSurf->OsResource.pGmmResInfo->GetSizeMainSurface());
-            }
-
-            if (pipeBufAddrParams.presColMvTempBuffer[n] != nullptr)
-            {
-                m_osInterface->pfnDumpTraceGpuData(
-                    m_osInterface,
-                    "Decode_HevcColMvTempBuffer",
-                    n,
-                    pipeBufAddrParams.presColMvTempBuffer[n],
-                    curMvBuffer->size);
+                
+                m_allocator->UnLock(&m_tempRefSurf->OsResource);
             }
         }
     }
-
-    if (pipeBufAddrParams.presCurMvTempBuffer != nullptr)
-    {
-        m_osInterface->pfnDumpTraceGpuData(
-            m_osInterface,
-            "Decode_HevcCurMvTempBuffer",
-            0,
-            pipeBufAddrParams.presCurMvTempBuffer,
-            curMvBuffer->size);
-    }
     
     return MOS_STATUS_SUCCESS;
 }
