@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2021, Intel Corporation
+* Copyright (c) 2018-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -30,16 +30,23 @@
 #include "decode_hevc_packet_real_tile_m12.h"
 #include "decode_hevc_picture_packet_m12.h"
 #include "decode_hevc_slice_packet_m12.h"
-#include "media_user_settings_mgr_g12.h"
 #include "decode_utils.h"
 #include "decode_common_feature_defs.h"
 #include "decode_hevc_mem_compression_m12.h"
+#include "decode_sfc_histogram_postsubpipeline_m12.h"
+#include "decode_hevc_feature_manager.h"
+#include "decode_input_bitstream_m12.h"
+#include "decode_cp_bitstream_m12.h"
+#include "decode_hevc_downsampling_packet.h"
+#include "decode_marker_packet_g12.h"
+#include "decode_predication_packet_g12.h"
 
 namespace decode {
 
 HevcPipelineM12::HevcPipelineM12(CodechalHwInterface *hwInterface, CodechalDebugInterface *debugInterface)
-    : HevcPipeline(hwInterface, debugInterface)
+    : HevcPipeline(*hwInterface, debugInterface)
 {
+    m_hwInterface = hwInterface;
 }
 
 MOS_STATUS HevcPipelineM12::Init(void *settings)
@@ -49,7 +56,7 @@ MOS_STATUS HevcPipelineM12::Init(void *settings)
 
     DECODE_CHK_STATUS(Initialize(settings));
 
-    if (m_shortFormatInUse)
+    if (m_basicFeature->m_shortFormatInUse)
     {
         HucS2lPktM12 *hucS2lPkt = MOS_New(HucS2lPktM12, this, m_task, m_hwInterface);
         DECODE_CHK_NULL(hucS2lPkt);
@@ -77,9 +84,78 @@ MOS_STATUS HevcPipelineM12::Init(void *settings)
     DECODE_CHK_STATUS(RegisterPacket(DecodePacketId(this, hevcRealTilePacketId), hevcDecodePktRealTile));
     DECODE_CHK_STATUS(hevcDecodePktRealTile->Init());
 
+    if (m_numVdbox == 2)
+    {
+        m_allowVirtualNodeReassign = true;
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS HevcPipelineM12::InitContexOption(HevcScalabilityPars &scalPars)
+{
+    scalPars.usingHcp           = true;
+    scalPars.enableVE           = MOS_VE_SUPPORTED(m_osInterface);
+    scalPars.disableScalability = m_hwInterface->IsDisableScalability();
+    if (m_osInterface->pfnIsMultipleCodecDevicesInUse(m_osInterface))
+    {
+        scalPars.disableScalability = true;
+    }
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if (m_osInterface->bHcpDecScalabilityMode == MOS_SCALABILITY_ENABLE_MODE_FALSE)
+    {
+        scalPars.disableScalability = true;
+    }
+    else if (m_osInterface->bHcpDecScalabilityMode == MOS_SCALABILITY_ENABLE_MODE_USER_FORCE)
+    {
+        scalPars.disableScalability = false;
+    }
+    scalPars.modeSwithThreshold1 =
+        ReadUserFeature(m_userSettingPtr, "HCP Decode Mode Switch TH1", MediaUserSetting::Group::Sequence).Get<uint32_t>();
+    scalPars.modeSwithThreshold2 =
+        ReadUserFeature(m_userSettingPtr, "HCP Decode Mode Switch TH2", MediaUserSetting::Group::Sequence).Get<uint32_t>();
+    scalPars.forceMultiPipe =
+        ReadUserFeature(m_userSettingPtr, "HCP Decode Always Frame Split", MediaUserSetting::Group::Sequence).Get<bool>();
+#endif
+    return MOS_STATUS_SUCCESS;
+}
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+MOS_STATUS HevcPipelineM12::HwStatusCheck(const DecodeStatusMfx &status)
+{
+    DECODE_FUNC_CALL();
+
+    if (m_basicFeature->m_shortFormatInUse)
+    {
+        // Check HuC_status2 Imem loaded bit, if 0, return error
+        if (((status.m_hucErrorStatus2 >> 32) && (m_hwInterface->GetHucInterface()->GetHucStatus2ImemLoadedMask())) == 0)
+        {
+            if (!m_reportHucStatus)
+            {
+                WriteUserFeature(__MEDIA_USER_FEATURE_VALUE_HUC_LOAD_STATUS_ID, 1, m_osInterface->pOsContext);
+                m_reportHucStatus = true;
+            }
+            DECODE_ASSERTMESSAGE("Huc IMEM Loaded fails");
+            MT_ERR1(MT_DEC_HEVC, MT_DEC_HUC_ERROR_STATUS2, (status.m_hucErrorStatus2 >> 32));
+        }
+
+        // Check Huc_status None Critical Error bit, bit 15. If 0, return error.
+        if (((status.m_hucErrorStatus >> 32) & m_hwInterface->GetHucInterface()->GetHucStatusHevcS2lFailureMask()) == 0)
+        {
+            if (!m_reportHucCriticalError)
+            {
+                WriteUserFeature(__MEDIA_USER_FEATURE_VALUE_HUC_REPORT_CRITICAL_ERROR_ID, 1, m_osInterface->pOsContext);
+                m_reportHucCriticalError = true;
+            }
+            DECODE_ASSERTMESSAGE("Huc Report Critical Error!");
+            MT_ERR1(MT_DEC_HEVC, MT_DEC_HUC_STATUS_CRITICAL_ERROR, (status.m_hucErrorStatus >> 32));
+        }
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+#endif
+
 MOS_STATUS HevcPipelineM12::InitScalabOption(HevcBasicFeature &basicFeature)
 {
     DECODE_FUNC_CALL();
@@ -112,25 +188,28 @@ MOS_STATUS HevcPipelineM12::InitScalabOption(HevcBasicFeature &basicFeature)
     scalPars.maxTileRow    = HEVC_NUM_MAX_TILE_ROW;
 #if (_DEBUG || _RELEASE_INTERNAL)
     scalPars.disableRealTile =
-        ReadUserFeature(__MEDIA_USER_FEATURE_VALUE_DISABLE_HEVC_REALTILE_DECODE_ID, m_osInterface->pOsContext).u32Data ?
-        true : false;
-
+        ReadUserFeature(m_userSettingPtr, "Disable HEVC Real Tile Decode", MediaUserSetting::Group::Sequence).Get<bool>();
     bool enableRealTileMultiPhase =
-        ReadUserFeature(__MEDIA_USER_FEATURE_VALUE_ENABLE_HEVC_REALTILE_MULTI_PHASE_DECODE_ID, m_osInterface->pOsContext).u32Data ?
-        true : false;
-    if (!enableRealTileMultiPhase)
+        ReadUserFeature(m_userSettingPtr, "Enable HEVC Real Tile Multi Phase Decode", MediaUserSetting::Group::Sequence).Get<bool>();
+        if (!enableRealTileMultiPhase)
     {
         scalPars.maxTileColumn = 2;
     }
 
     scalPars.userPipeNum =
-        uint8_t(ReadUserFeature(__MEDIA_USER_FEATURE_VALUE_HCP_DECODE_USER_PIPE_NUM_ID, m_osInterface->pOsContext).u32Data);
+        uint8_t(ReadUserFeature(m_userSettingPtr, "HCP Decode User Pipe Num", MediaUserSetting::Group::Sequence).Get<uint32_t>());
 #endif
     // Long format real tile requires subset params
-    if (!m_shortFormatInUse && basicFeature.m_hevcSubsetParams == nullptr)
+    if (!basicFeature.m_shortFormatInUse && basicFeature.m_hevcSubsetParams == nullptr)
     {
         scalPars.disableRealTile = true;
     }
+
+    if (MEDIA_IS_SKU(m_skuTable, FtrVirtualTileScalabilityDisable))
+    {
+        scalPars.disableVirtualTile = true;
+    }
+
     scalPars.surfaceFormat  = basicFeature.m_destSurface.Format;
     scalPars.frameWidth     = basicFeature.m_width;
     scalPars.frameHeight    = basicFeature.m_height;
@@ -140,6 +219,17 @@ MOS_STATUS HevcPipelineM12::InitScalabOption(HevcBasicFeature &basicFeature)
     scalPars.numTileColumns = picParams->tiles_enabled_flag ?
                                 (picParams->num_tile_columns_minus1 + 1) : 0;
 
+    // HEVC 422 8b/10b && <8k - disable virtual tile sclability
+    if (MEDIA_IS_SKU(m_skuTable, FtrDecodeHEVC422VTScalaDisable))
+    {
+        if ((scalPars.surfaceFormat == Format_YUY2 || scalPars.surfaceFormat == Format_Y210) &&
+            ((scalPars.frameWidth * scalPars.frameHeight) < (7680 * 4320)))
+        {
+            scalPars.disableVirtualTile = true;
+            SCALABILITY_VERBOSEMESSAGE("HEVC 422 && Resolution < 8k - Disable VT Scalability ");
+        }
+    }
+
     DECODE_CHK_STATUS(m_scalabOption.SetScalabilityOption(&scalPars));
 
     return MOS_STATUS_SUCCESS;
@@ -182,7 +272,7 @@ MOS_STATUS HevcPipelineM12::AllocateResources(HevcBasicFeature &basicFeature)
     if (m_secondLevelBBArray == nullptr)
     {
         m_secondLevelBBArray = m_allocator->AllocateBatchBufferArray(
-            size, count, m_secondLevelBBNum, true, m_shortFormatInUse ? notLockableVideoMem : lockableVideoMem);
+            size, count, m_secondLevelBBNum, true, basicFeature.m_shortFormatInUse ? notLockableVideoMem : lockableVideoMem);
         DECODE_CHK_NULL(m_secondLevelBBArray);
         PMHW_BATCH_BUFFER &batchBuf = m_secondLevelBBArray->Fetch();
         DECODE_CHK_NULL(batchBuf);
@@ -192,7 +282,7 @@ MOS_STATUS HevcPipelineM12::AllocateResources(HevcBasicFeature &basicFeature)
         PMHW_BATCH_BUFFER &batchBuf = m_secondLevelBBArray->Fetch();
         DECODE_CHK_NULL(batchBuf);
         DECODE_CHK_STATUS(m_allocator->Resize(
-            batchBuf, size, count, m_shortFormatInUse ? notLockableVideoMem : lockableVideoMem));
+            batchBuf, size, count, basicFeature.m_shortFormatInUse ? notLockableVideoMem : lockableVideoMem));
     }
 
     return MOS_STATUS_SUCCESS;
@@ -211,6 +301,7 @@ MOS_STATUS HevcPipelineM12::Prepare(void *params)
     if (IsFirstProcessPipe(*pipelineParams))
     {
         DECODE_CHK_STATUS(HevcPipeline::Prepare(params));
+        DECODE_CHK_STATUS(HevcPipeline::DestoryPhaseList());
     }
 
     DECODE_CHK_STATUS(m_preSubPipeline->Prepare(*pipelineParams));
@@ -220,6 +311,18 @@ MOS_STATUS HevcPipelineM12::Prepare(void *params)
     {
         if (IsCompleteBitstream())
         {
+            if (m_pCodechalOcaDumper)
+            {
+                m_pCodechalOcaDumper->SetHevcDecodeParam(
+                    m_basicFeature->m_hevcPicParams,
+                    m_basicFeature->m_hevcRextPicParams,
+                    m_basicFeature->m_hevcSccPicParams,
+                    m_basicFeature->m_hevcSliceParams,
+                    m_basicFeature->m_hevcRextSliceParams,
+                    m_basicFeature->m_numSlices,
+                    m_basicFeature->m_shortFormatInUse);
+            }
+
             CODECHAL_DEBUG_TOOL(
                 m_debugInterface->m_bufferDumpFrameNum = m_basicFeature->m_frameNum;
                 DECODE_CHK_STATUS(DumpParams(*m_basicFeature))
@@ -291,7 +394,7 @@ MOS_STATUS HevcPipelineM12::Execute()
             CODECHAL_DEBUG_TOOL(DECODE_CHK_STATUS(DumpSecondLevelBatchBuffer()));
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-            if (MOS_GetTraceEventKeyword() & EVENT_DECODE_COMMAND_KEYWORD)
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_COMMAND))
             {
                 TraceDataDump2ndLevelBB(GetSliceLvlCmdBuffer());
             }
@@ -331,10 +434,78 @@ MOS_STATUS HevcPipelineM12::Destroy()
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS HevcPipelineM12::CreateFeatureManager()
+{
+    DECODE_FUNC_CALL();
+    m_featureManager = MOS_New(DecodeHevcFeatureManager, m_allocator, m_hwInterface, m_osInterface);
+    DECODE_CHK_NULL(m_featureManager);
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS HevcPipelineM12::Initialize(void *settings)
 {
     DECODE_FUNC_CALL();
-    DECODE_CHK_STATUS(HevcPipeline::Initialize(settings));
+
+    DECODE_CHK_NULL(settings);
+
+    DECODE_CHK_STATUS(MediaPipeline::InitPlatform());
+    DECODE_CHK_STATUS(MediaPipeline::CreateMediaCopyWrapper());
+    DECODE_CHK_NULL(m_mediaCopyWrapper);
+    m_mediaCopyWrapper->CreateMediaCopyState();
+
+    DECODE_CHK_NULL(m_waTable);
+
+    auto *codecSettings = (CodechalSetting *)settings;
+    DECODE_CHK_NULL(m_hwInterface);
+    DECODE_CHK_STATUS(m_hwInterface->Initialize(codecSettings));
+
+    if (m_mediaCopyWrapper->MediaCopyStateIsNull())
+    {
+        m_mediaCopyWrapper->SetMediaCopyState(m_hwInterface->CreateMediaCopy(m_osInterface));
+    }
+
+#if USE_CODECHAL_DEBUG_TOOL
+    DECODE_CHK_NULL(m_debugInterface);
+    DECODE_CHK_STATUS(m_debugInterface->SetFastDumpConfig(m_mediaCopyWrapper->GetMediaCopyState()));
+#endif
+    if (m_hwInterface->m_hwInterfaceNext)
+    {
+        m_hwInterface->m_hwInterfaceNext->legacyHwInterface = m_hwInterface;
+    }
+    m_mediaContext = MOS_New(MediaContext, scalabilityDecoder, m_hwInterface->m_hwInterfaceNext, m_osInterface);
+    DECODE_CHK_NULL(m_mediaContext);
+
+    m_task = CreateTask(MediaTask::TaskType::cmdTask);
+    DECODE_CHK_NULL(m_task);
+
+    m_numVdbox = GetSystemVdboxNumber();
+
+    bool limitedLMemBar = MEDIA_IS_SKU(m_skuTable, FtrLimitedLMemBar) ? true : false;
+    m_allocator         = MOS_New(DecodeAllocator, m_osInterface, limitedLMemBar);
+    DECODE_CHK_NULL(m_allocator);
+
+    DECODE_CHK_STATUS(CreateStatusReport());
+
+    m_decodecp = Create_DecodeCpInterface(codecSettings, m_hwInterface->GetCpInterface(), m_hwInterface->GetOsInterface());
+    if (m_decodecp)
+    {
+        m_decodecp->RegisterParams(codecSettings);
+    }
+    DECODE_CHK_STATUS(CreateFeatureManager());
+    DECODE_CHK_STATUS(m_featureManager->Init(codecSettings));
+
+    DECODE_CHK_STATUS(CreateSubPipeLineManager(codecSettings));
+    DECODE_CHK_STATUS(CreateSubPacketManager(codecSettings));
+
+    // Create basic GPU context
+    DecodeScalabilityPars scalPars;
+    MOS_ZeroMemory(&scalPars, sizeof(scalPars));
+    DECODE_CHK_STATUS(m_mediaContext->SwitchContext(VdboxDecodeFunc, &scalPars, &m_scalability));
+    m_decodeContext = m_osInterface->pfnGetGpuContext(m_osInterface);
+
+    m_basicFeature = dynamic_cast<HevcBasicFeature *>(m_featureManager->GetFeature(FeatureIDs::basicFeature));
+    DECODE_CHK_NULL(m_basicFeature);
+
 #ifdef _MMC_SUPPORTED
     DECODE_CHK_STATUS(InitMmcState());
 #endif
@@ -405,7 +576,22 @@ uint32_t HevcPipelineM12::GetCompletedReport()
 
 MOS_STATUS HevcPipelineM12::CreateSubPackets(DecodeSubPacketManager& subPacketManager, CodechalSetting &codecSettings)
 {
-    DECODE_CHK_STATUS(HevcPipeline::CreateSubPackets(subPacketManager, codecSettings));
+    DecodePredicationPktG12 *predicationPkt = MOS_New(DecodePredicationPktG12, this, m_hwInterface);
+    DECODE_CHK_NULL(predicationPkt);
+    DECODE_CHK_STATUS(subPacketManager.Register(
+        DecodePacketId(this, predicationSubPacketId), *predicationPkt));
+
+    DecodeMarkerPktG12 *markerPkt = MOS_New(DecodeMarkerPktG12, this, m_hwInterface);
+    DECODE_CHK_NULL(markerPkt);
+    DECODE_CHK_STATUS(subPacketManager.Register(
+        DecodePacketId(this, markerSubPacketId), *markerPkt));
+    
+#ifdef _DECODE_PROCESSING_SUPPORTED
+    HevcDownSamplingPkt *downSamplingPkt = MOS_New(HevcDownSamplingPkt, this, *m_hwInterface);
+    DECODE_CHK_NULL(downSamplingPkt);
+    DECODE_CHK_STATUS(subPacketManager.Register(
+        DecodePacketId(this, downSamplingSubPacketId), *downSamplingPkt));
+#endif
 
     HevcDecodePicPktM12 *pictureDecodePkt = MOS_New(HevcDecodePicPktM12, this, m_hwInterface);
     DECODE_CHK_NULL(pictureDecodePkt);
@@ -425,6 +611,31 @@ MOS_STATUS HevcPipelineM12::CreateSubPackets(DecodeSubPacketManager& subPacketMa
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS HevcPipelineM12::CreatePostSubPipeLines(DecodeSubPipelineManager &subPipelineManager)
+{
+    DECODE_FUNC_CALL();
+
+#ifdef _DECODE_PROCESSING_SUPPORTED
+    auto sfcHistogramPostSubPipeline = MOS_New(DecodeSfcHistogramSubPipelineM12, this, m_task, m_numVdbox, m_hwInterface);
+    DECODE_CHK_NULL(sfcHistogramPostSubPipeline);
+    DECODE_CHK_STATUS(m_postSubPipeline->Register(*sfcHistogramPostSubPipeline));
+#endif
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS HevcPipelineM12::CreatePreSubPipeLines(DecodeSubPipelineManager &subPipelineManager)
+{
+    m_bitstream = MOS_New(DecodeInputBitstreamM12, this, m_task, m_numVdbox, m_hwInterface);
+    DECODE_CHK_NULL(m_bitstream);
+    DECODE_CHK_STATUS(subPipelineManager.Register(*m_bitstream));
+
+    m_streamout = MOS_New(DecodeStreamOutM12, this, m_task, m_numVdbox, m_hwInterface);
+    DECODE_CHK_NULL(m_streamout);
+    DECODE_CHK_STATUS(subPipelineManager.Register(*m_streamout));
+    return MOS_STATUS_SUCCESS;
+}
+
 #ifdef _MMC_SUPPORTED
 MOS_STATUS HevcPipelineM12::InitMmcState()
 {
@@ -466,7 +677,7 @@ MOS_STATUS HevcPipelineM12::DumpParams(HevcBasicFeature &basicFeature)
             basicFeature.m_hevcSliceParams,
             basicFeature.m_hevcRextSliceParams,
             basicFeature.m_numSlices,
-            m_shortFormatInUse));
+            basicFeature.m_shortFormatInUse));
     }
 
     if(basicFeature.m_hevcSubsetParams != nullptr)
