@@ -385,8 +385,12 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::SetHcpRefSurfaceParams(MHW_VDBOX_SURFACE_PA
 #endif
     }
 #ifdef _MMC_SUPPORTED
-    Vp9DecodeMemComp *vp9DecodeMemComp = dynamic_cast<Vp9DecodeMemComp *>(m_mmcState);
-    DECODE_CHK_STATUS(vp9DecodeMemComp->SetRefSurfaceMask(*m_vp9BasicFeature, refSurfaceParams));
+    if (m_mmcState->IsMmcEnabled())
+    {
+        Vp9DecodeMemComp *vp9DecodeMemComp = dynamic_cast<Vp9DecodeMemComp *>(m_mmcState);
+        DECODE_CHK_STATUS(vp9DecodeMemComp->SetRefSurfaceMask(*m_vp9BasicFeature, refSurfaceParams));
+        DECODE_CHK_STATUS(vp9DecodeMemComp->SetRefSurfaceCompressionFormat(*m_vp9BasicFeature, refSurfaceParams));
+    }
 #endif
     return MOS_STATUS_SUCCESS;
 }
@@ -512,9 +516,14 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::SetHcpPipeBufAddrParams(MHW_VDBOX_PIPE_BUF_
     CODECHAL_DEBUG_TOOL(DumpRefResources(pipeBufAddrParams, m_vp9BasicFeature->m_resVp9MvTemporalBuffer[0]->size));
    
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    if (MOS_GetTraceEventKeyword() & EVENT_DECODE_REFYUV_KEYWORD)
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_MV))
     {
-        TraceDataDumpRefResources(pipeBufAddrParams, m_vp9BasicFeature, m_vp9BasicFeature->m_resVp9MvTemporalBuffer[0]->size);
+        TraceDataDumpMV(pipeBufAddrParams, m_vp9BasicFeature->m_resVp9MvTemporalBuffer[0]->size);
+    }
+
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_REFYUV))
+    {
+        TraceDataDumpReferences(pipeBufAddrParams);
     }
 #endif
 
@@ -681,10 +690,44 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::DumpRefResources(MHW_VDBOX_PIPE_BUF_ADDR_PA
 #endif
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
+MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpMV(
     MHW_VDBOX_PIPE_BUF_ADDR_PARAMS &pipeBufAddrParams,
-    Vp9BasicFeature *m_vp9BasicFeature,
     uint32_t size)
+{
+    if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presColMvTempBuffer[0]))
+    {
+        ResourceAutoLock resLock(m_allocator, pipeBufAddrParams.presColMvTempBuffer[0]);
+        auto             pData = (uint8_t *)resLock.LockResourceForRead();
+        DECODE_CHK_NULL(pData);
+
+        MOS_TraceDataDump(
+            "Decode_Vp9ColMvTempBuffer",
+            0,
+            pData,
+            size);
+
+        m_allocator->UnLock(pipeBufAddrParams.presColMvTempBuffer[0]);
+    };
+
+    if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presCurMvTempBuffer))
+    {
+        ResourceAutoLock resLock(m_allocator, pipeBufAddrParams.presCurMvTempBuffer);
+        auto             pData = (uint8_t *)resLock.LockResourceForRead();
+        DECODE_CHK_NULL(pData);
+
+        MOS_TraceDataDump(
+            "Decode_Vp9CurMvTempBuffer",
+            0,
+            pData,
+            size);
+
+        m_allocator->UnLock(pipeBufAddrParams.presCurMvTempBuffer);
+    };
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpReferences(MHW_VDBOX_PIPE_BUF_ADDR_PARAMS &pipeBufAddrParams)
 {
     bool bAllocateLastRef   = false;
     bool bAllocateGoldenRef = false;
@@ -697,22 +740,6 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
         dstSurface.OsResource = *(pipeBufAddrParams.presReferences[CodechalDecodeLastRef]);
         DECODE_CHK_STATUS(m_allocator->GetSurfaceInfo(&dstSurface));
 
-        DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
-            {
-                PICTURE_FRAME,
-                dstSurface.dwOffset,
-                dstSurface.YPlaneOffset.iYOffset,
-                dstSurface.dwPitch,
-                dstSurface.dwWidth,
-                dstSurface.dwHeight,
-                (uint32_t)dstSurface.Format,
-                dstSurface.UPlaneOffset.iLockSurfaceOffset,
-                dstSurface.VPlaneOffset.iLockSurfaceOffset,
-                dstSurface.UPlaneOffset.iSurfaceOffset,
-                dstSurface.VPlaneOffset.iSurfaceOffset,
-            };
-        MOS_TraceEvent(EVENT_DECODE_SURFACE_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-
         if (m_tempLastRefSurf == nullptr || m_allocator->ResourceIsNull(&m_tempLastRefSurf->OsResource))
         {
             bAllocateLastRef = true;
@@ -751,14 +778,34 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
             &m_tempLastRefSurf->OsResource,
             false));
 
+        DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
+        {
+            PICTURE_FRAME,
+            0,
+            m_tempLastRefSurf->dwOffset,
+            m_tempLastRefSurf->YPlaneOffset.iYOffset,
+            m_tempLastRefSurf->dwPitch,
+            m_tempLastRefSurf->dwWidth,
+            m_tempLastRefSurf->dwHeight,
+            (uint32_t)m_tempLastRefSurf->Format,
+            m_tempLastRefSurf->UPlaneOffset.iLockSurfaceOffset,
+            m_tempLastRefSurf->VPlaneOffset.iLockSurfaceOffset,
+            m_tempLastRefSurf->UPlaneOffset.iSurfaceOffset,
+            m_tempLastRefSurf->VPlaneOffset.iSurfaceOffset,
+        };
+        MOS_TraceEvent(EVENT_DECODE_DUMPINFO_REF, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+
         ResourceAutoLock resLock(m_allocator, &m_tempLastRefSurf->OsResource);
         auto             pData = (uint8_t *)resLock.LockResourceForRead();
+        DECODE_CHK_NULL(pData);
 
         MOS_TraceDataDump(
             "Decode_VP9LastRef",
             0, 
             pData,
             (uint32_t)m_tempLastRefSurf->OsResource.pGmmResInfo->GetSizeMainSurface());
+        
+        m_allocator->UnLock(&m_tempLastRefSurf->OsResource);
     }
 
     if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presReferences[CodechalDecodeGoldenRef]))
@@ -768,22 +815,6 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
         dstSurface.OsResource = *(pipeBufAddrParams.presReferences[CodechalDecodeGoldenRef]);
         DECODE_CHK_STATUS(m_allocator->GetSurfaceInfo(&dstSurface));
 
-        DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
-        {
-            PICTURE_FRAME,
-            dstSurface.dwOffset,
-            dstSurface.YPlaneOffset.iYOffset,
-            dstSurface.dwPitch,
-            dstSurface.dwWidth,
-            dstSurface.dwHeight,
-            (uint32_t)dstSurface.Format,
-            dstSurface.UPlaneOffset.iLockSurfaceOffset,
-            dstSurface.VPlaneOffset.iLockSurfaceOffset,
-            dstSurface.UPlaneOffset.iSurfaceOffset,
-            dstSurface.VPlaneOffset.iSurfaceOffset,
-        };
-        MOS_TraceEvent(EVENT_DECODE_SURFACE_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-
         if (m_tempGoldenRefSurf == nullptr || m_allocator->ResourceIsNull(&m_tempGoldenRefSurf->OsResource))
         {
             bAllocateGoldenRef = true;
@@ -822,14 +853,34 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
             &m_tempGoldenRefSurf->OsResource,
             false));
 
+        DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
+        {
+            PICTURE_FRAME,
+            0,
+            m_tempGoldenRefSurf->dwOffset,
+            m_tempGoldenRefSurf->YPlaneOffset.iYOffset,
+            m_tempGoldenRefSurf->dwPitch,
+            m_tempGoldenRefSurf->dwWidth,
+            m_tempGoldenRefSurf->dwHeight,
+            (uint32_t)m_tempGoldenRefSurf->Format,
+            m_tempGoldenRefSurf->UPlaneOffset.iLockSurfaceOffset,
+            m_tempGoldenRefSurf->VPlaneOffset.iLockSurfaceOffset,
+            m_tempGoldenRefSurf->UPlaneOffset.iSurfaceOffset,
+            m_tempGoldenRefSurf->VPlaneOffset.iSurfaceOffset,
+        };
+        MOS_TraceEvent(EVENT_DECODE_DUMPINFO_REF, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+
         ResourceAutoLock resLock(m_allocator, &m_tempGoldenRefSurf->OsResource);
         auto             pData = (uint8_t *)resLock.LockResourceForRead();
+        DECODE_CHK_NULL(pData);
 
         MOS_TraceDataDump(
             "Decode_VP9GoldenRef",
             0,
             pData,
             (uint32_t)m_tempGoldenRefSurf->OsResource.pGmmResInfo->GetSizeMainSurface());
+        
+        m_allocator->UnLock(&m_tempGoldenRefSurf->OsResource);
     }
 
     if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presReferences[CodechalDecodeAlternateRef]))
@@ -839,22 +890,6 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
         dstSurface.OsResource = *(pipeBufAddrParams.presReferences[CodechalDecodeAlternateRef]);
         DECODE_CHK_STATUS(m_allocator->GetSurfaceInfo(&dstSurface));
 
-        DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
-        {
-            PICTURE_FRAME,
-            dstSurface.dwOffset,
-            dstSurface.YPlaneOffset.iYOffset,
-            dstSurface.dwPitch,
-            dstSurface.dwWidth,
-            dstSurface.dwHeight,
-            (uint32_t)dstSurface.Format,
-            dstSurface.UPlaneOffset.iLockSurfaceOffset,
-            dstSurface.VPlaneOffset.iLockSurfaceOffset,
-            dstSurface.UPlaneOffset.iSurfaceOffset,
-            dstSurface.VPlaneOffset.iSurfaceOffset,
-        };
-        MOS_TraceEvent(EVENT_DECODE_SURFACE_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-
         if (m_tempAltRefSurf == nullptr || m_allocator->ResourceIsNull(&m_tempAltRefSurf->OsResource))
         {
             bAllocateAltRef = true;
@@ -893,36 +928,36 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
             &m_tempAltRefSurf->OsResource,
             false));
 
+        DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
+        {
+            PICTURE_FRAME,
+            0,
+            m_tempAltRefSurf->dwOffset,
+            m_tempAltRefSurf->YPlaneOffset.iYOffset,
+            m_tempAltRefSurf->dwPitch,
+            m_tempAltRefSurf->dwWidth,
+            m_tempAltRefSurf->dwHeight,
+            (uint32_t)m_tempAltRefSurf->Format,
+            m_tempAltRefSurf->UPlaneOffset.iLockSurfaceOffset,
+            m_tempAltRefSurf->VPlaneOffset.iLockSurfaceOffset,
+            m_tempAltRefSurf->UPlaneOffset.iSurfaceOffset,
+            m_tempAltRefSurf->VPlaneOffset.iSurfaceOffset,
+        };
+        MOS_TraceEvent(EVENT_DECODE_DUMPINFO_REF, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+
         ResourceAutoLock resLock(m_allocator, &m_tempAltRefSurf->OsResource);
         auto             pData = (uint8_t *)resLock.LockResourceForRead();
-
+        DECODE_CHK_NULL(pData);
+        
         MOS_TraceDataDump(
             "Decode_VP9AltRef",
             0,
             pData,
             (uint32_t)m_tempAltRefSurf->OsResource.pGmmResInfo->GetSizeMainSurface());
+        
+        m_allocator->UnLock(&m_tempAltRefSurf->OsResource);
     }
 
-    if (pipeBufAddrParams.presColMvTempBuffer[0])
-    {
-        m_osInterface->pfnDumpTraceGpuData(
-            m_osInterface,
-            "Decode_Vp9ColMvTempBuffer",
-            0,
-            pipeBufAddrParams.presColMvTempBuffer[0],
-            size);
-    };
-
-    if (pipeBufAddrParams.presCurMvTempBuffer)
-    {
-        m_osInterface->pfnDumpTraceGpuData(
-            m_osInterface,
-            "Decode_Vp9CurMvTempBuffer",
-            0,
-            pipeBufAddrParams.presCurMvTempBuffer,
-            size);
-    };
-
     return MOS_STATUS_SUCCESS;
 }
 #endif
