@@ -25,6 +25,14 @@
 //! \details  Common interface and structure used in media copy which are platform independent
 //!
 #include "media_copy_xe_xpm_plus.h"
+#include "media_blt_copy_xe_xpm_plus.h"
+#include "media_render_copy_xe_xpm_plus.h"
+#include "media_skuwa_specific.h"
+#include "mos_os.h"
+#include "mos_resource_defs.h"
+#include "mos_utilities.h"
+#include "vp_common.h"
+class MhwInterfaces;
 
 MediaCopyStateXe_Xpm_Plus::MediaCopyStateXe_Xpm_Plus() :
     MediaCopyBaseState()
@@ -41,9 +49,9 @@ MOS_STATUS MediaCopyStateXe_Xpm_Plus::Initialize(  PMOS_INTERFACE  osInterface,
     MEDIA_FEATURE_TABLE* pSkuTable;
 
     m_osInterface   = osInterface;
-    m_mhwInterfaces = mhwInterfaces;
+    m_mhwInterfacesXeXpmPlus = mhwInterfaces;
 
-    MCPY_CHK_STATUS_RETURN(MediaCopyBaseState::Initialize(osInterface, mhwInterfaces));
+    MCPY_CHK_STATUS_RETURN(MediaCopyBaseState::Initialize(osInterface));
 
     pSkuTable = osInterface->pfnGetSkuTable(osInterface);
     if (MEDIA_IS_SKU(pSkuTable, FtrCCSNode))
@@ -51,7 +59,7 @@ MOS_STATUS MediaCopyStateXe_Xpm_Plus::Initialize(  PMOS_INTERFACE  osInterface,
         // render copy init
         if (nullptr == m_renderCopy )
         {
-            m_renderCopy = MOS_New(RenderCopy_Xe_Xpm_Plus, m_osInterface, m_mhwInterfaces);
+            m_renderCopy = MOS_New(RenderCopy_Xe_Xpm_Plus, m_osInterface, m_mhwInterfacesXeXpmPlus);
             MCPY_CHK_NULL_RETURN(m_renderCopy);
             MCPY_CHK_STATUS_RETURN(m_renderCopy->Initialize());
         }
@@ -64,7 +72,7 @@ MOS_STATUS MediaCopyStateXe_Xpm_Plus::Initialize(  PMOS_INTERFACE  osInterface,
     // blt copy init
     if (nullptr == m_bltState)
     {
-        m_bltState = MOS_New(BltStateXe_Xpm_Plus, m_osInterface, m_mhwInterfaces);
+        m_bltState = MOS_New(BltStateXe_Xpm_Plus, m_osInterface, m_mhwInterfacesXeXpmPlus);
         MCPY_CHK_NULL_RETURN(m_bltState);
         MCPY_CHK_STATUS_RETURN(m_bltState->Initialize());
     }
@@ -74,8 +82,21 @@ MOS_STATUS MediaCopyStateXe_Xpm_Plus::Initialize(  PMOS_INTERFACE  osInterface,
 MediaCopyStateXe_Xpm_Plus::~MediaCopyStateXe_Xpm_Plus()
 {
     MOS_Delete(m_renderCopy);
-
     MOS_Delete(m_bltState);
+    if (m_mhwInterfacesXeXpmPlus)
+    {
+        if (m_mhwInterfacesXeXpmPlus->m_cpInterface)
+        {
+            Delete_MhwCpInterface(m_mhwInterfacesXeXpmPlus->m_cpInterface);
+            m_mhwInterfacesXeXpmPlus->m_cpInterface = nullptr;
+        }
+        MOS_Delete(m_mhwInterfacesXeXpmPlus->m_miInterface);
+        MOS_Delete(m_mhwInterfacesXeXpmPlus->m_veboxInterface);
+        MOS_Delete(m_mhwInterfacesXeXpmPlus->m_bltInterface);
+        MOS_Delete(m_mhwInterfacesXeXpmPlus->m_renderInterface);
+        MOS_Delete(m_mhwInterfacesXeXpmPlus);
+        m_mhwInterfacesXeXpmPlus = nullptr;
+    }
 }
 
 bool MediaCopyStateXe_Xpm_Plus::RenderFormatSupportCheck(PMOS_RESOURCE src, PMOS_RESOURCE dst)
@@ -164,41 +185,33 @@ MOS_STATUS MediaCopyStateXe_Xpm_Plus::MediaRenderCopy(PMOS_RESOURCE src, PMOS_RE
     }
 }
 
-MOS_STATUS MediaCopyStateXe_Xpm_Plus::CapabilityCheck()
+MOS_STATUS MediaCopyStateXe_Xpm_Plus::CapabilityCheck(MCPY_STATE_PARAMS& mcpySrc, MCPY_STATE_PARAMS& mcpyDst, MCPY_ENGINE_CAPS& caps)
 {
-    // init hw enigne caps.
-    m_mcpyEngineCaps.engineBlt    = 1;
-    m_mcpyEngineCaps.engineRender = 1;
-    m_mcpyEngineCaps.engineVebox = 0;
+    // init hw enigne caps.pvc doesn't have vebox
+    caps.engineBlt    = 1;
+    caps.engineRender = 1;
+    caps.engineVebox = 0;
 
     // derivate class specific check. include HW engine avaliable check.
-    MCPY_CHK_STATUS_RETURN(FeatureSupport(m_mcpySrc.OsRes, m_mcpyDst.OsRes, m_mcpyEngineCaps));
+    MCPY_CHK_STATUS_RETURN(FeatureSupport(mcpySrc.OsRes, mcpyDst.OsRes, caps));
 
     // common policy check
     // legal check
     // Blt engine does not support protection, allow the copy if dst is staging buffer in system mem
-    if (m_mcpySrc.CpMode == MCPY_CPMODE_CP && m_mcpyDst.CpMode == MCPY_CPMODE_CLEAR && !m_allowCPBltCopy)
+    if (mcpySrc.CpMode == MCPY_CPMODE_CP && mcpyDst.CpMode == MCPY_CPMODE_CLEAR && !m_allowCPBltCopy)
     {
         MCPY_ASSERTMESSAGE("illegal usage");
         return MOS_STATUS_INVALID_PARAMETER;
     }
 
     // Eu cap check.
-    if (!RenderFormatSupportCheck(m_mcpySrc.OsRes, m_mcpyDst.OsRes) || // format check, implemented on Gen derivate class.
-        (m_mcpyDst.CompressionMode == MOS_MMC_MC) ||
-        m_mcpySrc.bAuxSuface)
+    if (!RenderFormatSupportCheck(mcpySrc.OsRes, mcpyDst.OsRes) || // format check, implemented on Gen derivate class.
+        mcpySrc.bAuxSuface)
     {
-        m_mcpyEngineCaps.engineRender = false;
+        caps.engineRender = false;
     }
 
-    // blt check.
-    if ((m_mcpySrc.CompressionMode != MOS_MMC_DISABLED) ||
-        (m_mcpyDst.CompressionMode != MOS_MMC_DISABLED))
-    {
-        m_mcpyEngineCaps.engineBlt = false;
-    }
-
-    if (!m_mcpyEngineCaps.engineVebox && !m_mcpyEngineCaps.engineBlt && !m_mcpyEngineCaps.engineRender)
+    if (!caps.engineVebox && !caps.engineBlt && !caps.engineRender)
     {
         return MOS_STATUS_INVALID_PARAMETER; // unsupport copy on each hw engine.
     }
@@ -206,17 +219,18 @@ MOS_STATUS MediaCopyStateXe_Xpm_Plus::CapabilityCheck()
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS MediaCopyStateXe_Xpm_Plus::CopyEnigneSelect(MCPY_METHOD preferMethod)
+MOS_STATUS MediaCopyStateXe_Xpm_Plus::CopyEnigneSelect(MCPY_METHOD preferMethod, MCPY_ENGINE& mcpyEngine, MCPY_ENGINE_CAPS& caps)
 {
     // assume perf render > vebox > blt. blt data should be measured.
     // driver should make sure there is at least one he can process copy even customer choice doesn't match caps.
     switch (preferMethod)
     {
         case MCPY_METHOD_PERFORMANCE:
-            m_mcpyEngine = m_mcpyEngineCaps.engineRender ? MCPY_ENGINE_RENDER:MCPY_ENGINE_BLT;
+        case MCPY_METHOD_DEFAULT:
+            mcpyEngine = caps.engineRender ? MCPY_ENGINE_RENDER:MCPY_ENGINE_BLT;
             break;
         default:
-            m_mcpyEngine = MCPY_ENGINE_BLT;
+            mcpyEngine = MCPY_ENGINE_BLT;
             break;
     }
 
