@@ -30,6 +30,7 @@
 #include "decode_av1_feature_defs_g12.h"
 #include "mos_defs.h"
 #include "hal_oca_interface.h"
+#include "codechal_utilities.h"
 
 namespace decode 
 {
@@ -140,51 +141,61 @@ MOS_STATUS FilmGrainAppNoisePkt::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8
     MediaPerfProfiler *             pPerfProfiler       = nullptr;
     MOS_CONTEXT *                   pOsContext          = nullptr;
     PMHW_MI_MMIOREGISTERS           pMmioRegisters      = nullptr;
-
-    RENDER_PACKET_CHK_NULL_RETURN(m_renderHal);
-    RENDER_PACKET_CHK_NULL_RETURN(m_renderHal->pMhwRenderInterface);
-    RENDER_PACKET_CHK_NULL_RETURN(m_renderHal->pMhwMiInterface);
-    RENDER_PACKET_CHK_NULL_RETURN(m_renderHal->pMhwRenderInterface->GetMmioRegisters());
-    RENDER_PACKET_CHK_NULL_RETURN(m_renderHal->pOsInterface);
-    RENDER_PACKET_CHK_NULL_RETURN(m_renderHal->pOsInterface->pOsContext);
+    PRENDERHAL_INTERFACE_LEGACY     pRenderHalLegacy    = (PRENDERHAL_INTERFACE_LEGACY)m_renderHal;
+    
+    RENDER_PACKET_CHK_NULL_RETURN(pRenderHalLegacy);
+    RENDER_PACKET_CHK_NULL_RETURN(pRenderHalLegacy->pMhwRenderInterface);
+    RENDER_PACKET_CHK_NULL_RETURN(pRenderHalLegacy->pMhwMiInterface);
+    RENDER_PACKET_CHK_NULL_RETURN(pRenderHalLegacy->pMhwRenderInterface->GetMmioRegisters());
+    RENDER_PACKET_CHK_NULL_RETURN(pRenderHalLegacy->pOsInterface);
+    RENDER_PACKET_CHK_NULL_RETURN(pRenderHalLegacy->pOsInterface->pOsContext);
 
     eStatus         = MOS_STATUS_UNKNOWN;
-    pOsInterface    = m_renderHal->pOsInterface;
-    pMhwMiInterface = m_renderHal->pMhwMiInterface;
-    pMhwRender      = m_renderHal->pMhwRenderInterface;
+    pOsInterface    = pRenderHalLegacy->pOsInterface;
+    pMhwMiInterface = pRenderHalLegacy->pMhwMiInterface;
+    pMhwRender      = pRenderHalLegacy->pMhwRenderInterface;
     iRemaining      = 0;
     FlushParam      = g_cRenderHal_InitMediaStateFlushParams;
-    pPerfProfiler   = m_renderHal->pPerfProfiler;
+    pPerfProfiler   = pRenderHalLegacy->pPerfProfiler;
     pOsContext      = pOsInterface->pOsContext;
     pMmioRegisters  = pMhwRender->GetMmioRegisters();
 
     RENDER_PACKET_CHK_STATUS_RETURN(SetPowerMode(CODECHAl_MEDIA_STATE_AV1_FILM_GRAIN_AN));
 
+    PMOS_RESOURCE resource = nullptr;
+    uint32_t      offset   = 0;
+    DECODE_CHK_STATUS(m_statusReport->GetAddress(decode::statusReportGlobalCount, resource, offset));
+
+    GenericPrologParams.bEnableMediaFrameTracking     = true;
+    GenericPrologParams.presMediaFrameTrackingSurface = resource;
+    GenericPrologParams.dwMediaFrameTrackingTag       = m_statusReport->GetSubmittedCount() + 1;
+    // Set media frame tracking address offset(the offset from the decoder status buffer page)
+    GenericPrologParams.dwMediaFrameTrackingAddrOffset = offset;
     // Initialize command buffer and insert prolog
-    RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pfnInitCommandBuffer(m_renderHal, commandBuffer, &GenericPrologParams));
+    RENDER_PACKET_CHK_STATUS_RETURN(pRenderHalLegacy->pfnInitCommandBuffer(pRenderHalLegacy, commandBuffer, &GenericPrologParams));
     RENDER_PACKET_CHK_STATUS_RETURN(StartStatusReport(statusReportRcs, commandBuffer));
 
     HalOcaInterface::On1stLevelBBStart(*commandBuffer, *m_osInterface->pOsContext, m_osInterface->CurrentGpuContextHandle,
         *m_hwInterface->GetMiInterface(), *m_hwInterface->GetMiInterface()->GetMmioRegisters());
-    HalOcaInterface::TraceMessage(*commandBuffer, *m_osInterface->pOsContext, __FUNCTION__, sizeof(__FUNCTION__));
+    HalOcaInterface::TraceMessage(*commandBuffer, (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext, __FUNCTION__, sizeof(__FUNCTION__));
 
     if (pOsInterface && !m_av1BasicFeature->m_singleKernelPerfFlag)
     {
-        RENDER_PACKET_CHK_STATUS_RETURN(pPerfProfiler->AddPerfCollectStartCmd((void *)m_renderHal, pOsInterface, pMhwMiInterface, commandBuffer));
+        RENDER_PACKET_CHK_STATUS_RETURN(pPerfProfiler->AddPerfCollectStartCmd((void *)pRenderHalLegacy, pOsInterface, pMhwMiInterface, commandBuffer));
     }
 
     // Write timing data for 3P budget
-    RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pfnSendTimingData(m_renderHal, commandBuffer, true));
+    RENDER_PACKET_CHK_STATUS_RETURN(pRenderHalLegacy->pfnSendTimingData(pRenderHalLegacy, commandBuffer, true));
 
     bEnableSLM = false;  // Media walker first
-    RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pfnSetCacheOverrideParams(
-        m_renderHal,
-        &m_renderHal->L3CacheSettings,
+    RENDER_PACKET_CHK_STATUS_RETURN(pRenderHalLegacy->pfnSetCacheOverrideParams(
+        pRenderHalLegacy,
+        &pRenderHalLegacy->L3CacheSettings,
         bEnableSLM));
 
     // Flush media states
-    RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pfnSendMediaStates(
-        m_renderHal,
+    RENDER_PACKET_CHK_STATUS_RETURN(pRenderHalLegacy->pfnSendMediaStates(
+        pRenderHalLegacy,
         commandBuffer,
         m_walkerType == WALKER_TYPE_MEDIA ? &m_mediaWalkerParams : nullptr,
         m_walkerType == WALKER_TYPE_MEDIA ? nullptr : &m_gpgpuWalkerParams));
@@ -192,13 +203,13 @@ MOS_STATUS FilmGrainAppNoisePkt::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8
     // Write back GPU Status tag
     if (!pOsInterface->bEnableKmdMediaFrameTracking)
     {
-        RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pfnSendRcsStatusTag(m_renderHal, commandBuffer));
+        RENDER_PACKET_CHK_STATUS_RETURN(pRenderHalLegacy->pfnSendRcsStatusTag(pRenderHalLegacy, commandBuffer));
     }
 
-    RENDER_PACKET_CHK_STATUS_RETURN(pPerfProfiler->AddPerfCollectEndCmd((void *)m_renderHal, pOsInterface, pMhwMiInterface, commandBuffer));
+    RENDER_PACKET_CHK_STATUS_RETURN(pPerfProfiler->AddPerfCollectEndCmd((void *)pRenderHalLegacy, pOsInterface, pMhwMiInterface, commandBuffer));
 
     // Write timing data for 3P budget
-    RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pfnSendTimingData(m_renderHal, commandBuffer, false));
+    RENDER_PACKET_CHK_STATUS_RETURN(pRenderHalLegacy->pfnSendTimingData(pRenderHalLegacy, commandBuffer, false));
 
     MHW_PIPE_CONTROL_PARAMS PipeControlParams;
 
@@ -209,7 +220,7 @@ MOS_STATUS FilmGrainAppNoisePkt::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8
     PipeControlParams.bDisableCSStall               = false;
     RENDER_PACKET_CHK_STATUS_RETURN(pMhwMiInterface->AddPipeControl(commandBuffer, nullptr, &PipeControlParams));
 
-    if (MEDIA_IS_WA(m_renderHal->pWaTable, WaSendDummyVFEafterPipelineSelect))
+    if (MEDIA_IS_WA(pRenderHalLegacy->pWaTable, WaSendDummyVFEafterPipelineSelect))
     {
         MHW_VFE_PARAMS VfeStateParams       = {};
         VfeStateParams.dwNumberofURBEntries = 1;
@@ -217,7 +228,7 @@ MOS_STATUS FilmGrainAppNoisePkt::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8
     }
 
     // Add media flush command in case HW not cleaning the media state
-    if (MEDIA_IS_WA(m_renderHal->pWaTable, WaMSFWithNoWatermarkTSGHang))
+    if (MEDIA_IS_WA(pRenderHalLegacy->pWaTable, WaMSFWithNoWatermarkTSGHang))
     {
         FlushParam.bFlushToGo = true;
         if (m_walkerType == WALKER_TYPE_MEDIA)
@@ -230,7 +241,7 @@ MOS_STATUS FilmGrainAppNoisePkt::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8
         }
         RENDER_PACKET_CHK_STATUS_RETURN(pMhwMiInterface->AddMediaStateFlush(commandBuffer, nullptr, &FlushParam));
     }
-    else if (MEDIA_IS_WA(m_renderHal->pWaTable, WaAddMediaStateFlushCmd))
+    else if (MEDIA_IS_WA(pRenderHalLegacy->pWaTable, WaAddMediaStateFlushCmd))
     {
         RENDER_PACKET_CHK_STATUS_RETURN(pMhwMiInterface->AddMediaStateFlush(commandBuffer, nullptr, &FlushParam));
     }
@@ -251,7 +262,7 @@ MOS_STATUS FilmGrainAppNoisePkt::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8
         // Send Batch Buffer end command for 1st level Batch Buffer
         RENDER_PACKET_CHK_STATUS_RETURN(pMhwMiInterface->AddMiBatchBufferEnd(commandBuffer, nullptr));
     }
-    else if (m_renderHal->pOsInterface->bNoParsingAssistanceInKmd)
+    else if (pRenderHalLegacy->pOsInterface->bNoParsingAssistanceInKmd)
     {
         RENDER_PACKET_CHK_STATUS_RETURN(pMhwMiInterface->AddMiBatchBufferEnd(commandBuffer, nullptr));
     }
@@ -264,10 +275,10 @@ MOS_STATUS FilmGrainAppNoisePkt::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8
     if ((NullRenderingFlags.VPLgca ||
             NullRenderingFlags.VPGobal) == false)
     {
-        dwSyncTag = m_renderHal->pStateHeap->dwNextTag++;
+        dwSyncTag = pRenderHalLegacy->pStateHeap->dwNextTag++;
 
         // Set media state and batch buffer as busy
-        m_renderHal->pStateHeap->pCurMediaState->bBusy = true;
+        pRenderHalLegacy->pStateHeap->pCurMediaState->bBusy = true;
         if (pBatchBuffer)
         {
             pBatchBuffer->bBusy     = true;
@@ -316,6 +327,7 @@ MOS_STATUS FilmGrainAppNoisePkt::KernelStateSetup()
     int32_t           curbeLength = m_filmGrainFeature->m_filmGrainCurbeSize[m_kernelIndex];
     m_kernelCount                 = 1;
 
+    PRENDERHAL_INTERFACE_LEGACY pRenderHalLegacy = (PRENDERHAL_INTERFACE_LEGACY)m_renderHal;
     // Initialize States
     MOS_ZeroMemory(m_filter, sizeof(m_filter));
     MOS_ZeroMemory(&m_renderData.KernelEntry, sizeof(Kdll_CacheEntry));
@@ -324,7 +336,7 @@ MOS_STATUS FilmGrainAppNoisePkt::KernelStateSetup()
     m_renderData.KernelParam.GRF_Count          = 0;
     m_renderData.KernelParam.BT_Count           = btCount;
     m_renderData.KernelParam.Sampler_Count      = 0;
-    m_renderData.KernelParam.Thread_Count       = m_renderHal->pMhwRenderInterface->GetHwCaps()->dwMaxThreads;
+    m_renderData.KernelParam.Thread_Count       = pRenderHalLegacy->pMhwRenderInterface->GetHwCaps()->dwMaxThreads;
     m_renderData.KernelParam.GRF_Start_Register = 0;
     m_renderData.KernelParam.CURBE_Length       = curbeLength;
     m_renderData.KernelParam.block_width        = CODECHAL_MACROBLOCK_WIDTH;
@@ -336,7 +348,7 @@ MOS_STATUS FilmGrainAppNoisePkt::KernelStateSetup()
     m_renderData.KernelParam.blocks_x = resolutionX;
     m_renderData.KernelParam.blocks_y = resolutionY;
 
-    m_renderData.iCurbeOffset = m_renderHal->pMhwStateHeap->GetSizeofCmdInterfaceDescriptorData();
+    m_renderData.iCurbeOffset = pRenderHalLegacy->pMhwStateHeap->GetSizeofCmdInterfaceDescriptorData();
 
     // Set Parameters for Kernel Entry
     m_renderData.KernelEntry.iKUID       = 0;
@@ -367,7 +379,7 @@ MOS_STATUS FilmGrainAppNoisePkt::SetUpSurfaceState()
     RENDERHAL_SURFACE_STATE_PARAMS surfaceParams;
     MOS_ZeroMemory(&surfaceParams, sizeof(RENDERHAL_SURFACE_STATE_PARAMS));
     surfaceParams.MemObjCtl         = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ELLC_LLC_L3].Value;
-    surfaceParams.bRenderTarget     = true;
+    surfaceParams.isOutput     = true;
     surfaceParams.Boundary          = RENDERHAL_SS_BOUNDARY_ORIGINAL;
     if (m_hwInterface->Uses2PlanesInputSurfaceFilmGrain())
     {
@@ -401,7 +413,7 @@ MOS_STATUS FilmGrainAppNoisePkt::SetUpSurfaceState()
     isWritable                  = true;
     MOS_ZeroMemory(&surfaceParams, sizeof(surfaceParams));
     surfaceParams.MemObjCtl     = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ELLC_LLC_L3].Value;
-    surfaceParams.bRenderTarget = true;
+    surfaceParams.isOutput = true;
     surfaceParams.Boundary      = RENDERHAL_SS_BOUNDARY_ORIGINAL;
     surfaceParams.bWidthInDword_Y = true;
     surfaceParams.bWidthInDword_UV = true;
@@ -420,7 +432,7 @@ MOS_STATUS FilmGrainAppNoisePkt::SetUpSurfaceState()
     isWritable                  = true;
     MOS_ZeroMemory(&surfaceParams, sizeof(RENDERHAL_SURFACE_STATE_PARAMS));
     surfaceParams.MemObjCtl     = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ELLC_LLC_L3].Value;
-    surfaceParams.bRenderTarget = true;
+    surfaceParams.isOutput = true;
     surfaceParams.Boundary      = RENDERHAL_SS_BOUNDARY_ORIGINAL;
     MOS_ZeroMemory(&renderHalSurfaceNext, sizeof(RENDERHAL_SURFACE_NEXT));
     m_bindingTableIndex[anInputYDithering] = SetSurfaceForHwAccess(
@@ -434,7 +446,7 @@ MOS_STATUS FilmGrainAppNoisePkt::SetUpSurfaceState()
     isWritable                  = true;
     MOS_ZeroMemory(&surfaceParams, sizeof(RENDERHAL_SURFACE_STATE_PARAMS));
     surfaceParams.MemObjCtl     = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ELLC_LLC_L3].Value;
-    surfaceParams.bRenderTarget = true;
+    surfaceParams.isOutput = true;
     surfaceParams.Boundary      = RENDERHAL_SS_BOUNDARY_ORIGINAL;
     MOS_ZeroMemory(&renderHalSurfaceNext, sizeof(RENDERHAL_SURFACE_NEXT));
     m_bindingTableIndex[anInputUDithering] = SetSurfaceForHwAccess(
@@ -448,7 +460,7 @@ MOS_STATUS FilmGrainAppNoisePkt::SetUpSurfaceState()
     isWritable                  = true;
     MOS_ZeroMemory(&surfaceParams, sizeof(RENDERHAL_SURFACE_STATE_PARAMS));
     surfaceParams.MemObjCtl     = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ELLC_LLC_L3].Value;
-    surfaceParams.bRenderTarget = true;
+    surfaceParams.isOutput = true;
     surfaceParams.Boundary      = RENDERHAL_SS_BOUNDARY_ORIGINAL;
     MOS_ZeroMemory(&renderHalSurfaceNext, sizeof(RENDERHAL_SURFACE_NEXT));
     m_bindingTableIndex[anInputVDithering] = SetSurfaceForHwAccess(
@@ -462,7 +474,7 @@ MOS_STATUS FilmGrainAppNoisePkt::SetUpSurfaceState()
     isWritable = true;
     MOS_ZeroMemory(&surfaceParams, sizeof(RENDERHAL_SURFACE_STATE_PARAMS));
     surfaceParams.MemObjCtl     = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ELLC_LLC_L3].Value;
-    surfaceParams.bRenderTarget = true;
+    surfaceParams.isOutput = true;
     surfaceParams.Boundary      = RENDERHAL_SS_BOUNDARY_ORIGINAL;
     surfaceParams.bBufferUse    = true;
     MOS_ZeroMemory(&renderHalSurfaceNext, sizeof(RENDERHAL_SURFACE_NEXT));
@@ -479,7 +491,7 @@ MOS_STATUS FilmGrainAppNoisePkt::SetUpSurfaceState()
 
     MOS_ZeroMemory(&surfaceParams, sizeof(RENDERHAL_SURFACE_STATE_PARAMS));
     surfaceParams.MemObjCtl     = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ELLC_LLC_L3].Value;
-    surfaceParams.bRenderTarget = false;
+    surfaceParams.isOutput = false;
     surfaceParams.Boundary      = RENDERHAL_SS_BOUNDARY_ORIGINAL;
     surfaceParams.bBufferUse    = true;
 
@@ -497,7 +509,7 @@ MOS_STATUS FilmGrainAppNoisePkt::SetUpSurfaceState()
 
     MOS_ZeroMemory(&surfaceParams, sizeof(RENDERHAL_SURFACE_STATE_PARAMS));
     surfaceParams.MemObjCtl     = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ELLC_LLC_L3].Value;
-    surfaceParams.bRenderTarget = false;
+    surfaceParams.isOutput = false;
     surfaceParams.Boundary      = RENDERHAL_SS_BOUNDARY_ORIGINAL;
     surfaceParams.bBufferUse    = true;
 
@@ -515,7 +527,7 @@ MOS_STATUS FilmGrainAppNoisePkt::SetUpSurfaceState()
 
     MOS_ZeroMemory(&surfaceParams, sizeof(RENDERHAL_SURFACE_STATE_PARAMS));
     surfaceParams.MemObjCtl     = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ELLC_LLC_L3].Value;
-    surfaceParams.bRenderTarget = false;
+    surfaceParams.isOutput = false;
     surfaceParams.Boundary      = RENDERHAL_SS_BOUNDARY_ORIGINAL;
     surfaceParams.bBufferUse    = true;
 
