@@ -27,7 +27,6 @@
 #include <algorithm>
 #include "encode_av1_basic_feature.h"
 #include "encode_utils.h"
-#include "codechal_utilities.h"
 #include "encode_av1_reference_frames.h"
 #include "codec_def_encode_av1.h"
 
@@ -39,7 +38,7 @@ MOS_STATUS Av1ReferenceFrames::Init(Av1BasicFeature *basicFeature)
     ENCODE_CHK_NULL_RETURN(basicFeature);
 
     m_basicFeature = basicFeature;
-    ENCODE_CHK_STATUS_RETURN(CodecHalAllocateDataList(
+    ENCODE_CHK_STATUS_RETURN(EncodeAllocateDataList(
         m_refList,
         CODEC_AV1_NUM_UNCOMPRESSED_SURFACE));
 
@@ -50,7 +49,12 @@ Av1ReferenceFrames::~Av1ReferenceFrames()
 {
     ENCODE_FUNC_CALL();
 
-    CodecHalFreeDataList(m_refList, CODEC_AV1_NUM_UNCOMPRESSED_SURFACE);
+    EncodeFreeDataList(m_refList, CODEC_AV1_NUM_UNCOMPRESSED_SURFACE);
+}
+
+static bool MmcEnabled(MOS_MEMCOMP_STATE state)
+{
+    return state == MOS_MEMCOMP_RC || state == MOS_MEMCOMP_MC;
 }
 
 MOS_STATUS Av1ReferenceFrames::Update()
@@ -60,6 +64,8 @@ MOS_STATUS Av1ReferenceFrames::Update()
     // initialize internal structures for current frame before set up
     m_refFrameFlags = 0;
     m_numRefFrames = 0;
+    uint32_t compressionFormat = 0;
+
     MOS_ZeroMemory(m_currRefPic, sizeof(m_currRefPic));
     for (auto i = 0; i < CODEC_AV1_NUM_REF_FRAMES; i++)
     {
@@ -78,7 +84,6 @@ MOS_STATUS Av1ReferenceFrames::Update()
     m_refFrameBiasFlagsForRefManagement.value = 0;
 
     // save current frame infomation into m_refList
-    UpdateRefFrameSize(picParams->frame_width_minus1 + 1, picParams->frame_height_minus1 + 1);
     auto currRefIdx = picParams->CurrReconstructedPic.FrameIdx;
     m_currRefList = m_refList[currRefIdx];
 
@@ -88,8 +93,8 @@ MOS_STATUS Av1ReferenceFrames::Update()
     m_currRefList->sRefRawBuffer = m_basicFeature->m_rawSurface;
     m_currRefList->RefPic = picParams->CurrOriginalPic;
     m_currRefList->resBitstreamBuffer = m_basicFeature->m_resBitstreamBuffer;
-    m_currRefList->m_frameWidth = m_refWidth;
-    m_currRefList->m_frameHeight = m_refHeight;
+    m_currRefList->m_frameWidth = m_refWidth? m_refWidth : picParams->frame_width_minus1 + 1;
+    m_currRefList->m_frameHeight = m_refHeight? m_refHeight : picParams->frame_height_minus1 + 1;
     m_currRefList->m_orderHint = picParams->order_hint;
     m_currRefList->m_miCols = m_basicFeature->m_miCols;
     m_currRefList->m_miRows = m_basicFeature->m_miRows;
@@ -145,7 +150,8 @@ MOS_STATUS Av1ReferenceFrames::Update()
     {
         m_firstValidRefPic = currRawOrRecon;
     }
-
+    m_basicFeature->GetSurfaceMmcInfo(m_firstValidRefPic, m_refMmcState[intraFrame], compressionFormat);
+    m_refCompressionFormat = MmcEnabled(m_refMmcState[intraFrame])? compressionFormat : m_refCompressionFormat;
     return MOS_STATUS_SUCCESS;
 
 }
@@ -226,7 +232,7 @@ MOS_STATUS Av1ReferenceFrames::SetupCurrRefPic()
     auto seqParams = m_basicFeature->m_av1SeqParams;
     ENCODE_CHK_NULL_RETURN(seqParams);
     auto firstValid = false;
-
+    uint32_t compressionFormat = 0;
     for (auto i = 0; i < av1NumInterRefFrames; i++)
     {
         if (m_refFrameFlags & (AV1_ENCODE_GET_REF_FALG(i)))
@@ -247,12 +253,6 @@ MOS_STATUS Av1ReferenceFrames::SetupCurrRefPic()
             }
 
             m_currRefList->m_refOrderHint[i] = m_refList[frameIdx]->m_orderHint;
-            //TBD
-            //if (m_vp9SeqParams->SeqFlags.fields.EnableDynamicScaling &&
-            //    (refList[frameIdx]->dwFrameWidth != m_oriFrameWidth || refList[frameIdx]->dwFrameHeight != m_oriFrameHeight))
-            //{
-            //    m_dysRefFrameFlags |= DYS_REF_LAST;
-            //}
         }
     }
 
@@ -263,6 +263,8 @@ MOS_STATUS Av1ReferenceFrames::SetupCurrRefPic()
         {
             m_currRefPic[i] = m_firstValidRefPic;
         }
+        m_basicFeature->GetSurfaceMmcInfo(m_currRefPic[i], m_refMmcState[i + 1], compressionFormat);
+        m_refCompressionFormat = MmcEnabled(m_refMmcState[i + 1]) ? compressionFormat : m_refCompressionFormat;
     }
 
     return MOS_STATUS_SUCCESS;
@@ -531,6 +533,64 @@ std::vector<PMOS_SURFACE> Av1ReferenceFrames::GetPakRefSurface() const
     return refs;
 }
 
+void Av1ReferenceFrames::GetFwdBwdRefPicList(CODEC_PICTURE (&refsPicList)[2][15])
+{
+    ENCODE_FUNC_CALL();
+    auto picParams       = m_basicFeature->m_av1PicParams;
+    auto ref_frame_ctrl0 = picParams->ref_frame_ctrl_l0;
+    auto ref_frame_ctrl1 = picParams->ref_frame_ctrl_l1;
+
+    uint8_t ref_frame_ctrl_l0 = RefFrameL0L1(ref_frame_ctrl0);
+    uint8_t ref_frame_ctrl_l1 = RefFrameL0L1(ref_frame_ctrl1);
+    uint8_t RefFrameBiasFlags = m_refFrameBiasFlagsForRefManagement.value;
+
+    uint8_t fwdRefNum = 0;
+    uint8_t bwdRefNum = 0;
+
+    for (auto i = 0; i < av1NumInterRefFrames; i++)
+    {
+        uint8_t mask = AV1_ENCODE_GET_REF_FALG(i);
+        if ((ref_frame_ctrl_l0 & mask) && !(RefFrameBiasFlags & mask))
+        {
+            auto index  = picParams->ref_frame_idx[i];
+            refsPicList[0][fwdRefNum].FrameIdx = index;
+            refsPicList[0][fwdRefNum].PicEntry = picParams->RefFrameList[index].PicEntry;
+            refsPicList[0][fwdRefNum].PicFlags = picParams->RefFrameList[index].PicFlags;
+            fwdRefNum++;
+        }
+        if ((ref_frame_ctrl_l1 & mask) && (RefFrameBiasFlags & mask))
+        {
+            auto index  = picParams->ref_frame_idx[i];
+            refsPicList[1][bwdRefNum].FrameIdx = index;
+            refsPicList[1][bwdRefNum].PicEntry = picParams->RefFrameList[index].PicEntry;
+            refsPicList[1][bwdRefNum].PicFlags = picParams->RefFrameList[index].PicFlags;
+            bwdRefNum++;
+        }
+    }
+    uint8_t CodingType = (m_basicFeature->m_pictureCodingType == I_TYPE) ? I_TYPE : (m_basicFeature->m_ref.IsLowDelay() ? (m_basicFeature->m_ref.IsPFrame() ? P_TYPE : B_TYPE) : B_TYPE);
+    if (CodingType == B_TYPE && m_lowDelay && bwdRefNum == 0)
+    {
+        for (int j = 0; j < fwdRefNum; j++)
+        {
+            refsPicList[1][j] = refsPicList[0][j];
+        }
+    }
+}
+
+void Av1ReferenceFrames::GetRefFramePOC(int32_t (&refsPOCList)[15], int32_t const orderHint)
+{
+    auto picParams = m_basicFeature->m_av1PicParams;
+    for (auto i = 0; i < av1NumInterRefFrames; i++)
+    {
+        if (picParams->RefFrameList[i].PicFlags != PICTURE_INVALID)
+        {
+            auto frameIdx = picParams->RefFrameList[i].FrameIdx;
+            auto dist = GetRelativeDist(m_refList[frameIdx]->m_orderHint, m_currRefList->m_orderHint);
+            refsPOCList[i] = orderHint + dist;
+        }
+    }
+}
+
 bool Av1ReferenceFrames::CheckSegmentForPrimeFrame()
 {
     ENCODE_FUNC_CALL();
@@ -949,7 +1009,7 @@ MHW_SETPAR_DECL_SRC(AVP_SURFACE_STATE, Av1ReferenceFrames)
         params.pitch   = m_firstValidRefPic->dwPitch;
         params.uOffset = m_firstValidRefPic->YoffsetForUplane;
         params.vOffset = m_firstValidRefPic->YoffsetForVplane;
-        m_basicFeature->GetSurfaceMmcInfo(m_firstValidRefPic, params.mmcState, params.compressionFormat);
+
     }
     else
     {
@@ -961,8 +1021,10 @@ MHW_SETPAR_DECL_SRC(AVP_SURFACE_STATE, Av1ReferenceFrames)
         params.pitch   = m_currRefPic[params.surfaceStateId - av1LastRef]->dwPitch;
         params.uOffset = m_currRefPic[params.surfaceStateId - av1LastRef]->YoffsetForUplane;
         params.vOffset = m_currRefPic[params.surfaceStateId - av1LastRef]->YoffsetForVplane;
-        m_basicFeature->GetSurfaceMmcInfo(m_currRefPic[params.surfaceStateId - av1LastRef], params.mmcState, params.compressionFormat);
+
     }
+    std::copy(std::begin(m_refMmcState), std::end(m_refMmcState), params.mmcState);
+    params.compressionFormat = m_refCompressionFormat;
 
     return MOS_STATUS_SUCCESS;
 }
