@@ -26,11 +26,11 @@
 
 #include "encode_hevc_basic_feature.h"
 #include "encode_utils.h"
-#include "codechal_utilities.h"
 #include "encode_allocator.h"
 #include "encode_hevc_header_packer.h"
 #include "encode_hevc_vdenc_const_settings.h"
 #include "mos_solo_generic.h"
+#include "mos_os_cp_interface_specific.h"
 
 using namespace mhw::vdbox;
 namespace encode
@@ -66,6 +66,37 @@ MOS_STATUS HevcBasicFeature::Init(void *setting)
     m_maxTileNumber = CODECHAL_GET_WIDTH_IN_BLOCKS(m_frameWidth, CODECHAL_HEVC_MIN_TILE_SIZE) *
         CODECHAL_GET_HEIGHT_IN_BLOCKS(m_frameHeight, CODECHAL_HEVC_MIN_TILE_SIZE);
 
+    MOS_ALLOC_GFXRES_PARAMS allocParams{};
+    allocParams.Type     = MOS_GFXRES_BUFFER;
+    allocParams.TileType = MOS_TILE_LINEAR;
+    allocParams.Format   = Format_Buffer;
+
+    allocParams.dwBytes  = MOS_ALIGN_CEIL(m_sizeOfHcpPakFrameStats * m_maxTileNumber, CODECHAL_PAGE_SIZE);
+    allocParams.pBufName = "FrameStatStreamOutBuffer";
+    allocParams.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
+    m_recycleBuf->RegisterResource(FrameStatStreamOutBuffer, allocParams, 1);
+
+    allocParams.dwBytes  = MOS_ALIGN_CEIL(1216 * m_maxTileNumber, CODECHAL_PAGE_SIZE);
+    allocParams.pBufName = "vdencStats";
+    allocParams.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_WRITE;
+    m_recycleBuf->RegisterResource(VdencStatsBuffer, allocParams, 1);
+
+    uint32_t numOfLCU    = MOS_ROUNDUP_DIVIDE(m_frameWidth, m_maxLCUSize) * (MOS_ROUNDUP_DIVIDE(m_frameHeight, m_maxLCUSize) + 1);
+    allocParams.dwBytes  = MOS_ALIGN_CEIL(2 * sizeof(uint32_t) * (numOfLCU * 5 + numOfLCU * 64 * 8), CODECHAL_PAGE_SIZE);
+    allocParams.pBufName = "CuRecordStreamOutBuffer";
+    allocParams.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_OUTPUT_STATISTICS_WRITE;
+    ENCODE_NORMALMESSAGE("osCpInterface = %p\n", m_osInterface->osCpInterface);
+    if (m_osInterface->osCpInterface != nullptr)
+    {
+        ENCODE_NORMALMESSAGE("IsCpEnabled = %u\n", m_osInterface->osCpInterface->IsCpEnabled());
+    }
+    if (m_osInterface->osCpInterface == nullptr || !m_osInterface->osCpInterface->IsCpEnabled())
+    {
+        allocParams.dwMemType = MOS_MEMPOOL_SYSTEMMEMORY;
+    }
+    allocParams.Flags.bCacheable = true;
+    m_recycleBuf->RegisterResource(CuRecordStreamOutBuffer, allocParams, m_maxSyncDepth);
+
     ENCODE_CHK_STATUS_RETURN(m_ref.Init(this, m_allocator));
 
     MediaUserSetting::Value outValue;
@@ -90,7 +121,7 @@ MOS_STATUS HevcBasicFeature::Update(void *params)
     ENCODE_FUNC_CALL();
     ENCODE_CHK_NULL_RETURN(params);
 
-    EncodeBasicFeature::Update(params);
+    ENCODE_CHK_STATUS_RETURN(EncodeBasicFeature::Update(params));
 
     EncoderParams* encodeParams = (EncoderParams*)params;
 
@@ -105,31 +136,8 @@ MOS_STATUS HevcBasicFeature::Update(void *params)
     m_nalUnitParams = encodeParams->ppNALUnitParams;
     ENCODE_CHK_NULL_RETURN(m_nalUnitParams);
     m_NumNalUnits   = encodeParams->uiNumNalUnits;
-
-#if MHW_HWCMDPARSER_ENABLED
-    {
-        char frameType;
-        switch (m_hevcPicParams->CodingType)
-        {
-        case I_TYPE:
-            frameType = 'I';
-            break;
-        case P_TYPE:
-            frameType = 'P';
-            break;
-        case B_TYPE:
-            frameType = m_hevcSeqParams->LowDelayMode ? 'G' : 'B';
-            break;
-        }
-
-        auto instance = mhw::HwcmdParser::GetInstance();
-        if (instance)
-        {
-            instance->UpdateFrameInfo(frameType);
-        }
-    }
-#endif
-
+    m_bEnableSubPelMode = encodeParams->bEnableSubPelMode;
+    m_SubPelMode        = encodeParams->SubPelMode;
 #ifdef _ENCODE_RESERVED
     if (m_rsvdState && m_rsvdState->GetFeatureRsvdFlag())
     {
@@ -197,6 +205,7 @@ MOS_STATUS HevcBasicFeature::Update(void *params)
     }
 
     ENCODE_CHK_STATUS_RETURN(GetTrackedBuffers());
+    ENCODE_CHK_STATUS_RETURN(GetRecycleBuffers());
 
     if (m_hevcSeqParams->LowDelayMode)
     {
@@ -343,7 +352,7 @@ MOS_STATUS HevcBasicFeature::UpdateTrackedBufferParameters()
     {
         allocParams.dwBytes  = m_sizeOfMvTemporalBuffer;
         allocParams.pBufName = "mvTemporalBuffer";
-
+        allocParams.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_NOCACHE;
         ENCODE_CHK_STATUS_RETURN(m_trackedBuf->RegisterParam(encode::BufferType::mvTemporalBuffer, allocParams));
     }
 
@@ -509,21 +518,7 @@ uint32_t HevcBasicFeature::GetProfileLevelMaxFrameSize()
     auto     maxBytePerPicNot0    = (uint64_t)((((float_t)maxMBPS * (float_t)m_hevcSeqParams->FrameRate.Denominator) / (float_t)m_hevcSeqParams->FrameRate.Numerator) * formatFactor);
     uint32_t profileLevelMaxFrame = 0;
 
-    uint32_t userMaxFrameSize = m_hevcSeqParams->UserMaxIFrameSize;
-    if ((m_hevcPicParams->CodingType != I_TYPE) && (m_hevcSeqParams->UserMaxPBFrameSize > 0))
-    {
-        userMaxFrameSize = m_hevcSeqParams->UserMaxPBFrameSize;
-    }
-
-    if (userMaxFrameSize != 0)
-    {
-        profileLevelMaxFrame = (uint32_t)MOS_MIN(userMaxFrameSize, maxBytePerPic);
-        profileLevelMaxFrame = (uint32_t)MOS_MIN(maxBytePerPicNot0, profileLevelMaxFrame);
-    }
-    else {
-        profileLevelMaxFrame = (uint32_t)MOS_MIN(maxBytePerPicNot0, maxBytePerPic);
-    }
-
+    profileLevelMaxFrame = (uint32_t)MOS_MIN(maxBytePerPicNot0, maxBytePerPic);
     profileLevelMaxFrame = (uint32_t)MOS_MIN((m_frameHeight * m_frameWidth), profileLevelMaxFrame);
 
     return profileLevelMaxFrame;
@@ -555,6 +550,34 @@ MOS_STATUS HevcBasicFeature::GetTrackedBuffers()
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS HevcBasicFeature::GetRecycleBuffers()
+{
+    ENCODE_CHK_NULL_RETURN(m_recycleBuf);
+
+    uint32_t recycleBufferIdx = -1;
+    for (uint32_t i = 0; i < m_maxSyncDepth; i++)
+    {
+        auto pos = find(m_recycleBufferIdxes.begin(), m_recycleBufferIdxes.end(), i);
+        if (pos == m_recycleBufferIdxes.end())
+        {
+            recycleBufferIdx = i;
+            break;
+        }
+    }
+
+    if (recycleBufferIdx == -1 || recycleBufferIdx >= m_maxSyncDepth)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
+    m_resMbCodeBuffer = m_recycleBuf->GetBuffer(RecycleResId::CuRecordStreamOutBuffer, recycleBufferIdx);
+    ENCODE_CHK_NULL_RETURN(m_resMbCodeBuffer);
+
+    m_recycleBufferIdxes.push_back(recycleBufferIdx);
+
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS HevcBasicFeature::SetRoundingValues()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
@@ -662,6 +685,7 @@ MOS_STATUS HevcBasicFeature::GetSurfaceMmcInfo(PMOS_SURFACE surface, MOS_MEMCOMP
 
 MHW_SETPAR_DECL_SRC(VDENC_PIPE_MODE_SELECT, HevcBasicFeature)
 {
+    params.frameStatisticsStreamOut              = m_hevcPicParams->StatusReportEnable.fields.FrameStats;
     params.bitDepthMinus8                        = m_hevcSeqParams->bit_depth_luma_minus8;
     params.chromaType                            = m_hevcSeqParams->chroma_format_idc;
     params.wirelessSessionId                     = 0;
@@ -740,12 +764,6 @@ MHW_SETPAR_DECL_SRC(VDENC_REF_SURFACE_STATE, HevcBasicFeature)
     params.width       = ((m_hevcSeqParams->wFrameWidthInMinCbMinus1 + 1) << (m_hevcSeqParams->log2_min_coding_block_size_minus3 + 3));
     uint32_t tileMode   = GetHwTileType(params.tileType, params.tileModeGmm, params.gmmTileEn);
 
-    if (MEDIA_IS_WA(m_osInterface->pfnGetWaTable(m_osInterface), WaForceTile64ReconSurfaceToTile4) && params.format != Format_NV12 && tileMode == MOS_TILE_64_GMM)
-    {
-        params.gmmTileEn = false;
-        params.tileType  = MOS_TILE_YF;
-    }
-
     if (m_reconSurface.Format == Format_Y410 || m_reconSurface.Format == Format_444P || m_reconSurface.Format == Format_AYUV)
     {
         if (m_reconSurface.Format == Format_Y410)
@@ -795,17 +813,15 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, HevcBasicFeature)
 {
     if (m_mmcState->IsMmcEnabled())
     {
-        ENCODE_CHK_STATUS_RETURN(m_mmcState->GetSurfaceMmcState(const_cast<PMOS_SURFACE>(&m_reconSurface), &params.mmcStatePreDeblock));
-        ENCODE_CHK_STATUS_RETURN(m_mmcState->GetSurfaceMmcFormat(const_cast<PMOS_SURFACE>(&m_reconSurface), &params.compressionFormatRecon));
+        params.mmcEnabled = true;
         ENCODE_CHK_STATUS_RETURN(m_mmcState->GetSurfaceMmcState(const_cast<PMOS_SURFACE>(&m_rawSurface), &params.mmcStateRaw));
         ENCODE_CHK_STATUS_RETURN(m_mmcState->GetSurfaceMmcFormat(const_cast<PMOS_SURFACE>(&m_rawSurface), &params.compressionFormatRaw));
     }
     else
     {
-        params.mmcStatePreDeblock     = MOS_MEMCOMP_DISABLED;
-        params.compressionFormatRecon = 0;
-        params.mmcStateRaw            = MOS_MEMCOMP_DISABLED;
-        params.compressionFormatRaw   = 0;
+        params.mmcEnabled           = false;
+        params.mmcStateRaw          = MOS_MEMCOMP_DISABLED;
+        params.compressionFormatRaw = 0;
     }
 
     params.surfaceRaw               = m_rawSurfaceToPak;
@@ -837,7 +853,7 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, HevcBasicFeature)
     if (MEDIA_IS_WA(waTable, Wa_22011549751) &&
         m_hevcPicParams->CodingType == I_TYPE &&
         !m_osInterface->bSimIsActive &&
-        !Mos_Solo_Extension(m_osInterface->pOsContext) &&
+        !Mos_Solo_Extension((MOS_CONTEXT_HANDLE)m_osInterface->pOsContext) &&
         !m_hevcPicParams->pps_curr_pic_ref_enabled_flag)
     {
         params.numActiveRefL0  = 1;
@@ -1005,7 +1021,7 @@ MHW_SETPAR_DECL_SRC(VDENC_CMD2, HevcBasicFeature)
     if (MEDIA_IS_WA(waTable, Wa_22011549751) &&
         m_hevcPicParams->CodingType == I_TYPE &&
         !m_osInterface->bSimIsActive &&
-        !Mos_Solo_Extension(m_osInterface->pOsContext) &&
+        !Mos_Solo_Extension((MOS_CONTEXT_HANDLE)m_osInterface->pOsContext) &&
         !m_hevcPicParams->pps_curr_pic_ref_enabled_flag)
     {
         params.pictureType = 3;
@@ -1013,6 +1029,8 @@ MHW_SETPAR_DECL_SRC(VDENC_CMD2, HevcBasicFeature)
         params.frameIdxL1Ref0 = 0;
     }
 
+    ENCODE_CHK_COND_RETURN(m_SubPelMode < 0 || m_SubPelMode > 3, "Invalid subPelMode");
+    params.subPelMode = m_bEnableSubPelMode ? m_SubPelMode : 3;
     auto settings = static_cast<HevcVdencFeatureSettings *>(m_constSettings);
     ENCODE_CHK_NULL_RETURN(settings);
 
@@ -1069,6 +1087,7 @@ MHW_SETPAR_DECL_SRC(HCP_PIC_STATE, HevcBasicFeature)
     {
         params.sseEnable = false;
     }
+    params.constrainedIntraPredFlag = m_hevcPicParams->constrained_intra_pred_flag;
 
     return MOS_STATUS_SUCCESS;
 }
@@ -1239,6 +1258,10 @@ MHW_SETPAR_DECL_SRC(HCP_SURFACE_STATE, HevcBasicFeature)
     }
 #ifdef _MMC_SUPPORTED
     GetSurfaceMmcInfo(psSurface, params.mmcState, params.dwCompressionFormat);
+    if (params.surfaceStateId == CODECHAL_HCP_REF_SURFACE_ID)
+    {
+        m_ref.MHW_SETPAR_F(HCP_SURFACE_STATE)(params);
+    }
 #endif
 
     ENCODE_CHK_NULL_RETURN(psSurface);
