@@ -41,6 +41,10 @@
 #include <memory>
 #include <vector>
 
+#if _MEDIA_RESERVED
+#include "encode_tracked_buffer_ext.h"
+#endif
+
 namespace encode
 {
 // define the buffer types in the tracked list
@@ -55,16 +59,16 @@ enum class BufferType
     vdencSegIdStreamOutBuffer,
     bwdAdaptCdfBuffer,
     postCdefReconSurface,
+    preMbCodedBuffer,
+    preRefSurface,
+    preRawSurface,
     preDs4xSurface,
     preDs8xSurface,
     superResRefScaled,
     superResRef4xDsScaled,
     superResRef8xDsScaled,
-#if _MEDIA_RESERVED
-#define BUFFER_TYPE_EXT
-#include "encode_tracked_buffer_ext.h"
-#undef BUFFER_TYPE_EXT
-#endif
+    preencRef0,
+    preencRef1,
 };
 
 struct MapBufferResourceType
@@ -217,13 +221,13 @@ protected:
         {BufferType::vdencSegIdStreamOutBuffer, ResourceType::bufferResource},
         {BufferType::bwdAdaptCdfBuffer,         ResourceType::bufferResource},
         {BufferType::postCdefReconSurface,      ResourceType::surfaceResource},
+        {BufferType::preMbCodedBuffer,          ResourceType::bufferResource},
+        {BufferType::preRefSurface,             ResourceType::surfaceResource},
+        {BufferType::preRawSurface,             ResourceType::surfaceResource},
         {BufferType::preDs4xSurface,            ResourceType::surfaceResource},
         {BufferType::preDs8xSurface,            ResourceType::surfaceResource},
-#if _MEDIA_RESERVED
-#define BUFFER_MAP_EXT
-#include "encode_tracked_buffer_ext.h"
-#undef BUFFER_MAP_EXT
-#endif
+        {BufferType::preencRef0,                ResourceType::bufferResource},
+        {BufferType::preencRef1,                ResourceType::bufferResource},
         {BufferType::superResRefScaled,         ResourceType::surfaceResource},
         {BufferType::superResRef4xDsScaled,     ResourceType::surfaceResource},
         {BufferType::superResRef8xDsScaled,     ResourceType::surfaceResource},
@@ -243,7 +247,7 @@ protected:
     std::map<BufferType, std::shared_ptr<BufferQueue> > m_bufferQueue = {};  //!< buffer queues
     std::map<BufferType, std::shared_ptr<BufferQueue> > m_oldQueue = {};     //!< old queues for resolution change
 
-MEDIA_CLASS_DEFINE_END(TrackedBuffer)
+MEDIA_CLASS_DEFINE_END(encode__TrackedBuffer)
 };
 }  // namespace encode
 #endif  // !__ENCODE_BUFFER_TRACKER_H__
