@@ -27,7 +27,6 @@
 #define __ENCODE_TILE_H__
 #include "encode_basic_feature.h"
 #include "encode_pipeline.h"
-#include "codechal_encoder_base.h"
 
 namespace encode
 {
@@ -156,7 +155,7 @@ class EncodeTile : public MediaFeature
 public:
     EncodeTile(MediaFeatureManager *featureManager,
         EncodeAllocator *allocator,
-        CodechalHwInterface *hwInterface,
+        CodechalHwInterfaceNext *hwInterface,
         void *constSettings);
 
     virtual ~EncodeTile();
@@ -475,10 +474,10 @@ protected:
     //!
     virtual MOS_STATUS AllocateTileStatistics(void *params) = 0;
 
-    EncodeAllocator      *m_allocator         = nullptr;  //!< Allocator used in tile feature
-    EncodeBasicFeature   *m_basicFeature      = nullptr;  //!< EncodeBasicFeature
-    CodechalHwInterface  *m_hwInterface       = nullptr;  //!< Hw interface as utilities
-    MediaFeatureManager  *m_featureManager    = nullptr;  //!< Pointer to feature manager
+    EncodeAllocator          *m_allocator         = nullptr;  //!< Allocator used in tile feature
+    EncodeBasicFeature       *m_basicFeature      = nullptr;  //!< EncodeBasicFeature
+    CodechalHwInterfaceNext  *m_hwInterface       = nullptr;  //!< Hw interface as utilities
+    MediaFeatureManager      *m_featureManager    = nullptr;  //!< Pointer to feature manager
 
     EncodeTileData       *m_tileData          = nullptr;  //!< Pointer to the Tile data array
     uint32_t              m_numTiles          = 1;        //!< Total tile numbers
@@ -503,7 +502,7 @@ protected:
     uint32_t          m_tileLevelBatchSize    = 0;    //!< Size of the 2rd level batch buffer for each tile
     uint32_t          m_numTileBatchAllocated[m_codecHalNumTileLevelBatchBuffers] ={0};    //!< The number of allocated batch buffer for tiles
     uint32_t          m_tileBatchBufferIndex = 0;     //!< Current index for tile batch buffer of same frame, updated per frame
-    PMHW_BATCH_BUFFER m_tileLevelBatchBuffer[m_codecHalNumTileLevelBatchBuffers][EncodeBasicFeature::m_vdencBrcPassNum] = {0};  //!< Tile level batch buffer for each tile
+    PMHW_BATCH_BUFFER m_tileLevelBatchBuffer[m_codecHalNumTileLevelBatchBuffers][EncodeBasicFeature::m_vdencBrcPassNum] = {{0}};  //!< Tile level batch buffer for each tile
     MOS_RESOURCE      m_resTileBasedStatisticsBuffer[EncodeBasicFeature::m_uncompressedSurfaceNum] = {};
     MOS_RESOURCE      m_resHuCPakAggregatedFrameStatsBuffer = {};
     MOS_RESOURCE      m_tileRecordBuffer[EncodeBasicFeature::m_uncompressedSurfaceNum] = {};
@@ -514,7 +513,7 @@ protected:
 
     bool              m_enableTileReplay = false;  //!< TileReplay Enable
 
-MEDIA_CLASS_DEFINE_END(EncodeTile)
+MEDIA_CLASS_DEFINE_END(encode__EncodeTile)
 };
 
 }  // namespace encode
