@@ -31,7 +31,7 @@
 #include "encode_status_report_defs.h"
 #include "encode_utils.h"
 #include "encode_allocator.h"
-#include "codechal_encoder_base.h"
+#include "codec_def_common_encode.h"
 #include "media_status_report.h"
 
 namespace encode {
@@ -287,7 +287,7 @@ namespace encode {
         //! \param  [in] enableRcs
         //!         Enable Rcs status buffer contarol if true
         //!
-        EncoderStatusReport(EncodeAllocator *allocator, bool enableMfx, bool enableRcs, bool enableCp);
+        EncoderStatusReport(EncodeAllocator *allocator, PMOS_INTERFACE pOsInterface, bool enableMfx, bool enableRcs, bool enableCp);
         virtual ~EncoderStatusReport();
 
         //!
@@ -397,6 +397,7 @@ namespace encode {
 
     protected:
         EncodeStatusReportData m_statusReportData[m_statusNum] = {};
+        PMOS_INTERFACE         m_osInterface = nullptr;
         bool                   m_enableMfx = false;
         bool                   m_enableRcs = false;
         bool                   m_enableCp  = false;
@@ -422,7 +423,7 @@ namespace encode {
         static const uint32_t  m_maxCodecFuncNum = 12;
         static const uint32_t  m_codecFuncToFuncIdPairs[m_maxCodecFuncNum];
 
-    MEDIA_CLASS_DEFINE_END(EncoderStatusReport)
+    MEDIA_CLASS_DEFINE_END(encode__EncoderStatusReport)
     };
 }
 
