@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -104,36 +104,6 @@ enum AvpBufferType
     avpInternalBufferMax
 };
 
-enum CommandsNumberOfAddress
-{
-    MI_BATCH_BUFFER_START_CMD_NUMBER_OF_ADDRESSES              =  1, //  2 DW for  1 address field
-    MI_STORE_DATA_IMM_CMD_NUMBER_OF_ADDRESSES                  =  1, //  2 DW for  1 address field
-    MI_FLUSH_DW_CMD_NUMBER_OF_ADDRESSES                        =  1, //  2 DW for  1 address field
-    MI_CONDITIONAL_BATCH_BUFFER_END_CMD_NUMBER_OF_ADDRESSES    =  1, //  2 DW for  1 address field
-    MI_STORE_REGISTER_MEM_CMD_NUMBER_OF_ADDRESSES              =  1, //  2 DW for  1 address field
-    MI_COPY_MEM_MEM_CMD_NUMBER_OF_ADDRESSES                    =  4, //  4 DW for  2 address fields
-    MI_SEMAPHORE_WAIT_CMD_NUMBER_OF_ADDRESSES                  =  1, //  2 DW for  1 address fields
-    MI_ATOMIC_CMD_NUMBER_OF_ADDRESSES                          =  1, //  2 DW for  1 address field
-
-    MFX_WAIT_CMD_NUMBER_OF_ADDRESSES                           =  0, //  0 DW for    address fields
-
-    AVP_PIPE_MODE_SELECT_CMD_NUMBER_OF_ADDRESSES               =  0,  //  0 DW for    address fields
-    AVP_SURFACE_STATE_CMD_NUMBER_OF_ADDRESSES                  =  0,  //  0 DW for    address fields
-    AVP_PIPE_BUF_ADDR_STATE_CMD_NUMBER_OF_ADDRESSES            =  61, //           61 address fields
-    AVP_IND_OBJ_BASE_ADDR_STATE_CMD_NUMBER_OF_ADDRESSES        =  3,  //            3 address fields
-    AVP_PIC_STATE_CMD_NUMBER_OF_ADDRESSES                      =  0,  //  0 DW for    address fields
-    AVP_REF_IDX_STATE_CMD_NUMBER_OF_ADDRESSES                  =  0,  //  0 DW for    address fields
-    AVP_SEGMENT_STATE_CMD_NUMBER_OF_ADDRESSES                  =  0,  //  0 DW for    address fields
-    AVP_TILE_CODING_CMD_NUMBER_OF_ADDRESSES                    =  0,  //  0 DW for    address fields
-    AVP_BSD_OBJECT_CMD_NUMBER_OF_ADDRESSES                     =  0,  //  0 DW for    address fields
-    AVP_INLOOP_FILTER_STATE_CMD_NUMBER_OF_ADDRESSES            =  0,  //  0 DW for    address fields
-    AVP_INTER_PRED_STATE_CMD_NUMBER_OF_ADDRESSES               =  0,  //  0 DW for    address fields
-    AVP_PAK_INSERT_OBJECT_CMD_NUMBER_OF_ADDRESSES              =  0,   //  0 DW for    address fields
-    VDENC_PIPE_BUF_ADDR_STATE_CMD_NUMBER_OF_ADDRESSES          =  12,  // 12 DW for 12 address fields
-    VD_PIPELINE_FLUSH_CMD_NUMBER_OF_ADDRESSES                  =  0,  //  0 DW for  0 address fields
-    AVP_FILM_GRAIN_STATE_CMD_NUMBER_OF_ADDRESSES               =  0,  // 0 DW for  0 address fields
-};
-
 struct AvpBufferSizePar
 {
     uint8_t      bitDepthIdc;
@@ -265,7 +235,7 @@ struct _MHW_PAR_T(AVP_PIC_STATE)
 
     bool     autoBistreamStitchingInHardware     = false;
 
-    bool     postCdefPixelStreamoutEn            = false;
+    bool     postCdefReconPixelStreamoutEn       = false;
 
     bool     allowScreenContentTools             = false;
     bool     allowIntraBC                        = false;
@@ -325,6 +295,9 @@ struct _MHW_PAR_T(AVP_TILE_CODING)
     bool     lastTileOfFrame                         = false;
     bool     disableCdfUpdateFlag                    = false;
     bool     disableFrameContextUpdateFlag           = false;
+#if (_DEBUG || _RELEASE_INTERNAL)
+    bool     enableAvpDebugMode                      = false;
+#endif
 
     uint8_t  numOfActiveBePipes                      = 0;
     uint16_t numOfTileColumnsInFrame                 = 0;
@@ -436,7 +409,7 @@ struct _MHW_PAR_T(AVP_SURFACE_STATE)
     uint32_t          vOffset            = 0;
     uint8_t           surfaceStateId     = 0;
     uint8_t           bitDepthLumaMinus8 = 0;
-    MOS_MEMCOMP_STATE mmcState           = MOS_MEMCOMP_DISABLED;
+    MOS_MEMCOMP_STATE mmcState[av1TotalRefsPerFrame] = { MOS_MEMCOMP_DISABLED };
     uint32_t          compressionFormat  = 0;
     SURFACE_FORMAT    srcFormat          = SURFACE_FORMAT::SURFACE_FORMAT_PLANAR4208;
     uint32_t          uvPlaneAlignment   = 0;
@@ -469,9 +442,38 @@ struct _MHW_PAR_T(AVP_PAK_INSERT_OBJECT)
     PMHW_BATCH_BUFFER batchBufferForPakSlices    = nullptr;
 };
 
-struct _MHW_PAR_T(AVP_CMD1)
+struct _MHW_PAR_T(AVP_FILM_GRAIN_STATE)
 {
-    __MHW_VDBOX_AVP_WRAPPER_EXT(AVP_CMD1_CMDPAR_EXT);
+    uint16_t    grainRandomSeed            = 0;
+    uint8_t     clipToRestrictedRange      = 0;
+    uint8_t     numOfYPoints               = 0;
+    uint8_t     numOfCbPoints              = 0;
+    uint8_t     numOfCrPoints              = 0;
+    uint8_t     matrixCoefficients         = 0;
+    uint8_t     grainScalingMinus8         = 0;
+    uint8_t     arCoeffLag                 = 0;
+    uint32_t    arCoeffShiftMinus6         = 0;
+    uint32_t    grainScaleShift            = 0;
+    uint32_t    chromaScalingFromLuma      = 0;
+    uint32_t    grainNoiseOverlap          = 0;
+                                               
+    uint8_t     pointYValue[14]            = {};
+    uint8_t     pointYScaling[14]          = {};
+    uint8_t     pointCbValue[10]           = {};
+    uint8_t     pointCbScaling[10]         = {};
+    uint8_t     pointCrValue[10]           = {};
+    uint8_t     pointCrScaling[10]         = {};
+                                               
+    int8_t      arCoeffsY[24]              = {};
+    int8_t      arCoeffsCb[25]             = {};
+    int8_t      arCoeffsCr[25]             = {};
+                                               
+    uint8_t     cbMult                     = 0;
+    uint8_t     cbLumaMult                 = 0;
+    uint16_t    cbOffset                   = 0;
+    uint8_t     crMult                     = 0;
+    uint8_t     crLumaMult                 = 0;
+    uint16_t    crOffset                   = 0;
 };
 
 }  // namespace avp
