@@ -28,12 +28,13 @@
 //!
 
 #include "media_context.h"
-#include "mos_gpucontextmgr.h"
 #include "mos_interface.h"
 #include "mos_os_virtualengine_next.h"
-#include "codechal_hw.h"
+#if !EMUL
+#include "codec_hw_next.h"
 #include "decode_scalability_defs.h"
-
+#endif
+#include "mos_os_cp_interface_specific.h"
 MediaContext::MediaContext(uint8_t componentType, void *hwInterface, PMOS_INTERFACE osInterface)
 {
     if (!hwInterface)
@@ -56,6 +57,7 @@ MediaContext::MediaContext(uint8_t componentType, void *hwInterface, PMOS_INTERF
 
     m_hwInterface = hwInterface;
     m_osInterface = osInterface;
+    m_userSettingPtr = osInterface->pfnGetUserSettingInstance(osInterface);
     m_componentType = componentType;
 
     m_streamId = m_osInterface->streamIndex;
@@ -69,6 +71,16 @@ MediaContext::~MediaContext()
         m_osInterface->pfnWaitAllCmdCompletion(m_osInterface);
     }
 
+    if ((MOS_VE_MULTINODESCALING_SUPPORTED(m_osInterface)) &&
+       (m_curNodeOrdinal == MOS_GPU_NODE_VIDEO || m_curNodeOrdinal == MOS_GPU_NODE_VIDEO2))
+    {
+        m_osInterface->pfnDestroyVideoNodeAssociation(m_osInterface, m_curNodeOrdinal);
+        if (m_osInterface->osStreamState && m_osInterface->osStreamState->component == COMPONENT_Encode)
+        {
+            m_osInterface->pfnSetLatestVirtualNode(m_osInterface, MOS_GPU_NODE_MAX);
+        }
+    }
+
     for (auto& curAttribute : m_gpuContextAttributeTable)
     {
         if (curAttribute.scalabilityState)
@@ -102,28 +114,27 @@ MediaContext::~MediaContext()
                     return;
                 }
             }
-            else
+#if !_VULKAN
+            else if (m_osInterface->modularizedGpuCtxEnabled)
             {
-                auto gpuContextMgr = m_osInterface->pfnGetGpuContextMgr(m_osInterface);
-                
-                if (gpuContextMgr == nullptr)
+                // Be compatible to legacy MOS
+                auto status = m_osInterface->pfnDestroyGpuContextByHandle(m_osInterface, curAttribute.gpuContext);
+                if (status != MOS_STATUS_SUCCESS)
                 {
-                    //No need to destory GPU context when adv_gpucontext not enabled in Os context
-                    MOS_OS_NORMALMESSAGE("There is no Gpu context manager, adv gpu context not enabled, no need to destory GPU contexts.");
+                    MOS_OS_NORMALMESSAGE("Could not destroy gpu context");
                     return;
                 }
-                else
+            }
+#endif //!_VULKAN
+            else
+            {
+                auto status = m_osInterface->pfnDestroyGpuContext(
+                    m_osInterface,
+                    curAttribute.ctxForLegacyMos);
+                if (status != MOS_STATUS_SUCCESS)
                 {
-                    auto gpuContext = gpuContextMgr->GetGpuContext(curAttribute.gpuContext);
-                    if (gpuContext)
-                    {
-                        gpuContextMgr->DestroyGpuContext(gpuContext);
-                    }
-                    else
-                    {
-                        MOS_OS_ASSERTMESSAGE("Not found gpu Context to destory, something must be wrong");
-                        return;
-                    }
+                    MOS_OS_NORMALMESSAGE("Gpu Context destory failed, something must be wrong");
+                    return;
                 }
             }
         }
@@ -132,9 +143,10 @@ MediaContext::~MediaContext()
             MOS_OS_ASSERTMESSAGE("Invalid gpu Context handle in entry, something must be wrong");
             return;
         }
-
+#if !EMUL
         // Be compatible to legacy MOS
         m_osInterface->pfnSetGpuContextHandle(m_osInterface, MOS_GPU_CONTEXT_INVALID_HANDLE, curAttribute.ctxForLegacyMos);
+#endif
     }
 
     m_gpuContextAttributeTable.clear();
@@ -168,17 +180,25 @@ MOS_STATUS MediaContext::SwitchContext(MediaFunction func, ContextRequirement *r
         if (scalPars->raMode)
         {
             MOS_OS_NORMALMESSAGE("request RA mode context for protected render workload");
-            WriteUserFeature(__MEDIA_USER_FEATURE_VALUE_RA_MODE_ENABLE_ID, 1, m_osInterface->pOsContext);
+            ReportUserSetting(m_userSettingPtr,
+                              __MEDIA_USER_FEATURE_VALUE_RA_MODE_ENABLE,
+                              uint32_t(1),
+                              MediaUserSetting::Group::Device);
         }
         if (scalPars->protectMode)
         {
             MOS_OS_NORMALMESSAGE("request protect mode context for protected render workload");
-            WriteUserFeature(__MEDIA_USER_FEATURE_VALUE_PROTECT_MODE_ENABLE_ID, 1, m_osInterface->pOsContext);
+            ReportUserSetting(m_userSettingPtr,
+                              __MEDIA_USER_FEATURE_VALUE_PROTECT_MODE_ENABLE,
+                              uint32_t(1),
+                              MediaUserSetting::Group::Device);
         }
     }
 
     uint32_t index = m_invalidContextAttribute;
+#if !EMUL
     MOS_OS_CHK_STATUS_RETURN(SearchContext<ScalabilityPars*>(func, (ScalabilityPars*)requirement, index));
+#endif
     if (index == m_invalidContextAttribute)
     {
         MOS_OS_CHK_STATUS_RETURN(CreateContext<ScalabilityPars*>(func, (ScalabilityPars*)requirement, index));
@@ -314,6 +334,13 @@ MOS_STATUS MediaContext::CreateContext(MediaFunction func, T params, uint32_t& i
     indexReturn = m_gpuContextAttributeTable.size();
     m_gpuContextAttributeTable.push_back(newAttr);
 
+    if (func == VeboxVppFunc || func == ComputeVppFunc)
+    {
+         m_osInterface->pfnRegisterBBCompleteNotifyEvent(
+            m_osInterface,
+            newAttr.ctxForLegacyMos);
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -339,7 +366,9 @@ MOS_STATUS MediaContext::SwitchContext(
     MediaScalability * veStateProvided = nullptr;
 
     uint32_t index = m_invalidContextAttribute;
+#if !EMUL
     MOS_OS_CHK_STATUS_RETURN(SearchContext<MediaScalabilityOption&>(func, scalabilityOption, index));
+#endif
     if (index == m_invalidContextAttribute)
     {
         MOS_OS_CHK_STATUS_RETURN(CreateContext<MediaScalabilityOption *>(func, &scalabilityOption, index));
@@ -388,14 +417,42 @@ MOS_STATUS MediaContext::FunctionToNode(MediaFunction func, const MOS_GPUCTX_CRE
         break;
     case VdboxEncodeFunc:
     case VdboxDecodeFunc:
+    case VdboxDecodeVirtualNode0Func:
+    case VdboxDecodeVirtualNode1Func:
         if (option.LRCACount >= 2)
         {
             node = MOS_GPU_NODE_VIDEO; // multiple pipe decode or encode always using VIDEO node
+            if (MOS_VE_MULTINODESCALING_SUPPORTED(m_osInterface))
+            {
+                if (m_curNodeOrdinal == MOS_GPU_NODE_VIDEO || m_curNodeOrdinal == MOS_GPU_NODE_VIDEO2)
+                {
+                    m_osInterface->pfnDestroyVideoNodeAssociation(m_osInterface, m_curNodeOrdinal);
+                    if (func == VdboxEncodeFunc)
+                    {
+                        m_osInterface->pfnSetLatestVirtualNode(m_osInterface, MOS_GPU_NODE_MAX);
+                    }
+                }
+                MOS_OS_CHK_STATUS_RETURN(m_osInterface->pfnCreateVideoNodeAssociation(
+                    m_osInterface,
+                    true,
+                    &node));
+                if (func == VdboxDecodeFunc || func == VdboxDecodeVirtualNode0Func || func == VdboxDecodeVirtualNode1Func)
+                {
+                    m_osInterface->pfnSetDecoderVirtualNodePerStream(m_osInterface, node);
+                }
+                else if (func == VdboxEncodeFunc)
+                {
+                    m_osInterface->pfnSetLatestVirtualNode(m_osInterface, node);
+                }
+            }
+            m_curNodeOrdinal = node;
         }
+#if !EMUL
         else
         {
-            MOS_OS_CHK_STATUS_RETURN(FunctionToNodeCodec(node));
+            MOS_OS_CHK_STATUS_RETURN(FunctionToNodeCodec(func, node));
         }
+#endif
         break;
     case VdboxDecodeWaFunc:
     case VdboxDecrpytFunc:
@@ -418,20 +475,161 @@ MOS_STATUS MediaContext::FunctionToNode(MediaFunction func, const MOS_GPUCTX_CRE
 
     return status;
 }
-
-MOS_STATUS MediaContext::FunctionToNodeCodec(MOS_GPU_NODE& node)
+#if !EMUL
+MOS_STATUS MediaContext::FunctionToNodeCodec(MediaFunction func, MOS_GPU_NODE& node)
 {
-    CodechalHwInterface *hwInterface = static_cast<CodechalHwInterface *>(m_hwInterface);
-    MhwVdboxMfxInterface *mfxInterface = hwInterface->GetMfxInterface();
-    MOS_OS_CHK_NULL_RETURN(mfxInterface);
+    MHW_VDBOX_GPUNODE_LIMIT gpuNodeLimit = {0};
+
+    MOS_OS_CHK_STATUS_RETURN(FindGpuNodeToUse(func , &gpuNodeLimit));
 
-    MHW_VDBOX_GPUNODE_LIMIT gpuNodeLimit = { 0 };
-    MOS_OS_CHK_STATUS_RETURN(mfxInterface->FindGpuNodeToUse(&gpuNodeLimit));
     node = (MOS_GPU_NODE)(gpuNodeLimit.dwGpuNodeToUse);
 
     return MOS_STATUS_SUCCESS;
 }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+MOS_STATUS MediaContext::CheckScalabilityOverrideValidity()
+{
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+    MEDIA_SYSTEM_INFO *gtSystemInfo = nullptr;
+    uint32_t           forceVdbox   = 0;
+    bool               scalableDecMode = false;
+    bool               useVD1          = false;
+    bool               useVD2          = false;
+
+    MHW_MI_CHK_NULL(m_osInterface);
+    scalableDecMode = m_osInterface->bHcpDecScalabilityMode ? true : false;
+    forceVdbox      = m_osInterface->eForceVdbox;
+    gtSystemInfo    = m_osInterface->pfnGetGtSystemInfo(m_osInterface);
+    MHW_MI_CHK_NULL(gtSystemInfo);
+
+    if (forceVdbox != MOS_FORCE_VDBOX_NONE &&
+        forceVdbox != MOS_FORCE_VDBOX_1 &&
+        forceVdbox != MOS_FORCE_VDBOX_2 &&
+        // 2 pipes, VDBOX1-BE1, VDBOX2-BE2
+        forceVdbox != MOS_FORCE_VDBOX_1_1_2 &&
+        forceVdbox != MOS_FORCE_VDBOX_2_1_2)
+    {
+        eStatus = MOS_STATUS_INVALID_PARAMETER;
+        MHW_ASSERTMESSAGE("user feature forceVdbox value is invalid.");
+        return eStatus;
+    }
+    if (!scalableDecMode &&
+        (forceVdbox == MOS_FORCE_VDBOX_1_1_2 ||
+            forceVdbox == MOS_FORCE_VDBOX_2_1_2))
+    {
+        eStatus = MOS_STATUS_INVALID_PARAMETER;
+        MHW_ASSERTMESSAGE("user feature forceVdbox valude does not consistent with regkey scalability mode.");
+        return eStatus;
+    }
+
+    if (scalableDecMode && !m_scalabilitySupported)
+    {
+        eStatus = MOS_STATUS_INVALID_PARAMETER;
+        MHW_ASSERTMESSAGE("user feature scalability mode is not allowed on current platform!");
+        return eStatus;
+    }
+
+    if (forceVdbox == 0)
+    {
+        useVD1 = true;
+    }
+    else
+    {
+        MHW_VDBOX_IS_VDBOX_SPECIFIED(forceVdbox, MOS_FORCE_VDBOX_1, MOS_FORCEVDBOX_VDBOXID_BITSNUM, MOS_FORCEVDBOX_MASK, useVD1);
+        MHW_VDBOX_IS_VDBOX_SPECIFIED(forceVdbox, MOS_FORCE_VDBOX_2, MOS_FORCEVDBOX_VDBOXID_BITSNUM, MOS_FORCEVDBOX_MASK, useVD2);
+    }
+    if (!gtSystemInfo->VDBoxInfo.IsValid ||
+        (useVD1 && !gtSystemInfo->VDBoxInfo.Instances.Bits.VDBox0Enabled) ||
+        (useVD2 && !gtSystemInfo->VDBoxInfo.Instances.Bits.VDBox1Enabled))
+    {
+        eStatus = MOS_STATUS_INVALID_PARAMETER;
+        MHW_ASSERTMESSAGE("the forced VDBOX is not enabled in current platform.");
+        return eStatus;
+    }
+
+    return eStatus;
+}
+#endif
+
+MOS_STATUS MediaContext::FindGpuNodeToUse(MediaFunction func, PMHW_VDBOX_GPUNODE_LIMIT gpuNodeLimit)
+{
+    bool       setVideoNode = false;
+    MOS_STATUS eStatus      = MOS_STATUS_SUCCESS;
+
+    MOS_GPU_NODE videoGpuNode = MOS_GPU_NODE_VIDEO;
+
+    if (MOS_VE_MULTINODESCALING_SUPPORTED(m_osInterface))
+    {
+        if (GetNumVdbox() == 1)
+        {
+            videoGpuNode = MOS_GPU_NODE_VIDEO;
+        }
+        else
+        {
+            if (m_curNodeOrdinal == MOS_GPU_NODE_VIDEO || m_curNodeOrdinal == MOS_GPU_NODE_VIDEO2)
+            {
+                m_osInterface->pfnDestroyVideoNodeAssociation(m_osInterface, m_curNodeOrdinal);
+                if (func == VdboxEncodeFunc)
+                {
+                    m_osInterface->pfnSetLatestVirtualNode(m_osInterface, MOS_GPU_NODE_MAX);
+                }
+            }
+            if (func == VdboxDecodeVirtualNode0Func)
+            {
+                setVideoNode = true;
+                videoGpuNode = MOS_GPU_NODE_VIDEO;
+            }
+            else if (func == VdboxDecodeVirtualNode1Func)
+            {
+                setVideoNode = true;
+                videoGpuNode = MOS_GPU_NODE_VIDEO2;
+            }
+            else if (func == VdboxEncodeFunc)
+            {
+                MOS_GPU_NODE node = m_osInterface->pfnGetLatestVirtualNode(m_osInterface, COMPONENT_Decode);
+                if (node != MOS_GPU_NODE_MAX)
+                {
+                    setVideoNode = true;
+                    videoGpuNode = (node == MOS_GPU_NODE_VIDEO) ? MOS_GPU_NODE_VIDEO2 : MOS_GPU_NODE_VIDEO;
+                }
+            }
+            MHW_MI_CHK_STATUS(m_osInterface->pfnCreateVideoNodeAssociation(
+                m_osInterface,
+                setVideoNode,
+                &videoGpuNode));
+            m_curNodeOrdinal = videoGpuNode;
+            if (func == VdboxDecodeFunc || func == VdboxDecodeVirtualNode0Func || func == VdboxDecodeVirtualNode1Func)
+            {
+                m_osInterface->pfnSetDecoderVirtualNodePerStream(m_osInterface, m_curNodeOrdinal);
+            }
+            else if (func == VdboxEncodeFunc)
+            {
+                m_osInterface->pfnSetLatestVirtualNode(m_osInterface, m_curNodeOrdinal);
+            }
+        }
+    }
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if (m_osInterface != nullptr && m_osInterface->bEnableDbgOvrdInVE &&
+        (!m_osInterface->bSupportVirtualEngine || !m_scalabilitySupported))
+    {
+        eStatus = MOS_STATUS_INVALID_PARAMETER;
+        MHW_ASSERTMESSAGE("not support DebugOverrid on current OS or Platform.");
+        return eStatus;
+    }
+
+    if (m_osInterface != nullptr && m_osInterface->bEnableDbgOvrdInVE)
+    {
+        MHW_MI_CHK_STATUS(CheckScalabilityOverrideValidity());
+    }
+#endif
+    gpuNodeLimit->dwGpuNodeToUse = videoGpuNode;
+
+    return eStatus;
+}
+#endif
+
 MOS_STATUS MediaContext::FunctionToGpuContext(MediaFunction func, const MOS_GPUCTX_CREATOPTIONS_ENHANCED &option, const MOS_GPU_NODE &node, MOS_GPU_CONTEXT &ctx)
 {
     MOS_OS_FUNCTION_ENTER;
@@ -448,6 +646,8 @@ MOS_STATUS MediaContext::FunctionToGpuContext(MediaFunction func, const MOS_GPUC
         MOS_OS_CHK_STATUS_RETURN(FunctionToGpuContextEncode(option, ctx));
         break;
     case VdboxDecodeFunc:
+    case VdboxDecodeVirtualNode0Func:
+    case VdboxDecodeVirtualNode1Func:
         MOS_OS_CHK_STATUS_RETURN(FunctionToGpuContextDecode(option, node, ctx));
         break;
     case VdboxDecodeWaFunc:
@@ -530,3 +730,117 @@ MOS_STATUS MediaContext::FunctionToGpuContextEncode(const MOS_GPUCTX_CREATOPTION
 
     return MOS_STATUS_SUCCESS;
 }
+
+void MediaContext::SetLatestDecoderVirtualNode()
+{
+    if (m_curNodeOrdinal == MOS_GPU_NODE_VIDEO || m_curNodeOrdinal == MOS_GPU_NODE_VIDEO2)
+    {
+        m_osInterface->pfnSetLatestVirtualNode(m_osInterface, m_curNodeOrdinal);
+    }
+}
+
+MOS_STATUS MediaContext::ReassignContextForDecoder(uint32_t frameNum, ContextRequirement *requirement, MediaScalability **scalabilityState)
+{
+    if (frameNum == 0)
+    {
+        // if encoder is working, always reassign decoder to different virtual node
+        MOS_GPU_NODE encoderNode = m_osInterface->pfnGetLatestVirtualNode(m_osInterface, COMPONENT_Encode);
+        if (encoderNode == MOS_GPU_NODE_VIDEO)
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode1Func, requirement, scalabilityState));
+        }
+        else if (encoderNode == MOS_GPU_NODE_VIDEO2)
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode0Func, requirement, scalabilityState));
+        }
+        else
+        {
+            // if only decoders are working, reassign decoder to different virtual node compared to latest used virtual node
+            MOS_GPU_NODE decoderNode = m_osInterface->pfnGetLatestVirtualNode(m_osInterface, COMPONENT_Decode);
+            if (decoderNode == MOS_GPU_NODE_VIDEO)
+            {
+                MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode1Func, requirement, scalabilityState));
+            }
+            else if (decoderNode == MOS_GPU_NODE_VIDEO2)
+            {
+                MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode0Func, requirement, scalabilityState));
+            }
+            else
+            {
+                MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeFunc, requirement, scalabilityState));
+            }
+        }
+    }
+    else
+    {
+        // for remaining frames, don't change virtual node assignment
+        MOS_GPU_NODE decoderNode = m_osInterface->pfnGetDecoderVirtualNodePerStream(m_osInterface);
+        if (decoderNode == MOS_GPU_NODE_VIDEO)
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode0Func, requirement, scalabilityState));
+        }
+        else if (decoderNode == MOS_GPU_NODE_VIDEO2)
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode1Func, requirement, scalabilityState));
+        }
+        else
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeFunc, requirement, scalabilityState));
+        }
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS MediaContext::ReassignContextForDecoder(uint32_t frameNum, MediaScalabilityOption &scalabilityOption, MediaScalability **scalabilityState)
+{
+    if (frameNum == 0)
+    {
+        // if encoder is working, always reassign decoder to different virtual node
+        MOS_GPU_NODE encoderNode = m_osInterface->pfnGetLatestVirtualNode(m_osInterface, COMPONENT_Encode);
+        if (encoderNode == MOS_GPU_NODE_VIDEO)
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode1Func, scalabilityOption, scalabilityState));
+        }
+        else if (encoderNode == MOS_GPU_NODE_VIDEO2)
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode0Func, scalabilityOption, scalabilityState));
+        }
+        else
+        {
+            // if only decoders are working, reassign decoder to different virtual node compared to latest used virtual node
+            MOS_GPU_NODE decoderNode = m_osInterface->pfnGetLatestVirtualNode(m_osInterface, COMPONENT_Decode);
+            if (decoderNode == MOS_GPU_NODE_VIDEO)
+            {
+                MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode1Func, scalabilityOption, scalabilityState));
+            }
+            else if (decoderNode == MOS_GPU_NODE_VIDEO2)
+            {
+                MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode0Func, scalabilityOption, scalabilityState));
+            }
+            else
+            {
+                MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeFunc, scalabilityOption, scalabilityState));
+            }
+        }
+    }
+    else
+    {
+        // for remaining frames, don't change virtual node assignment
+        MOS_GPU_NODE decoderNode = m_osInterface->pfnGetDecoderVirtualNodePerStream(m_osInterface);
+        if (decoderNode == MOS_GPU_NODE_VIDEO)
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode0Func, scalabilityOption, scalabilityState));
+        }
+        else if (decoderNode == MOS_GPU_NODE_VIDEO2)
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeVirtualNode1Func, scalabilityOption, scalabilityState));
+        }
+        else
+        {
+            MOS_OS_CHK_STATUS_RETURN(SwitchContext(VdboxDecodeFunc, scalabilityOption, scalabilityState));
+        }
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
