@@ -81,7 +81,7 @@ public:
         while (!kernelObjs.empty())
         {
             auto it = kernelObjs.begin();
-            if (m_cachedKernels.end() == m_cachedKernels.find(it->second->GetKernelId()))
+            if (m_cachedKernels.size() == 0 || m_cachedKernels.end() == m_cachedKernels.find(it->second->GetKernelId()))
             {
                 // Only destroy the kernels not exists in m_cachedKernels.
                 MOS_Delete(it->second);
@@ -93,7 +93,7 @@ public:
     }
 protected:
 
-    MOS_STATUS GetKernelInfo(uint32_t kuid, uint32_t& size, void*& kernel);
+    MOS_STATUS GetKernelInfo(std::string kernalName, uint32_t kuid, uint32_t &size, void *&kernel);
 
     MOS_STATUS FindAndInitKernelObj(VpRenderKernelObj* kernelObj);
 
@@ -103,7 +103,7 @@ protected:
     PVpAllocator          m_allocator   = nullptr;
     std::map<VpKernelID, VpRenderKernelObj *> m_cachedKernels;
 
-MEDIA_CLASS_DEFINE_END(VpKernelSet)
+MEDIA_CLASS_DEFINE_END(vp__VpKernelSet)
 };
 }
 
