@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2022, Intel Corporation
+* Copyright (c) 2018-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -30,10 +30,8 @@
 #include "vp_utils.h"
 #include "hw_filter.h"
 #include "sw_filter_pipe.h"
-#ifndef ENABLE_VP_SOFTLET_BUILD
-#include "vp_vebox_cmd_packet_legacy.h"
-#endif
 #include "vp_platform_interface.h"
+#include "vp_hal_ddi_utils.h"
 
 using namespace vp;
 
@@ -76,7 +74,6 @@ MOS_STATUS VpScalingFilter::SfcAdjustBoundary(
 
     VP_PUBLIC_CHK_NULL_RETURN(m_pvpMhwInterface);
     VP_PUBLIC_CHK_NULL_RETURN(m_pvpMhwInterface->m_vpPlatformInterface);
-    //VP_PUBLIC_CHK_NULL_RETURN(m_pvpMhwInterface->m_sfcInterface);
     VP_PUBLIC_CHK_NULL_RETURN(pdwSurfaceWidth);
     VP_PUBLIC_CHK_NULL_RETURN(pdwSurfaceHeight);
 
@@ -127,18 +124,23 @@ void VpScalingFilter::GetFormatWidthHeightAlignUnit(
     bool bOutput,
     bool bRotateNeeded,
     uint16_t & widthAlignUnit,
-    uint16_t & heightAlignUnit)
+    uint16_t & heightAlignUnit,
+    bool isInterlacedScaling)
 {
     VP_FUNC_CALL();
 
     widthAlignUnit = 1;
     heightAlignUnit = 1;
 
-    switch (VpUtils::GetSurfaceColorPack(format))
+    switch (VpHalDDIUtils::GetSurfaceColorPack(format))
     {
     case VPHAL_COLORPACK_420:
         widthAlignUnit = 2;
         heightAlignUnit = 2;
+        if (isInterlacedScaling && bOutput)
+        {
+            heightAlignUnit = 4;
+        }
         break;
     case VPHAL_COLORPACK_422:
         widthAlignUnit = 2;
@@ -196,7 +198,7 @@ MOS_STATUS VpScalingFilter::SetColorFillParams()
             // Clean history Dst BG Color if hit unsupported format
             if (!VpUtils::GetCscMatrixForRender8Bit(&m_colorFillColorDst, &Src, src_cspace, dst_cspace))
             {
-                VP_PUBLIC_NORMALMESSAGE("VpHal_CSC_8 failed!");
+                VP_PUBLIC_NORMALMESSAGE("VpUtils::GetCscMatrixForRender8Bit failed!");
                 MOS_ZeroMemory(&m_colorFillColorDst, sizeof(m_colorFillColorDst));
             }
             // store the values for next iteration
@@ -318,8 +320,8 @@ MOS_STATUS VpScalingFilter::SetRectSurfaceAlignment(bool isOutputSurf, uint32_t
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
     GetFormatWidthHeightAlignUnit(isOutputSurf ? m_scalingParams.formatOutput : m_scalingParams.formatInput,
-        isOutputSurf, m_scalingParams.rotation.rotationNeeded, wWidthAlignUnit, wHeightAlignUnit);
-    GetFormatWidthHeightAlignUnit(m_scalingParams.formatOutput, true, m_scalingParams.rotation.rotationNeeded, wWidthAlignUnitForDstRect, wHeightAlignUnitForDstRect);
+        isOutputSurf, m_scalingParams.rotation.rotationNeeded, wWidthAlignUnit, wHeightAlignUnit, false);
+    GetFormatWidthHeightAlignUnit(m_scalingParams.formatOutput, true, m_scalingParams.rotation.rotationNeeded, wWidthAlignUnitForDstRect, wHeightAlignUnitForDstRect, false);
 
     // The source rectangle is floored to the aligned unit to
     // get rid of invalid data(ex: an odd numbered src rectangle with NV12 format
@@ -519,7 +521,8 @@ MOS_STATUS VpScalingFilter::CalculateEngineParams()
             true,
             m_scalingParams.rotation.rotationNeeded,
             wOutputWidthAlignUnit,
-            wOutputHeightAlignUnit);
+            wOutputHeightAlignUnit,
+            m_scalingParams.interlacedScalingType == ISCALING_INTERLEAVED_TO_INTERLEAVED);
 
         // Apply alignment restriction to Region of the input frame.
         GetFormatWidthHeightAlignUnit(
@@ -527,7 +530,8 @@ MOS_STATUS VpScalingFilter::CalculateEngineParams()
             false,
             m_scalingParams.rotation.rotationNeeded,
             wInputWidthAlignUnit,
-            wInputHeightAlignUnit);
+            wInputHeightAlignUnit,
+            m_scalingParams.interlacedScalingType == ISCALING_INTERLEAVED_TO_INTERLEAVED);
 
         m_sfcScalingParams->dwOutputFrameHeight = MOS_ALIGN_CEIL(m_scalingParams.output.dwHeight, wOutputHeightAlignUnit);
         m_sfcScalingParams->dwOutputFrameWidth  = MOS_ALIGN_CEIL(m_scalingParams.output.dwWidth, wOutputWidthAlignUnit);
@@ -726,18 +730,11 @@ bool VpSfcScalingParameter::SetPacketParam(VpCmdPacket *pPacket)
         return false;
     }
 
-    VpVeboxCmdPacket *packet = dynamic_cast<VpVeboxCmdPacket *>(pPacket);
+    VpVeboxCmdPacketBase *packet = dynamic_cast<VpVeboxCmdPacketBase *>(pPacket);
     if (packet)
     {
         return MOS_SUCCEEDED(packet->SetScalingParams(params));
     }
-#ifndef ENABLE_VP_SOFTLET_BUILD
-    VpVeboxCmdPacketLegacy *packetLegacy = dynamic_cast<VpVeboxCmdPacketLegacy *>(pPacket);
-    if (packetLegacy)
-    {
-        return MOS_SUCCEEDED(packetLegacy->SetScalingParams(params));
-    }
-#endif
 
     VP_PUBLIC_ASSERTMESSAGE("Invalid packet for sfc scaling");
     return false;
@@ -917,6 +914,7 @@ MOS_STATUS PolicySfcScalingHandler::UpdateFeaturePipe(VP_EXECUTE_CAPS caps, SwFi
         {
             SwFilterScaling *filter2ndPass = featureScaling;
             SwFilterScaling *filter1ndPass = (SwFilterScaling *)feature.Clone();
+            VP_PUBLIC_CHK_NULL_RETURN(filter1ndPass);
 
             filter1ndPass->GetFilterEngineCaps().value = 0;
             filter1ndPass->SetFeatureType(FeatureType::FeatureTypeScaling);
@@ -975,10 +973,8 @@ MOS_STATUS PolicySfcScalingHandler::UpdateUnusedFeature(VP_EXECUTE_CAPS caps, Sw
         0 == caps.bOutputPipeFeatureInuse &&
         !feature.GetFilterEngineCaps().bEnabled)
     {
-        // To avoid scaling filter being destroyed in Policy::UpdateFeaturePipe.
-        feature.GetFilterEngineCaps().value = 0;
-        feature.GetFilterEngineCaps().forceEnableForSfc = 1;
-        feature.GetFilterEngineCaps().forceEnableForRender = 1;
+        // feature.GetFilterEngineCaps().usedForNextPass should be used here to
+        // avoid scaling filter being destroyed in Policy::UpdateFeaturePipe.
         feature.GetFilterEngineCaps().usedForNextPass = 1;
     }
     return MOS_STATUS_SUCCESS;
