@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2021, Intel Corporation
+* Copyright (c) 2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -33,22 +33,24 @@
 #include "mhw_sfc.h"
 #include "vp_render_ief.h"
 #include "mos_interface.h"
+#include "mhw_sfc_itf.h"
+#include "mhw_mi_itf.h"
+#include "vp_platform_interface.h"
+#include "vp_hal_ddi_utils.h"
 
 namespace vp {
 
 SfcRenderBase::SfcRenderBase(
     VP_MHWINTERFACE &vpMhwinterface,
-    PVpAllocator &allocator):
-    m_allocator(allocator)
+    PVpAllocator &allocator,
+    bool disbaleSfcDithering) :
+    m_allocator(allocator),
+    m_disableSfcDithering(disbaleSfcDithering)
 {
     VP_PUBLIC_CHK_NULL_NO_STATUS_RETURN(vpMhwinterface.m_osInterface);
-    VP_PUBLIC_CHK_NULL_NO_STATUS_RETURN(vpMhwinterface.m_sfcInterface);
-    VP_PUBLIC_CHK_NULL_NO_STATUS_RETURN(vpMhwinterface.m_mhwMiInterface);
     VP_PUBLIC_CHK_NULL_NO_STATUS_RETURN(vpMhwinterface.m_skuTable);
     VP_PUBLIC_CHK_NULL_NO_STATUS_RETURN(vpMhwinterface.m_waTable);
     m_osInterface   = vpMhwinterface.m_osInterface;
-    m_sfcInterface  = vpMhwinterface.m_sfcInterface;
-    m_miInterface   = vpMhwinterface.m_mhwMiInterface;
     m_skuTable      = vpMhwinterface.m_skuTable;
     m_waTable       = vpMhwinterface.m_waTable;
 
@@ -57,6 +59,9 @@ SfcRenderBase::SfcRenderBase(
       &m_AvsParameters,
       k_YCoefficientTableSize,
       k_UVCoefficientTableSize);
+
+    m_sfcItf = vpMhwinterface.m_vpPlatformInterface->GetMhwSfcItf();
+    m_miItf = vpMhwinterface.m_vpPlatformInterface->GetMhwMiItf();
 }
 
 SfcRenderBase::~SfcRenderBase()
@@ -83,7 +88,7 @@ MOS_STATUS SfcRenderBase::Init()
     MOS_ZeroMemory(&m_renderData, sizeof(m_renderData));
 
     m_bVdboxToSfc = false;
-    m_pipeMode = MhwSfcInterface::SFC_PIPE_MODE_VEBOX;
+    m_pipeMode = mhw::sfc::SFC_PIPE_MODE_VEBOX;
 
     m_scalabilityParams.numPipe = 1;
     m_scalabilityParams.curPipe = 0;
@@ -102,7 +107,7 @@ MOS_STATUS SfcRenderBase::SetCodecPipeMode(CODECHAL_STANDARD codecStandard)
         CODECHAL_VP8 == codecStandard ||
         CODECHAL_JPEG == codecStandard)
     {
-        m_pipeMode = MhwSfcInterface::SFC_PIPE_MODE_VDBOX;
+        m_pipeMode = mhw::sfc::SFC_PIPE_MODE_VDBOX;
     }
     else
     {
@@ -136,7 +141,7 @@ MOS_STATUS SfcRenderBase::Init(VIDEO_PARAMS &videoParams)
     return InitSfcStateParams();
 }
 
-void SfcRenderBase::SetRotationAndMirrowParams(PMHW_SFC_STATE_PARAMS psfcStateParams)
+void SfcRenderBase::SetRotationAndMirrowParams(mhw::sfc::SFC_STATE_PAR *psfcStateParams)
 {
     VP_FUNC_CALL();
 
@@ -147,7 +152,7 @@ void SfcRenderBase::SetRotationAndMirrowParams(PMHW_SFC_STATE_PARAMS psfcStatePa
     psfcStateParams->dwMirrorType  = m_renderData.mirrorType;
 }
 
-void SfcRenderBase::SetChromasitingParams(PMHW_SFC_STATE_PARAMS psfcStateParams)
+void SfcRenderBase::SetChromasitingParams(mhw::sfc::SFC_STATE_PAR *psfcStateParams)
 {
     VP_FUNC_CALL();
 
@@ -157,7 +162,7 @@ void SfcRenderBase::SetChromasitingParams(PMHW_SFC_STATE_PARAMS psfcStateParams)
 }
 
 void SfcRenderBase::SetColorFillParams(
-    PMHW_SFC_STATE_PARAMS       psfcStateParams)
+    mhw::sfc::SFC_STATE_PAR       *psfcStateParams)
 {
     VP_FUNC_CALL();
 
@@ -175,7 +180,7 @@ void SfcRenderBase::SetColorFillParams(
 }
 
 void SfcRenderBase::SetXYAdaptiveFilter(
-    PMHW_SFC_STATE_PARAMS       psfcStateParams)
+    mhw::sfc::SFC_STATE_PAR       *psfcStateParams)
 {
     VP_FUNC_CALL();
 
@@ -201,7 +206,7 @@ void SfcRenderBase::SetXYAdaptiveFilter(
 }
 
 void SfcRenderBase::SetRGBAdaptive(
-    PMHW_SFC_STATE_PARAMS       psfcStateParams)
+    mhw::sfc::SFC_STATE_PAR       *psfcStateParams)
 {
     VP_FUNC_CALL();
 
@@ -219,8 +224,8 @@ void SfcRenderBase::SetRGBAdaptive(
 }
 
 MOS_STATUS SfcRenderBase::SetIefStateCscParams(
-    PMHW_SFC_STATE_PARAMS           psfcStateParams,
-    PMHW_SFC_IEF_STATE_PARAMS       pIEFStateParams)
+    mhw::sfc::SFC_STATE_PAR           *psfcStateParams,
+    mhw::sfc::SFC_IEF_STATE_PAR       *pIEFStateParams)
 {
     VP_FUNC_CALL();
 
@@ -235,6 +240,7 @@ MOS_STATUS SfcRenderBase::SetIefStateCscParams(
         pIEFStateParams->bCSCEnable = true;
         if (m_bVdboxToSfc && m_videoConfig.codecStandard == CODECHAL_JPEG)
         {
+            m_cscInputSwapNeeded = false;
             if (m_videoConfig.jpeg.jpegChromaType == jpegRGB)
             {
                 m_cscCoeff[0] = 1.000000000f;
@@ -288,7 +294,7 @@ MOS_STATUS SfcRenderBase::SetIefStateCscParams(
         else if ((m_cscInputCspace != m_renderData.SfcInputCspace) ||
                 (m_renderData.pSfcPipeOutSurface && m_cscRTCspace != m_renderData.pSfcPipeOutSurface->ColorSpace))
         {
-            VpHal_GetCscMatrix(
+            VpUtils::GetCscMatrixForVeSfc8Bit(
                 m_renderData.SfcInputCspace,
                 m_renderData.pSfcPipeOutSurface->ColorSpace,
                 m_cscCoeff,
@@ -311,11 +317,47 @@ MOS_STATUS SfcRenderBase::SetIefStateCscParams(
                 m_cscCoeff[2] = fTemp[0];
                 m_cscCoeff[5] = fTemp[1];
                 m_cscCoeff[8] = fTemp[2];
+                m_cscInputSwapNeeded = true;
             }
+            else
+            {
+                m_cscInputSwapNeeded = false;
+            }
+
+            VP_RENDER_NORMALMESSAGE("sfc csc coeff calculated. (sfcInputCspace, cscRTCspace) current (%d, %d), previous (%d, %d), swap flag %d",
+                m_renderData.SfcInputCspace, m_renderData.pSfcPipeOutSurface->ColorSpace,
+                m_cscInputCspace, m_cscRTCspace, m_cscInputSwapNeeded ? 1 :0);
 
             m_cscInputCspace = m_renderData.SfcInputCspace;
             m_cscRTCspace    = m_renderData.pSfcPipeOutSurface->ColorSpace;
         }
+        else if (m_cscInputSwapNeeded != IsInputChannelSwapNeeded(m_renderData.SfcInputFormat))
+        {
+            float fTemp[3] = {};
+            fTemp[0]       = m_cscCoeff[0];
+            fTemp[1]       = m_cscCoeff[3];
+            fTemp[2]       = m_cscCoeff[6];
+
+            m_cscCoeff[0] = m_cscCoeff[2];
+            m_cscCoeff[3] = m_cscCoeff[5];
+            m_cscCoeff[6] = m_cscCoeff[8];
+
+            m_cscCoeff[2]   = fTemp[0];
+            m_cscCoeff[5]   = fTemp[1];
+            m_cscCoeff[8]   = fTemp[2];
+
+            m_cscInputSwapNeeded = IsInputChannelSwapNeeded(m_renderData.SfcInputFormat);
+
+            VP_RENDER_NORMALMESSAGE("sfc csc coeff swap flag need be updated to %d. sfcInputFormat %d, sfcInputCspace %d, cscRTCspace %d",
+                (m_cscInputSwapNeeded ? 1 : 0),
+                m_renderData.SfcInputFormat, m_cscInputCspace, m_cscRTCspace);
+        }
+        else
+        {
+            VP_RENDER_NORMALMESSAGE("sfc csc coeff reused. sfcInputFormat %d, sfcInputCspace %d, cscRTCspace %d, swap flag %d",
+                m_renderData.SfcInputFormat, m_cscInputCspace, m_cscRTCspace, (m_cscInputSwapNeeded ? 1 : 0));
+        }
+
         pIEFStateParams->pfCscCoeff     = m_cscCoeff;
         pIEFStateParams->pfCscInOffset  = m_cscInOffset;
         pIEFStateParams->pfCscOutOffset = m_cscOutOffset;
@@ -324,16 +366,17 @@ MOS_STATUS SfcRenderBase::SetIefStateCscParams(
 }
 
 MOS_STATUS SfcRenderBase::SetIefStateParams(
-    PMHW_SFC_STATE_PARAMS           psfcStateParams)
+    mhw::sfc::SFC_STATE_PAR           *psfcStateParams)
 {
     VP_FUNC_CALL();
 
-    PMHW_SFC_IEF_STATE_PARAMS   pIefStateParams = nullptr;
+    mhw::sfc::SFC_IEF_STATE_PAR   *pIefStateParams = nullptr;
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
     VP_RENDER_CHK_NULL_RETURN(psfcStateParams);
 
-    pIefStateParams = &m_IefStateParams;
+    auto &iefStateParams = m_sfcItf->MHW_GETPAR_F(SFC_IEF_STATE)();
+    pIefStateParams      = &iefStateParams;
     MOS_ZeroMemory(pIefStateParams, sizeof(*pIefStateParams));
     pIefStateParams->sfcPipeMode = m_pipeMode;
 
@@ -358,22 +401,25 @@ MOS_STATUS SfcRenderBase::SetAvsStateParams()
     VP_FUNC_CALL();
 
     MOS_STATUS                  eStatus            = MOS_STATUS_SUCCESS;
-    PMHW_SFC_AVS_STATE          pMhwAvsState       = nullptr;
+    mhw::sfc::SFC_AVS_STATE_PAR *pMhwAvsState       = nullptr;
     MHW_SCALING_MODE            scalingMode        = MHW_SCALING_AVS;
     bool                        bUse8x8Filter      = false;
 
-    VP_RENDER_CHK_NULL_RETURN(m_sfcInterface);
-
-    pMhwAvsState = &m_avsState.AvsStateParams;
+    auto &avsStateParams = m_sfcItf->MHW_GETPAR_F(SFC_AVS_STATE)();
+    pMhwAvsState         = &avsStateParams;
     MOS_ZeroMemory(pMhwAvsState, sizeof(MHW_SFC_AVS_STATE));
     pMhwAvsState->sfcPipeMode = m_pipeMode;
 
+    VP_RENDER_NORMALMESSAGE("bScaling %d, bForcePolyPhaseCoefs %d",
+        (m_renderData.bScaling ? 1 :0),
+        (m_renderData.bForcePolyPhaseCoefs ? 1 : 0));
+
     if (m_renderData.bScaling ||
         m_renderData.bForcePolyPhaseCoefs)
     {
         if (m_renderData.SfcSrcChromaSiting == MHW_CHROMA_SITING_NONE)
         {
-            if (VpHal_GetSurfaceColorPack(m_renderData.SfcInputFormat) == VPHAL_COLORPACK_420) // For 420, default is Left & Center, else default is Left & Top
+            if (VpHalDDIUtils::GetSurfaceColorPack(m_renderData.SfcInputFormat) == VPHAL_COLORPACK_420) // For 420, default is Left & Center, else default is Left & Top
             {
                 m_renderData.SfcSrcChromaSiting = MHW_CHROMA_SITING_HORZ_LEFT | MHW_CHROMA_SITING_VERT_CENTER;
             }
@@ -403,7 +449,7 @@ MOS_STATUS SfcRenderBase::SetAvsStateParams()
         {
             scalingMode = MHW_SCALING_AVS;
         }
-        VP_RENDER_CHK_STATUS_RETURN(m_sfcInterface->SetSfcAVSScalingMode(scalingMode));
+        VP_RENDER_CHK_STATUS_RETURN(SetSfcAVSScalingMode(scalingMode));
 
         if (m_renderData.sfcStateParams)
         {
@@ -419,12 +465,18 @@ MOS_STATUS SfcRenderBase::SetAvsStateParams()
             bUse8x8Filter = true;
         }
 
-        m_avsState.LumaCoeffs.sfcPipeMode   = m_pipeMode;
-        m_avsState.ChromaCoeffs.sfcPipeMode = m_pipeMode;
+        // directly get the par of SFC_AVS_LUMA_Coeff_Table_PAR  and initialize.
+        auto &lumaCoeffs = m_sfcItf->MHW_GETPAR_F(SFC_AVS_LUMA_Coeff_Table)();
 
-        VP_RENDER_CHK_STATUS_RETURN(m_sfcInterface->SetSfcSamplerTable(
-            &m_avsState.LumaCoeffs,
-            &m_avsState.ChromaCoeffs,
+        // directly get the par of SFC_AVS_CHROMA_Coeff_Table  and initialize.
+        auto &chromaCoeffs = m_sfcItf->MHW_GETPAR_F(SFC_AVS_CHROMA_Coeff_Table)();
+
+        lumaCoeffs.sfcPipeMode              = m_pipeMode;
+        chromaCoeffs.sfcPipeMode            = m_pipeMode;
+
+        VP_RENDER_CHK_STATUS_RETURN(SetSfcSamplerTable(
+            &lumaCoeffs,
+            &chromaCoeffs,
             m_renderData.pAvsParams,
             m_renderData.SfcInputFormat,
             m_renderData.fScaleX,
@@ -534,6 +586,47 @@ MOS_STATUS SfcRenderBase::SetupSfcState(PVP_SURFACE targetSurface)
 
     VP_RENDER_CHK_STATUS_RETURN(SetupScalabilityParams());
 
+    // Decompress resource if surfaces need write from a un-align offset
+    if ((targetSurface->osSurface->CompressionMode != MOS_MMC_DISABLED)        &&
+        IsSFCUncompressedWriteNeeded(targetSurface))
+    {
+        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+        MOS_SURFACE details = {};
+
+        m_osInterface->pfnSyncOnResource(
+            m_osInterface,
+            &targetSurface->osSurface->OsResource,
+            MOS_GPU_CONTEXT_VEBOX,
+            true);
+
+        eStatus = m_osInterface->pfnGetResourceInfo(m_osInterface, &targetSurface->osSurface->OsResource, &details);
+
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            VP_RENDER_ASSERTMESSAGE("Get SFC target surface resource info failed.");
+        }
+
+        if (!targetSurface->osSurface->OsResource.bUncompressedWriteNeeded)
+        {
+            eStatus = m_osInterface->pfnDecompResource(m_osInterface, &targetSurface->osSurface->OsResource);
+
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                VP_RENDER_ASSERTMESSAGE("inplace decompression failed for sfc target.");
+            }
+            else
+            {
+                VP_RENDER_NORMALMESSAGE("inplace decompression enabled for sfc target RECT is not compression block align.");
+                targetSurface->osSurface->OsResource.bUncompressedWriteNeeded = 1;
+            }
+        }
+    }
+
+    if (targetSurface->osSurface->OsResource.bUncompressedWriteNeeded)
+    {
+        m_renderData.sfcStateParams->MMCMode = MOS_MMC_RC;
+    }
+
     return eStatus;
 }
 
@@ -543,7 +636,7 @@ MOS_STATUS SfcRenderBase::SetScalingParams(PSFC_SCALING_PARAMS scalingParams)
 
     VP_PUBLIC_CHK_NULL_RETURN(scalingParams);
 
-    if (MhwSfcInterface::SFC_PIPE_MODE_VEBOX != m_pipeMode                          &&
+    if (mhw::sfc::SFC_PIPE_MODE_VEBOX      != m_pipeMode                          &&
         (scalingParams->dwInputFrameHeight != scalingParams->dwSourceRegionHeight   ||
         scalingParams->dwInputFrameWidth != scalingParams->dwSourceRegionWidth))
     {
@@ -572,7 +665,7 @@ MOS_STATUS SfcRenderBase::SetScalingParams(PSFC_SCALING_PARAMS scalingParams)
     m_renderData.sfcStateParams->dwInputFrameWidth              = scalingParams->dwInputFrameWidth;
     m_renderData.sfcStateParams->dwAVSFilterMode                = scalingParams->bBilinearScaling ?
                                                                     MEDIASTATE_SFC_AVS_FILTER_BILINEAR :
-                                                                    (MhwSfcInterface::SFC_PIPE_MODE_VDBOX == m_pipeMode ?
+                                                                    (mhw::sfc::SFC_PIPE_MODE_VDBOX == m_pipeMode ?
                                                                         MEDIASTATE_SFC_AVS_FILTER_5x5 : MEDIASTATE_SFC_AVS_FILTER_8x8);
     m_renderData.sfcStateParams->dwSourceRegionHeight           = scalingParams->dwSourceRegionHeight;
     m_renderData.sfcStateParams->dwSourceRegionWidth            = scalingParams->dwSourceRegionWidth;
@@ -582,6 +675,18 @@ MOS_STATUS SfcRenderBase::SetScalingParams(PSFC_SCALING_PARAMS scalingParams)
     m_renderData.sfcStateParams->dwScaledRegionWidth            = scalingParams->dwScaledRegionWidth;
     m_renderData.sfcStateParams->dwScaledRegionVerticalOffset   = scalingParams->dwScaledRegionVerticalOffset;
     m_renderData.sfcStateParams->dwScaledRegionHorizontalOffset = scalingParams->dwScaledRegionHorizontalOffset;
+    if (scalingParams->bRectangleEnabled)
+    {
+        m_renderData.sfcStateParams->bRectangleEnabled                      = true;
+        m_renderData.sfcStateParams->dwTargetRectangleStartHorizontalOffset = scalingParams->dwTargetRectangleStartHorizontalOffset;
+        m_renderData.sfcStateParams->dwTargetRectangleStartVerticalOffset   = scalingParams->dwTargetRectangleStartVerticalOffset;
+        m_renderData.sfcStateParams->dwTargetRectangleEndHorizontalOffset   = scalingParams->dwTargetRectangleEndHorizontalOffset;
+        m_renderData.sfcStateParams->dwTargetRectangleEndVerticalOffset     = scalingParams->dwTargetRectangleEndVerticalOffset;
+    }
+    else
+    {
+        m_renderData.sfcStateParams->bRectangleEnabled = false;
+    }
     m_renderData.sfcStateParams->fAVSXScalingRatio              = scalingParams->fAVSXScalingRatio;
     m_renderData.sfcStateParams->fAVSYScalingRatio              = scalingParams->fAVSYScalingRatio;
 
@@ -611,6 +716,13 @@ MOS_STATUS SfcRenderBase::SetScalingParams(PSFC_SCALING_PARAMS scalingParams)
         VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
     }
 
+    VP_RENDER_NORMALMESSAGE("fScaleX %f, fScaleY %f, bScaling %d, SfcScalingMode %d, SfcInputFormat %d, bRectangleEnabled",
+        m_renderData.fScaleX, m_renderData.fScaleY,
+        (m_renderData.bScaling ? 1 : 0),
+        m_renderData.SfcScalingMode,
+        m_renderData.SfcInputFormat,
+        (scalingParams->bRectangleEnabled ? 1: 0));
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -731,13 +843,29 @@ bool SfcRenderBase::IsInputChannelSwapNeeded(MOS_FORMAT inputFormat)
     }
 }
 
+MOS_STATUS SfcRenderBase::UpdateIefParams(PVPHAL_IEF_PARAMS iefParams)
+{
+    VP_FUNC_CALL();
+    m_renderData.bIEF           = (iefParams &&
+        iefParams->bEnabled &&
+        iefParams->fIEFFactor > 0.0F);
+    m_renderData.pIefParams     = iefParams;
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SfcRenderBase::UpdateCscParams(FeatureParamCsc &cscParams)
+{
+    VP_RENDER_CHK_STATUS_RETURN(UpdateIefParams(cscParams.pIEFParams));
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS SfcRenderBase::SetCSCParams(PSFC_CSC_PARAMS cscParams)
 {
     VP_FUNC_CALL();
 
     VP_PUBLIC_CHK_NULL_RETURN(cscParams);
 
-    if (MhwSfcInterface::SFC_PIPE_MODE_VEBOX == m_pipeMode)
+    if (mhw::sfc::SFC_PIPE_MODE_VEBOX == m_pipeMode)
     {
         m_renderData.bIEF           = cscParams->bIEFEnable;
         m_renderData.pIefParams     = cscParams->iefParams;
@@ -758,10 +886,20 @@ MOS_STATUS SfcRenderBase::SetCSCParams(PSFC_CSC_PARAMS cscParams)
     m_renderData.sfcStateParams->bRGBASwapEnable = IsOutputChannelSwapNeeded(cscParams->outputFormat);
     m_renderData.sfcStateParams->bInputColorSpace = cscParams->isInputColorSpaceRGB;
 
+    // Dithering parameter
+    if (cscParams->isDitheringNeeded && !m_disableSfcDithering)
+    {
+        m_renderData.sfcStateParams->ditheringEn = true;
+    }
+    else
+    {
+        m_renderData.sfcStateParams->ditheringEn = false;
+    }
+
     // Chromasitting config
     // VEBOX use polyphase coefficients for 1x scaling for better quality,
     // VDBOX dosen't use polyphase coefficients.
-    if (MhwSfcInterface::SFC_PIPE_MODE_VEBOX == m_pipeMode)
+    if (mhw::sfc::SFC_PIPE_MODE_VEBOX == m_pipeMode)
     {
         m_renderData.bForcePolyPhaseCoefs = cscParams->bChromaUpSamplingEnable;
     }
@@ -778,6 +916,10 @@ MOS_STATUS SfcRenderBase::SetCSCParams(PSFC_CSC_PARAMS cscParams)
     m_renderData.sfcStateParams->dwChromaDownSamplingHorizontalCoef = cscParams->chromaDownSamplingHorizontalCoef;
     m_renderData.sfcStateParams->dwChromaDownSamplingVerticalCoef   = cscParams->chromaDownSamplingVerticalCoef;
 
+    VP_RENDER_NORMALMESSAGE("cscParams.isDitheringNeeded %d, m_disableSfcDithering %d, ditheringEn %d, bForcePolyPhaseCoefs %d", 
+        cscParams->isDitheringNeeded, m_disableSfcDithering, m_renderData.sfcStateParams->ditheringEn,
+        (m_renderData.bForcePolyPhaseCoefs ? 1 : 0));
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -788,7 +930,7 @@ MOS_STATUS SfcRenderBase::SetRotMirParams(PSFC_ROT_MIR_PARAMS rotMirParams)
 
     VP_PUBLIC_CHK_NULL_RETURN(rotMirParams);
 
-    if (MhwSfcInterface::SFC_PIPE_MODE_VEBOX != m_pipeMode      &&
+    if (mhw::sfc::SFC_PIPE_MODE_VEBOX != m_pipeMode      &&
         VPHAL_ROTATION_IDENTITY != rotMirParams->rotationMode   &&
         VPHAL_MIRROR_HORIZONTAL != rotMirParams->rotationMode)
     {
@@ -828,6 +970,11 @@ MOS_STATUS SfcRenderBase::SetMmcParams(PMOS_SURFACE renderTarget, bool isFormalM
     {
         m_renderData.sfcStateParams->bMMCEnable = true;
         m_renderData.sfcStateParams->MMCMode    = renderTarget->CompressionMode;
+
+        if (renderTarget->OsResource.bUncompressedWriteNeeded)
+        {
+            m_renderData.sfcStateParams->MMCMode = MOS_MMC_RC;
+        }
     }
     else
     {
@@ -839,12 +986,12 @@ MOS_STATUS SfcRenderBase::SetMmcParams(PMOS_SURFACE renderTarget, bool isFormalM
 }
 
 MOS_STATUS SfcRenderBase::SetSfcStateInputChromaSubSampling(
-    PMHW_SFC_STATE_PARAMS       sfcStateParams)
+    mhw::sfc::SFC_STATE_PAR       *sfcStateParams)
 {
     VP_FUNC_CALL();
 
     VP_PUBLIC_CHK_NULL_RETURN(sfcStateParams);
-    VPHAL_COLORPACK colorPack = VpHal_GetSurfaceColorPack(m_renderData.SfcInputFormat);
+    VPHAL_COLORPACK colorPack = VpHalDDIUtils::GetSurfaceColorPack(m_renderData.SfcInputFormat);
     if (VPHAL_COLORPACK_400 == colorPack)
     {
         sfcStateParams->dwInputChromaSubSampling = MEDIASTATE_SFC_CHROMA_SUBSAMPLING_400;
@@ -873,7 +1020,7 @@ MOS_STATUS SfcRenderBase::SetSfcStateInputChromaSubSampling(
 }
 
 MOS_STATUS SfcRenderBase::SetSfcStateInputOrderingMode(
-    PMHW_SFC_STATE_PARAMS       sfcStateParams)
+    mhw::sfc::SFC_STATE_PAR       *sfcStateParams)
 {
     VP_FUNC_CALL();
 
@@ -883,7 +1030,7 @@ MOS_STATUS SfcRenderBase::SetSfcStateInputOrderingMode(
     {
         VP_PUBLIC_CHK_STATUS_RETURN(SetSfcStateInputOrderingModeVdbox(sfcStateParams));
     }
-    else if (MhwSfcInterface::SFC_PIPE_MODE_VEBOX == m_pipeMode)
+    else if (mhw::sfc::SFC_PIPE_MODE_VEBOX == m_pipeMode)
     {
         sfcStateParams->dwVDVEInputOrderingMode = MEDIASTATE_SFC_INPUT_ORDERING_VE_4x8;
     }
@@ -899,7 +1046,7 @@ MOS_STATUS SfcRenderBase::SetSfcStateInputOrderingMode(
 }
 
 MOS_STATUS SfcRenderBase::SetSfcStateInputOrderingModeVdbox(
-    PMHW_SFC_STATE_PARAMS       sfcStateParams)
+    mhw::sfc::SFC_STATE_PAR       *sfcStateParams)
 {
     VP_FUNC_CALL();
 
@@ -930,7 +1077,7 @@ MOS_STATUS SfcRenderBase::SetSfcStateInputOrderingModeVdbox(
 }
 
 MOS_STATUS SfcRenderBase::SetSfcStateInputOrderingModeJpeg(
-    PMHW_SFC_STATE_PARAMS       sfcStateParams)
+    mhw::sfc::SFC_STATE_PAR       *sfcStateParams)
 {
     VP_FUNC_CALL();
 
@@ -968,6 +1115,12 @@ MOS_STATUS SfcRenderBase::SetSfcStateInputOrderingModeJpeg(
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS SfcRenderBase::SetSfcStateInputOrderingModeHcp(
+    mhw::sfc::SFC_STATE_PAR* pSfcStateParams)
+{
+    return MOS_STATUS_UNIMPLEMENTED;
+}
+
 MOS_STATUS SfcRenderBase::InitMhwOutSurfParams(
   PVP_SURFACE                               pSfcPipeOutSurface,
   PMHW_SFC_OUT_SURFACE_PARAMS               pMhwOutSurfParams)
@@ -1007,41 +1160,21 @@ MOS_STATUS SfcRenderBase::InitMhwOutSurfParams(
     return eStatus;
 }
 
-MOS_STATUS SfcRenderBase::AddSfcLock(
-    PMOS_COMMAND_BUFFER            pCmdBuffer,
-    PMHW_SFC_LOCK_PARAMS           pSfcLockParams)
-{
-    VP_FUNC_CALL();
-
-    VP_RENDER_CHK_NULL_RETURN(m_sfcInterface);
-
-    // Send SFC_LOCK command to acquire SFC pipe for Vebox
-    VP_RENDER_CHK_STATUS_RETURN(m_sfcInterface->AddSfcLock(
-        pCmdBuffer,
-        pSfcLockParams));
-
-    return MOS_STATUS_SUCCESS;
-}
-
 MOS_STATUS SfcRenderBase::SendSfcCmd(
     bool                            bOutputToMemory,
     PMOS_COMMAND_BUFFER             pCmdBuffer)
 {
     VP_FUNC_CALL();
 
-    PMHW_SFC_INTERFACE              pSfcInterface;
-    MHW_SFC_LOCK_PARAMS             SfcLockParams;
+    mhw::sfc::SFC_LOCK_PAR          SfcLockParams;
     MOS_STATUS                      eStatus;
     MHW_SFC_OUT_SURFACE_PARAMS      OutSurfaceParam;
 
-    VP_RENDER_CHK_NULL_RETURN(m_sfcInterface);
     VP_RENDER_CHK_NULL_RETURN(pCmdBuffer);
 
     eStatus                 = MOS_STATUS_SUCCESS;
-    pSfcInterface           = m_sfcInterface;
 
-    // Setup params for SFC Lock command
-    SfcLockParams.sfcPipeMode     = m_pipeMode;
+    SfcLockParams.sfcPipeMode = m_pipeMode;
     SfcLockParams.bOutputToMemory = bOutputToMemory;
 
     // Send SFC_LOCK command to acquire SFC pipe for Vebox
@@ -1054,41 +1187,38 @@ MOS_STATUS SfcRenderBase::SendSfcCmd(
         &OutSurfaceParam));
 
     // Send SFC_STATE command
-    VP_RENDER_CHK_STATUS_RETURN(pSfcInterface->AddSfcState(
+    VP_RENDER_CHK_STATUS_RETURN(AddSfcState(
         pCmdBuffer,
         m_renderData.sfcStateParams,
         &OutSurfaceParam));
 
     // Send SFC_AVS_STATE command
-    VP_RENDER_CHK_STATUS_RETURN(pSfcInterface->AddSfcAvsState(
-        pCmdBuffer,
-        &m_avsState.AvsStateParams));
+    VP_RENDER_CHK_STATUS_RETURN(AddSfcAvsState(
+        pCmdBuffer));
 
     if (m_renderData.bScaling ||
         m_renderData.bForcePolyPhaseCoefs)
     {
         // Send SFC_AVS_LUMA_TABLE command
-        VP_RENDER_CHK_STATUS_RETURN(pSfcInterface->AddSfcAvsLumaTable(
-            pCmdBuffer,
-            &m_avsState.LumaCoeffs));
+        VP_RENDER_CHK_STATUS_RETURN(AddSfcAvsLumaTable(
+            pCmdBuffer));
 
         // Send SFC_AVS_CHROMA_TABLE command
-        VP_RENDER_CHK_STATUS_RETURN(pSfcInterface->AddSfcAvsChromaTable(
-            pCmdBuffer,
-            &m_avsState.ChromaCoeffs));
+        VP_RENDER_CHK_STATUS_RETURN(AddSfcAvsChromaTable(
+            pCmdBuffer));
     }
 
     // Send SFC_IEF_STATE command
     if (m_renderData.bIEF || m_renderData.bCSC)
     {
         // Will modified when enable IEF/CSC
-      VP_RENDER_CHK_STATUS_RETURN(pSfcInterface->AddSfcIefState(
-            pCmdBuffer,
-            &m_IefStateParams));
+        VP_RENDER_CHK_STATUS_RETURN(AddSfcIefState(
+            pCmdBuffer));
+        //SETPAR_AND_ADDCMD(SFC_IEF_STATE, sfcItf, pCmdBuffer);
     }
 
     // Send SFC_FRAME_START command to start processing a frame
-    VP_RENDER_CHK_STATUS_RETURN(pSfcInterface->AddSfcFrameStart(
+    VP_RENDER_CHK_STATUS_RETURN(AddSfcFrameStart(
         pCmdBuffer,
         m_pipeMode));
 
@@ -1155,7 +1285,7 @@ uint32_t SfcRenderBase::GetAvsLineBufferSize(bool lineTiledBuffer, bool b8tapChr
     uint32_t size = 0;
     uint32_t linebufferSizePerPixel = 0;
 
-    if (MhwSfcInterface::SFC_PIPE_MODE_VDBOX == m_pipeMode)
+    if (mhw::sfc::SFC_PIPE_MODE_VDBOX == m_pipeMode)
     {
         if (b8tapChromafiltering)
         {
@@ -1180,7 +1310,7 @@ uint32_t SfcRenderBase::GetAvsLineBufferSize(bool lineTiledBuffer, bool b8tapChr
     }
 
     // For VD+SFC mode, width needs be used. For VE+SFC mode, height needs be used.
-    if (MhwSfcInterface::SFC_PIPE_MODE_VEBOX == m_pipeMode)
+    if (mhw::sfc::SFC_PIPE_MODE_VEBOX == m_pipeMode)
     {
         size = height * linebufferSizePerPixel;
     }
@@ -1207,7 +1337,7 @@ uint32_t SfcRenderBase::GetIefLineBufferSize(bool lineTiledBuffer, uint32_t heig
     uint32_t size = 0;
 
     // For VE+SFC mode, height needs be used.
-    if (MhwSfcInterface::SFC_PIPE_MODE_VEBOX == m_pipeMode)
+    if (mhw::sfc::SFC_PIPE_MODE_VEBOX == m_pipeMode)
     {
         size = heightOutput * SFC_IEF_LINEBUFFER_SIZE_PER_VERTICAL_PIXEL;
     }
@@ -1233,9 +1363,9 @@ uint32_t SfcRenderBase::GetSfdLineBufferSize(bool lineTiledBuffer, MOS_FORMAT fo
     int size = 0;
 
     // For VD+SFC mode, width needs be used. For VE+SFC mode, height needs be used.
-    if (MhwSfcInterface::SFC_PIPE_MODE_VEBOX == m_pipeMode)
+    if (mhw::sfc::SFC_PIPE_MODE_VEBOX == m_pipeMode)
     {
-        size = (VPHAL_COLORPACK_444 == VpHal_GetSurfaceColorPack(formatOutput)) ? 0 : (heightOutput * SFC_SFD_LINEBUFFER_SIZE_PER_PIXEL);
+        size = (VPHAL_COLORPACK_444 == VpHalDDIUtils::GetSurfaceColorPack(formatOutput)) ? 0 : (heightOutput * SFC_SFD_LINEBUFFER_SIZE_PER_PIXEL);
     }
     else
     {
@@ -1288,7 +1418,7 @@ MOS_STATUS SfcRenderBase::AllocateLineBuffer(VP_SURFACE *&lineBuffer, uint32_t s
                                       MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_FF,
                                       MOS_TILE_UNSET_GMM,
                                       memTypeSurfVideoMem,
-                                      MOS_MEMPOOL_DEVICEMEMORY == memTypeSurfVideoMem));
+                                      VPP_INTER_RESOURCE_NOTLOCKABLE));
     }
     else if (lineBuffer)
     {
@@ -1316,13 +1446,10 @@ MOS_STATUS SfcRenderBase::AllocateResources()
     VP_FUNC_CALL();
 
     uint32_t                size;
-    PMHW_SFC_STATE_PARAMS   sfcStateParams;
 
     VP_RENDER_CHK_NULL_RETURN(m_allocator);
     VP_RENDER_CHK_NULL_RETURN(m_renderData.sfcStateParams);
 
-    sfcStateParams = m_renderData.sfcStateParams;
-
     if (m_scalabilityParams.numPipe > m_lineBufferAllocatedInArray    ||
         nullptr == m_AVSLineBufferSurfaceArray      ||
         nullptr == m_IEFLineBufferSurfaceArray      ||
@@ -1340,30 +1467,38 @@ MOS_STATUS SfcRenderBase::AllocateResources()
         VP_RENDER_CHK_NULL_RETURN(m_SFDLineBufferSurfaceArray);
     }
 
+    // for AVSLineBuffer, IEFLineBuffer and SFDLineBuffer, they are only needed when surface allocation bigger than 4150.
+    // for AVSLineTileBuffer, IEFLineTileBuffer and SFDLineTileBuffer, they are only needed for VdBox SFC scalability case and not needed for VeBox SFC case.
+
     // Allocate AVS Line Buffer surface----------------------------------------------
-    size = GetAvsLineBufferSize(false, sfcStateParams->b8tapChromafiltering, sfcStateParams->dwInputFrameWidth, sfcStateParams->dwInputFrameHeight);
+    size = GetAvsLineBufferSize(false, m_renderData.sfcStateParams->b8tapChromafiltering, m_renderData.sfcStateParams->dwInputFrameWidth, m_renderData.sfcStateParams->dwInputFrameHeight);
     VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_AVSLineBufferSurfaceArray, size, "SfcAVSLineBufferSurface"));
 
     // Allocate IEF Line Buffer surface----------------------------------------------
-    size = GetIefLineBufferSize(false, sfcStateParams->dwScaledRegionHeight);
+    size = GetIefLineBufferSize(false, m_renderData.sfcStateParams->dwScaledRegionHeight);
     VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_IEFLineBufferSurfaceArray, size, "SfcIEFLineBufferSurface"));
 
-    // Allocate SFD Line Buffer surface
-    size = GetSfdLineBufferSize(false, sfcStateParams->OutputFrameFormat, sfcStateParams->dwScaledRegionWidth, sfcStateParams->dwScaledRegionHeight);
-    VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_SFDLineBufferSurfaceArray, size, "SfcSFDLineBufferSurface"));
+    if (m_renderData.sfcStateParams->dwScaledRegionHeight > SFC_LINEBUFEER_SIZE_LIMITED)
+    {
+        // Allocate SFD Line Buffer surface
+        size = GetSfdLineBufferSize(false, m_renderData.sfcStateParams->OutputFrameFormat, m_renderData.sfcStateParams->dwScaledRegionWidth, m_renderData.sfcStateParams->dwScaledRegionHeight);
+        VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_SFDLineBufferSurfaceArray, size, "SfcSFDLineBufferSurface"));
+    }
 
-    // Allocate AVS Line Tile Buffer surface----------------------------------------------
-    size = GetAvsLineBufferSize(true, sfcStateParams->b8tapChromafiltering, sfcStateParams->dwInputFrameWidth, sfcStateParams->dwInputFrameHeight);
-    VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_AVSLineTileBufferSurface, size, "SfcAVSLineTileBufferSurface"));
+    if (m_bVdboxToSfc)
+    {
+        // Allocate AVS Line Tile Buffer surface----------------------------------------------
+        size = GetAvsLineBufferSize(true, m_renderData.sfcStateParams->b8tapChromafiltering, m_renderData.sfcStateParams->dwInputFrameWidth, m_renderData.sfcStateParams->dwInputFrameHeight);
+        VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_AVSLineTileBufferSurface, size, "SfcAVSLineTileBufferSurface"));
 
-    // Allocate IEF Line Tile Buffer surface----------------------------------------------
-    size = GetIefLineBufferSize(true, sfcStateParams->dwScaledRegionHeight);
-    VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_IEFLineTileBufferSurface, size, "SfcIEFLineTileBufferSurface"));
-
-    // Allocate SFD Line Tile Buffer surface
-    size = GetSfdLineBufferSize(true, sfcStateParams->OutputFrameFormat, sfcStateParams->dwScaledRegionWidth, sfcStateParams->dwScaledRegionHeight);
-    VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_SFDLineTileBufferSurface, size, "SfcSFDLineTileBufferSurface"));
+        // Allocate IEF Line Tile Buffer surface----------------------------------------------
+        size = GetIefLineBufferSize(true, m_renderData.sfcStateParams->dwScaledRegionHeight);
+        VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_IEFLineTileBufferSurface, size, "SfcIEFLineTileBufferSurface"));
 
+        // Allocate SFD Line Tile Buffer surface
+        size = GetSfdLineBufferSize(true, m_renderData.sfcStateParams->OutputFrameFormat, m_renderData.sfcStateParams->dwScaledRegionWidth, m_renderData.sfcStateParams->dwScaledRegionHeight);
+        VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_SFDLineTileBufferSurface, size, "SfcSFDLineTileBufferSurface"));
+    }
     return MOS_STATUS_SUCCESS;
 }
 
@@ -1424,4 +1559,156 @@ MOS_STATUS SfcRenderBase::SetHistogramBuf(PMOS_BUFFER histogramBuf)
 
     return MOS_STATUS_SUCCESS;
 }
+
+MOS_STATUS SfcRenderBase::AddSfcLock(
+    PMOS_COMMAND_BUFFER            pCmdBuffer,
+    mhw::sfc::SFC_LOCK_PAR         *sfcLockParams)
+{
+    VP_FUNC_CALL();
+
+    VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
+
+    auto& params = m_sfcItf->MHW_GETPAR_F(SFC_LOCK)();
+    params = {};
+    params = *sfcLockParams;
+
+    // Send SFC_LOCK command to acquire SFC pipe for Vebox
+    VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_LOCK)(pCmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SfcRenderBase::AddSfcState(
+    PMOS_COMMAND_BUFFER            pCmdBuffer,
+    mhw::sfc::SFC_STATE_PAR        *pSfcStateParams,
+    PMHW_SFC_OUT_SURFACE_PARAMS    pOutSurface)
+{
+    VP_FUNC_CALL();
+
+    VP_RENDER_CHK_NULL_RETURN(pSfcStateParams);
+    VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
+
+    auto& params = m_sfcItf->MHW_GETPAR_F(SFC_STATE)();
+    params = {};
+    params = *pSfcStateParams;
+    params.pOutSurface = pOutSurface;
+
+    // Send SFC_LOCK command to acquire SFC pipe for Vebox
+    VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_STATE)(pCmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SfcRenderBase::AddSfcAvsState(
+    PMOS_COMMAND_BUFFER             pCmdBuffer)
+{
+    VP_FUNC_CALL();
+    VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
+
+    VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_AVS_STATE)(pCmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SfcRenderBase::AddSfcIefState(
+    PMOS_COMMAND_BUFFER            pCmdBuffer)
+{
+    VP_FUNC_CALL();
+    VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
+
+    VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_IEF_STATE)(pCmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SfcRenderBase::AddSfcAvsLumaTable(
+    PMOS_COMMAND_BUFFER                pCmdBuffer)
+{
+    VP_FUNC_CALL();
+
+    VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
+
+    VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_AVS_LUMA_Coeff_Table)(pCmdBuffer));
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SfcRenderBase::AddSfcAvsChromaTable(
+    PMOS_COMMAND_BUFFER             pCmdBuffer)
+{
+    VP_FUNC_CALL();
+    VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
+
+    VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_AVS_CHROMA_Coeff_Table)(pCmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SfcRenderBase::AddSfcFrameStart(
+    PMOS_COMMAND_BUFFER            pCmdBuffer,
+    uint8_t                        sfcPipeMode)
+{
+    VP_FUNC_CALL();
+    VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
+
+    auto& SfcFrameStartParams = m_sfcItf->MHW_GETPAR_F(SFC_FRAME_START)();
+    SfcFrameStartParams = {};
+    SfcFrameStartParams.sfcPipeMode = m_pipeMode;
+    VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_FRAME_START)(pCmdBuffer));
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SfcRenderBase::SetSfcAVSScalingMode(
+    MHW_SCALING_MODE  ScalingMode)
+{
+    VP_FUNC_CALL();
+
+    MOS_STATUS                      eStatus;
+
+    eStatus = MOS_STATUS_SUCCESS;
+    VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
+
+    // Send SFC_FRAME_START command to start processing a frame
+    VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->SetSfcAVSScalingMode(
+        ScalingMode));
+
+    return eStatus;
+}
+
+MOS_STATUS SfcRenderBase::SetSfcSamplerTable(
+    mhw::sfc::SFC_AVS_LUMA_Coeff_Table_PAR   *pLumaTable,
+    mhw::sfc::SFC_AVS_CHROMA_Coeff_Table_PAR *pChromaTable,
+    PMHW_AVS_PARAMS                 pAvsParams,
+    MOS_FORMAT                      SrcFormat,
+    float                           fScaleX,
+    float                           fScaleY,
+    uint32_t                        dwChromaSiting,
+    bool                            bUse8x8Filter,
+    float                           fHPStrength,
+    float                           fLanczosT)
+{
+    VP_FUNC_CALL();
+
+    MOS_STATUS                      eStatus;
+
+    eStatus = MOS_STATUS_SUCCESS;
+    VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
+    VP_RENDER_CHK_NULL_RETURN(pLumaTable);
+    VP_RENDER_CHK_NULL_RETURN(pChromaTable);
+    VP_RENDER_CHK_NULL_RETURN(pAvsParams);
+
+    // Send SFC_FRAME_START command to start processing a frame
+    VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->SetSfcSamplerTable(
+        pLumaTable,
+        pChromaTable,
+        pAvsParams,
+        SrcFormat,
+        fScaleX,
+        fScaleY,
+        dwChromaSiting,
+        bUse8x8Filter,
+        fHPStrength,
+        fLanczosT));
+
+    return eStatus;
+}
 }
