@@ -30,7 +30,14 @@
 
 using namespace vp;
 
-#define VP_HDR_KERNEL_NAME "hdr_3dlut"
+//!
+//! \brief Binding Table Index for HDR 3DLut kernel
+//!
+#define BI_VEBOX_HDR_3DLUT_3DLUT 1
+#define BI_VEBOX_HDR_3DLUT_COEF  2
+
+#define BI_VEBOX_HDR_3DLUT_3DLUT_CM 0
+#define BI_VEBOX_HDR_3DLUT_COEF_CM  1
 
 static const float ccm_identity[12]               = {1.0f, 0.0f, 0.0f, 0.0f, 0.0f, 1.0f, 0.0f, 0.0f, 0.0f, 0.0f, 1.0f, 0.0f};
 static float       color_matrix_calculation[3][4] = {0.0f};
@@ -205,6 +212,125 @@ static void CalcCCMMatrix()
     color_matrix_calculation[2][3] = 0.0f;
 }
 
+// Used by ISA kernel
+VpRenderHdr3DLutKernel::VpRenderHdr3DLutKernel(PVP_MHWINTERFACE hwInterface, VpKernelID kernelId, uint32_t kernelIndex, std::string kernelName, PVpAllocator allocator) :
+    VpRenderKernelObj(hwInterface, kernelId, kernelIndex, VP_HDR_KERNEL_NAME, allocator)
+{
+    VP_FUNC_CALL();
+}
+
+// Used by L0 kernel
+VpRenderHdr3DLutKernel::VpRenderHdr3DLutKernel(PVP_MHWINTERFACE hwInterface, PVpAllocator allocator) :
+    VpRenderKernelObj(hwInterface, (VpKernelID)kernelHdr3DLutCalc, 0, VP_HDR_KERNEL_NAME_L0, allocator)
+{
+    VP_FUNC_CALL();
+    m_kernelBinaryID = VP_ADV_KERNEL_BINARY_ID(kernelHdr3DLutCalc);
+}
+
+VpRenderHdr3DLutKernel::~VpRenderHdr3DLutKernel()
+{
+}
+
+MOS_STATUS VpRenderHdr3DLutKernel::SetupSurfaceState()
+{
+    VP_FUNC_CALL();
+    VP_RENDER_CHK_NULL_RETURN(m_surfaceGroup);
+    VP_RENDER_CHK_NULL_RETURN(m_hwInterface);
+
+    PRENDERHAL_INTERFACE renderHal   = m_hwInterface->m_renderHal;
+    PMOS_INTERFACE       osInterface = m_hwInterface->m_osInterface;
+
+    KERNEL_SURFACE_STATE_PARAM kernelSurfaceParam            = {};
+    // Only need to specify binding index in surface parameters.
+    kernelSurfaceParam.surfaceOverwriteParams.updatedSurfaceParams = true; 
+    kernelSurfaceParam.surfaceOverwriteParams.bindedKernel   = true;
+    kernelSurfaceParam.surfaceOverwriteParams.bufferResource = true;
+
+    kernelSurfaceParam.surfaceOverwriteParams.bindIndex = BI_VEBOX_HDR_3DLUT_3DLUT;
+    kernelSurfaceParam.isOutput                         = true;
+    m_surfaceState.insert(std::make_pair(SurfaceType3DLut, kernelSurfaceParam));
+    kernelSurfaceParam.surfaceOverwriteParams.bindIndex = BI_VEBOX_HDR_3DLUT_COEF;
+    kernelSurfaceParam.isOutput                         = false;
+    m_surfaceState.insert(std::make_pair(SurfaceType3DLutCoef, kernelSurfaceParam));
+
+    VP_RENDER_CHK_STATUS_RETURN(InitCoefSurface(m_maxDisplayLum, m_maxContentLevelLum, m_hdrMode));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS VpRenderHdr3DLutKernel::GetCurbeState(void *&curbe, uint32_t &curbeLength)
+{
+    VP_FUNC_CALL();
+    // init the hdr 3dlut static data
+    MOS_ZeroMemory(&m_curbe, sizeof(m_curbe));
+    m_curbe.DW00.Thread_Group_X        = LUT65_SEG_SIZE;
+    m_curbe.DW01.Thread_Group_Y        = LUT65_SEG_SIZE;
+    m_curbe.DW02.Thread_Group_Z        = 1;
+    m_curbe.DW06.hdr3DLutSurface = GetSurfaceBindingIndex(SurfaceType3DLut);
+    m_curbe.DW07.hdrCoefSurface  = GetSurfaceBindingIndex(SurfaceType3DLutCoef);
+    m_curbe.DW08.hdr3DLutSurfaceHeight = LUT65_SEG_SIZE * LUT65_MUL_SIZE;
+    m_curbe.DW08.hdr3DLutSurfaceWidth  = LUT65_SEG_SIZE * 2;
+
+    curbeLength = sizeof(VEBOX_HDR_3DLUT_STATIC_DATA);
+    curbe = (uint8_t *) & m_curbe;
+    VP_RENDER_NORMALMESSAGE("HDR 3DLut Kernel curbelength %d", curbeLength);
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS VpRenderHdr3DLutKernel::SetKernelConfigs(KERNEL_CONFIGS &kernelConfigs)
+{
+    VP_FUNC_CALL();
+    auto it = kernelConfigs.find((VpKernelID)kernelHdr3DLutCalc);
+
+    if (kernelConfigs.end() == it || nullptr == it->second)
+    {
+        VP_RENDER_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+    }
+
+    PRENDER_HDR_3DLUT_CAL_PARAMS params = (PRENDER_HDR_3DLUT_CAL_PARAMS)it->second;
+
+    if (m_maxDisplayLum == params->maxDisplayLum && m_maxContentLevelLum == params->maxContentLevelLum &&
+        m_hdrMode == params->hdrMode)
+    {
+        // For such case, 3DLut calculation should be skipped in Policy::GetHdrExecutionCaps.
+        VP_RENDER_ASSERTMESSAGE("No change in 3D Lut parameters!");
+    }
+    else
+    {
+        m_maxDisplayLum      = params->maxDisplayLum;
+        m_maxContentLevelLum = params->maxContentLevelLum;
+        m_hdrMode            = params->hdrMode;
+        VP_RENDER_NORMALMESSAGE("Maximum Display Luminance %d, Maximum Content Level Luminance %d, HDR mode %d",
+            m_maxDisplayLum,
+            m_maxContentLevelLum,
+            m_hdrMode);
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
+
+MOS_STATUS VpRenderHdr3DLutKernel::GetWalkerSetting(KERNEL_WALKER_PARAMS &walkerParam, KERNEL_PACKET_RENDER_DATA &renderData)
+{
+
+    VP_FUNC_CALL();
+    RENDERHAL_KERNEL_PARAM kernelSettings;
+    uint32_t               blockWidth  = 16;
+    uint32_t               blockHeight = 8;
+
+    VP_RENDER_CHK_STATUS_RETURN(GetKernelSettings(kernelSettings));
+    MOS_ZeroMemory(&walkerParam, sizeof(KERNEL_WALKER_PARAMS));
+
+    VP_RENDER_CHK_STATUS_RETURN(VpRenderKernelObj::GetWalkerSetting(m_walkerParam, renderData));
+
+    m_walkerParam.iBlocksX          = LUT65_SEG_SIZE;
+    m_walkerParam.iBlocksY          = LUT65_SEG_SIZE;
+    m_walkerParam.isVerticalPattern = false;
+    m_walkerParam.bSyncFlag         = true;
+    walkerParam                     = m_walkerParam;
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS VpRenderHdr3DLutKernel::InitCoefSurface(const uint32_t maxDLL, const uint32_t maxCLL, const VPHAL_HDR_MODE hdrMode)
 {
     VP_FUNC_CALL();
@@ -228,13 +354,6 @@ MOS_STATUS VpRenderHdr3DLutKernel::InitCoefSurface(const uint32_t maxDLL, const
 
     VP_RENDER_CHK_NULL_RETURN(lockedAddr);
 
-    uint32_t widthInDWord = surf->osSurface->dwWidth;
-    uint32_t pitchInDWord = surf->osSurface->dwPitch / 4;
-    auto OffsetInDWordPadding = [&](uint32_t offsetInDWord)
-    {
-        return offsetInDWord / widthInDWord * pitchInDWord + offsetInDWord % widthInDWord;
-    };
-
     hdrcoefBuffer = (float *)lockedAddr;
 
     if (hdrMode == VPHAL_HDR_MODE_TONE_MAPPING)  // H2S
@@ -258,25 +377,20 @@ MOS_STATUS VpRenderHdr3DLutKernel::InitCoefSurface(const uint32_t maxDLL, const
     // Fill Coefficient Surface: Media kernel define the layout of coefficients. Please don't change it.
     const uint32_t pos_coef[17] = {7, 16, 17, 18, 19, 20, 21, 24, 25, 26, 27, 28, 29, 54, 55, 62, 63};
 
-    if (OffsetInDWordPadding(pos_coef[16]) * 4 > surf->osSurface->dwSize)
-    {
-        VP_RENDER_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
-    }
-
     // OETF curve
-    ((int *)hdrcoefBuffer)[OffsetInDWordPadding(pos_coef[0])] = oetfCurve;
+    ((int *)hdrcoefBuffer)[pos_coef[0]] = oetfCurve;
     // CCM
     for (uint32_t i = 0; i < VP_CCM_MATRIX_SIZE; ++i)
     {
-        hdrcoefBuffer[OffsetInDWordPadding(pos_coef[i + 1])] = ccmMatrix[i];
+        hdrcoefBuffer[pos_coef[i + 1]] = ccmMatrix[i];
     }
     // TM Source Type
-    ((int *)hdrcoefBuffer)[OffsetInDWordPadding(pos_coef[13])] = tmSrcType;
+    ((int *)hdrcoefBuffer)[pos_coef[13]] = tmSrcType;
     // TM Mode
-    ((int *)hdrcoefBuffer)[OffsetInDWordPadding(pos_coef[14])] = tmMode;
+    ((int *)hdrcoefBuffer)[pos_coef[14]] = tmMode;
     // Max CLL and DLL
-    hdrcoefBuffer[OffsetInDWordPadding(pos_coef[15])] = tmMaxCLL;
-    hdrcoefBuffer[OffsetInDWordPadding(pos_coef[16])] = tmMaxDLL;
+    hdrcoefBuffer[pos_coef[15]] = tmMaxCLL;
+    hdrcoefBuffer[pos_coef[16]] = tmMaxDLL;
 
     //Unlock
     VP_RENDER_CHK_STATUS_RETURN(m_allocator->UnLock(&surf->osSurface->OsResource));
@@ -284,20 +398,20 @@ MOS_STATUS VpRenderHdr3DLutKernel::InitCoefSurface(const uint32_t maxDLL, const
     return MOS_STATUS_SUCCESS;
 }
 
-VpRenderHdr3DLutKernel::VpRenderHdr3DLutKernel(PVP_MHWINTERFACE hwInterface, VpKernelID kernelID, uint32_t kernelIndex, PVpAllocator allocator) :
-    VpRenderKernelObj(hwInterface, kernelID, kernelIndex, VP_HDR_KERNEL_NAME, allocator)
+VpRenderHdr3DLutKernelCM::VpRenderHdr3DLutKernelCM(PVP_MHWINTERFACE hwInterface, VpKernelID kernelID, uint32_t kernelIndex, PVpAllocator allocator) : 
+    VpRenderHdr3DLutKernel(hwInterface, kernelID, kernelIndex, VP_HDR_KERNEL_NAME, allocator)
 {
     m_kernelBinaryID = VP_ADV_KERNEL_BINARY_ID(kernelID);
     m_isAdvKernel    = true;
 }
 
-VpRenderHdr3DLutKernel::~VpRenderHdr3DLutKernel()
+VpRenderHdr3DLutKernelCM::~VpRenderHdr3DLutKernelCM()
 {
     // No need to destroy dstArg.pData, which points to the local variable
     // in VpHdrFilter.
 }
 
-MOS_STATUS VpRenderHdr3DLutKernel::Init(VpRenderKernel &kernel)
+MOS_STATUS VpRenderHdr3DLutKernelCM::Init(VpRenderKernel &kernel)
 {
     VP_FUNC_CALL();
     m_kernelSize = kernel.GetKernelSize() + KERNEL_BINARY_PADDING_SIZE;
@@ -306,13 +420,12 @@ MOS_STATUS VpRenderHdr3DLutKernel::Init(VpRenderKernel &kernel)
     VP_RENDER_CHK_NULL_RETURN(pKernelBin);
 
     m_kernelBinary = pKernelBin + kernel.GetKernelBinOffset();
-
     m_kernelArgs = kernel.GetKernelArgs();
 
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpRenderHdr3DLutKernel::GetWalkerSetting(KERNEL_WALKER_PARAMS &walkerParam, KERNEL_PACKET_RENDER_DATA &renderData)
+MOS_STATUS VpRenderHdr3DLutKernelCM::GetWalkerSetting(KERNEL_WALKER_PARAMS &walkerParam, KERNEL_PACKET_RENDER_DATA &renderData)
 {
     VP_FUNC_CALL();
 
@@ -323,7 +436,7 @@ MOS_STATUS VpRenderHdr3DLutKernel::GetWalkerSetting(KERNEL_WALKER_PARAMS &walker
 }
 
 // Only for Adv kernels.
-MOS_STATUS VpRenderHdr3DLutKernel::SetWalkerSetting(KERNEL_THREAD_SPACE &threadSpace, bool bSyncFlag)
+MOS_STATUS VpRenderHdr3DLutKernelCM::SetWalkerSetting(KERNEL_THREAD_SPACE &threadSpace, bool bSyncFlag)
 {
     VP_FUNC_CALL();
     MOS_ZeroMemory(&m_walkerParam, sizeof(KERNEL_WALKER_PARAMS));
@@ -336,7 +449,7 @@ MOS_STATUS VpRenderHdr3DLutKernel::SetWalkerSetting(KERNEL_THREAD_SPACE &threadS
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpRenderHdr3DLutKernel::SetKernelArgs(KERNEL_ARGS &kernelArgs)
+MOS_STATUS VpRenderHdr3DLutKernelCM::SetKernelArgs(KERNEL_ARGS &kernelArgs, VP_PACKET_SHARED_CONTEXT *sharedContext)
 {
     VP_FUNC_CALL();
     if (kernelArgs.size() != m_kernelArgs.size())
@@ -370,7 +483,7 @@ MOS_STATUS VpRenderHdr3DLutKernel::SetKernelArgs(KERNEL_ARGS &kernelArgs)
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpRenderHdr3DLutKernel::GetCurbeState(void *&curbe, uint32_t &curbeLength)
+MOS_STATUS VpRenderHdr3DLutKernelCM::GetCurbeState(void *&curbe, uint32_t &curbeLength)
 {
     VP_FUNC_CALL();
     curbeLength = 0;
@@ -414,7 +527,7 @@ MOS_STATUS VpRenderHdr3DLutKernel::GetCurbeState(void *&curbe, uint32_t &curbeLe
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpRenderHdr3DLutKernel::SetupSurfaceState()
+MOS_STATUS VpRenderHdr3DLutKernelCM::SetupSurfaceState()
 {
     VP_FUNC_CALL();
     VP_RENDER_CHK_NULL_RETURN(m_surfaceGroup);
@@ -423,59 +536,23 @@ MOS_STATUS VpRenderHdr3DLutKernel::SetupSurfaceState()
     PRENDERHAL_INTERFACE renderHal = m_hwInterface->m_renderHal;
     PMOS_INTERFACE osInterface = m_hwInterface->m_osInterface;
 
-    for (auto arg : m_kernelArgs)
-    {
-        VP_RENDER_CHK_NULL_RETURN(arg.pData);
+    KERNEL_SURFACE_STATE_PARAM kernelSurfaceParam            = {};
+    kernelSurfaceParam.surfaceOverwriteParams.bindedKernel   = true;
+    kernelSurfaceParam.surfaceOverwriteParams.bufferResource = true;
 
-        if (arg.eArgKind == ARG_KIND_SURFACE)
-        {
-            SurfaceType surfType = *(SurfaceType *)arg.pData;
-
-            auto it = m_surfaceGroup->find(surfType);
-            if (m_surfaceGroup->end() == it)
-            {
-                VP_RENDER_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
-            }
-
-            auto surf = it->second;
-            VP_RENDER_CHK_NULL_RETURN(surf);
-            VP_RENDER_CHK_NULL_RETURN(surf->osSurface);
-
-            uint32_t depth = 4;
-            uint32_t width = surf->bufferWidth / depth;
-            uint32_t height = surf->bufferHeight;
-
-            KERNEL_SURFACE_STATE_PARAM kernelSurfaceParam = {};
-            kernelSurfaceParam.surfaceOverwriteParams.updatedSurfaceParams  = true;
-            kernelSurfaceParam.surfaceOverwriteParams.width                 = surf->bufferWidth / depth;
-            kernelSurfaceParam.surfaceOverwriteParams.height                = surf->bufferHeight;
-            kernelSurfaceParam.surfaceOverwriteParams.pitch                 = surf->bufferWidth;
-            kernelSurfaceParam.surfaceOverwriteParams.format                = Format_A8R8G8B8;
-            kernelSurfaceParam.surfaceOverwriteParams.tileType              = surf->osSurface->TileType;
-            kernelSurfaceParam.surfaceOverwriteParams.surface_offset        = 0;
-
-            kernelSurfaceParam.surfaceOverwriteParams.updatedRenderSurfaces                 = true;
-            kernelSurfaceParam.surfaceOverwriteParams.renderSurfaceParams.Type              = renderHal->SurfaceTypeDefault;
-            kernelSurfaceParam.surfaceOverwriteParams.renderSurfaceParams.bRenderTarget     = true; // true if no need sync for read.
-            kernelSurfaceParam.surfaceOverwriteParams.renderSurfaceParams.bWidthInDword_Y   = true;
-            kernelSurfaceParam.surfaceOverwriteParams.renderSurfaceParams.bWidthInDword_UV  = true;
-            kernelSurfaceParam.surfaceOverwriteParams.renderSurfaceParams.Boundary          = RENDERHAL_SS_BOUNDARY_ORIGINAL;
-            kernelSurfaceParam.surfaceOverwriteParams.renderSurfaceParams.bWidth16Align     = false;
-            //set mem object control for cache
-            kernelSurfaceParam.surfaceOverwriteParams.renderSurfaceParams.MemObjCtl = (osInterface->pfnCachePolicyGetMemoryObject(
-                        MOS_MP_RESOURCE_USAGE_DEFAULT,
-                        osInterface->pfnGetGmmClientContext(osInterface))).DwordValue;
-
-            m_surfaceState.insert(std::make_pair(*(SurfaceType *)arg.pData, kernelSurfaceParam));
-        }
-    }
+    kernelSurfaceParam.surfaceOverwriteParams.bindIndex = BI_VEBOX_HDR_3DLUT_3DLUT_CM;
+    kernelSurfaceParam.isOutput                         = true;
+    m_surfaceState.insert(std::make_pair(SurfaceType3DLut, kernelSurfaceParam));
+    kernelSurfaceParam.surfaceOverwriteParams.bindIndex = BI_VEBOX_HDR_3DLUT_COEF_CM;
+    kernelSurfaceParam.isOutput                         = false;
+    m_surfaceState.insert(std::make_pair(SurfaceType3DLutCoef, kernelSurfaceParam));
     
     VP_RENDER_CHK_STATUS_RETURN(InitCoefSurface(m_maxDisplayLum, m_maxContentLevelLum, m_hdrMode));
 
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpRenderHdr3DLutKernel::SetKernelConfigs(KERNEL_CONFIGS& kernelConfigs)
+MOS_STATUS VpRenderHdr3DLutKernelCM::SetKernelConfigs(KERNEL_CONFIGS& kernelConfigs)
 {
     VP_FUNC_CALL();
     auto it = kernelConfigs.find((VpKernelID)kernelHdr3DLutCalc);
