@@ -27,55 +27,11 @@
 //!
 #ifndef __VP_PIPELINE_ADAPTER_BASE_H__
 #define __VP_PIPELINE_ADAPTER_BASE_H__
-#include "vp_common.h"
-#include "vphal_common_tools.h"
-#include "mhw_vebox.h"
-#include "mhw_sfc.h"
-#include "vp_utils.h"
-#include "media_interfaces_mhw.h"
-#include "vp_feature_report.h"
+#include "vp_base.h"
 #include "mhw_vebox_itf.h"
-
-namespace vp
-{
-class VpPlatformInterface;
-class VpUserFeatureControl;
-};
-
-//-----------------------------------------------------------------------------
-// VPHAL-DDI RENDERING INTERFACE
-//
-//      Params that may apply to more than one layer are part of VPHAL_SURFACE
-//      DDI layers must set this interface before calling pfnRender
-//-----------------------------------------------------------------------------
-//!
-//! Structure VphalSettings
-//! \brief VPHAL Settings - controls allocation of internal resources in VPHAL
-//!
-struct VpSettings
-{
-    //!
-    //! \brief    VphalSettings Constructor
-    //! \details  Creates instance of VphalSettings
-    //!
-    VpSettings()    : maxPhases(0),
-                      mediaStates(0),
-                      sameSampleThreshold(0),
-                      disableDnDi(0),
-                      kernelUpdate(0),
-                      disableHdr(0),
-                      veboxParallelExecution(0),
-                      clearVideoViewMode(false){};
-
-    int32_t  maxPhases;
-    int32_t  mediaStates;
-    int32_t  sameSampleThreshold;
-    uint32_t disableDnDi;             //!< For validation purpose
-    uint32_t kernelUpdate;            //!< For VEBox Copy and Update kernels
-    uint32_t disableHdr;              //!< Disable Hdr
-    uint32_t veboxParallelExecution;  //!< Control VEBox parallel execution with render engine
-    uint32_t clearVideoViewMode;     //!< Perf Optimize for ClearVideoView DDI
-};
+#include "vp_utils.h"
+#include "mhw_sfc_itf.h"
+#include "mhw_render_itf.h"
 
 //!
 //! \brief Deinterlace Mode enum
@@ -97,50 +53,13 @@ typedef enum
     VPDDI_SUPERRESOLUTIONSCALING = 2   //!< Super scaling
 } SCALING_MODE;
 
-struct _VP_MHWINTERFACE
-{
-    // Internals
-    PLATFORM             m_platform;
-    MEDIA_FEATURE_TABLE *m_skuTable;
-    MEDIA_WA_TABLE *     m_waTable;
-
-    // States
-    PMOS_INTERFACE           m_osInterface;
-    PRENDERHAL_INTERFACE     m_renderHal;
-    PMHW_VEBOX_INTERFACE     m_veboxInterface;
-    MhwCpInterface *         m_cpInterface;
-    PMHW_SFC_INTERFACE       m_sfcInterface;
-    PMHW_MI_INTERFACE        m_mhwMiInterface;
-    vp::VpPlatformInterface *m_vpPlatformInterface;
-    void *                   m_settings;
-    VpFeatureReport *        m_reporting;
-
-    // Render GPU context/node
-    MOS_GPU_NODE    m_renderGpuNode;
-    MOS_GPU_CONTEXT m_renderGpuContext;
-
-    // vp Pipeline workload status report
-    PVPHAL_STATUS_TABLE m_statusTable;
-
-    void *m_debugInterface;
-    vp::VpUserFeatureControl *m_userFeatureControl;
-};
-
-using VP_MHWINTERFACE  = _VP_MHWINTERFACE;
-
 //!
 //! Class VpPipelineAdapterBase
 //! \brief VP_INTERFACE class definition
 //!
-class VpPipelineAdapterBase
+class VpPipelineAdapterBase : public VpBase
 {
 public:
-    // factory function
-    static VpPipelineAdapterBase *VphalStateFactory(
-        PMOS_INTERFACE pOsInterface,
-        PMOS_CONTEXT   pOsDriverContext,
-        MOS_STATUS *   peStatus);
-
     //!
     //! \brief    VpPipelineAdapterBase Constructor
     //! \details  Creates instance of VpPipelineAdapterBase
@@ -197,8 +116,11 @@ public:
     virtual MOS_STATUS GetStatusReport(
         PQUERY_STATUS_REPORT_APP pQueryReport,
         uint16_t                 numStatus);
+    
+    virtual MOS_STATUS GetStatusReportEntryLength(
+        uint32_t                         *puiLength);
 
-    virtual VpFeatureReport *GetRenderFeatureReport() = 0;
+    virtual VphalFeatureReport *GetRenderFeatureReport() = 0;
 
     //!
     //! \brief    VpPipelineAdapterBase Destuctor
@@ -207,62 +129,91 @@ public:
     //!
     virtual ~VpPipelineAdapterBase();
 
-    PMOS_INTERFACE GetOsInterface()
+    virtual PMOS_INTERFACE GetOsInterface()
     {
-        return m_pOsInterface;
+        return m_osInterface;
     }
 
-    void SetMhwVeboxInterface(MhwVeboxInterface *veboxInterface)
+    virtual MEDIA_FEATURE_TABLE *GetSkuTable()
+    {
+        return m_skuTable;
+    }
+
+    virtual PLATFORM &GetPlatform()
+    {
+        return m_platform;
+    }
+
+    virtual PRENDERHAL_INTERFACE GetRenderHal()
+    {
+        return m_vprenderHal;
+    }
+
+    void SetMhwVeboxItf(std::shared_ptr<mhw::vebox::Itf> veboxItf)
     {
         MOS_STATUS                  eStatus = MOS_STATUS_SUCCESS;
-        if (veboxInterface == nullptr)
+        if (veboxItf == nullptr)
         {
             return;
         }
 
-        if (m_veboxInterface != nullptr)
+        if (m_veboxItf != nullptr)
         {
-            m_veboxItf = std::static_pointer_cast<mhw::vebox::Itf>(m_veboxInterface->GetNewVeboxInterface());
+            eStatus = m_veboxItf->DestroyHeap();
 
-            if (m_veboxItf)
-            {
-                eStatus = m_veboxItf->DestroyHeap();
-            }
-            else
-            {
-                eStatus = m_veboxInterface->DestroyHeap();
-            }
-
-            MOS_Delete(m_veboxInterface);
-            m_veboxInterface = nullptr;
             m_veboxItf       = nullptr;
-            if (eStatus != MOS_STATUS_SUCCESS)
+            if (MOS_FAILED(eStatus))
             {
                 VP_PUBLIC_ASSERTMESSAGE("Failed to destroy Vebox Interface, eStatus:%d.\n", eStatus);
             }
         }
 
-        m_veboxInterface = veboxInterface;
-        m_veboxItf = std::static_pointer_cast<mhw::vebox::Itf>(veboxInterface->GetNewVeboxInterface());
+        m_veboxItf = veboxItf;
     }
 
-    void SetMhwSfcInterface(MhwSfcInterface *sfcInterface)
+    void SetMhwSfcItf(std::shared_ptr<mhw::sfc::Itf> sfcItf)
     {
-        if (sfcInterface == nullptr)
+        if (sfcItf == nullptr)
         {
             return;
         }
 
-        if (m_sfcInterface != nullptr)
+        if (m_sfcItf != nullptr)
         {
-            MOS_Delete(m_sfcInterface);
-            m_sfcInterface = nullptr;
+            m_sfcItf       = nullptr;
         }
 
-        m_sfcInterface = sfcInterface;
+        m_sfcItf = sfcItf;
     }
 
-    HANDLE m_gpuAppTaskEvent = nullptr;
+    void SetMhwMiItf(std::shared_ptr<mhw::mi::Itf> miItf)
+    {
+        if (miItf == nullptr)
+        {
+            return;
+        }
+        if (m_miItf != nullptr)
+        {
+            m_miItf = nullptr;
+        }
+
+        m_miItf = miItf;
+    }
+
+    void SetMhwRenderItf(std::shared_ptr<mhw::render::Itf> renderItf)
+    {
+        if (renderItf == nullptr)
+        {
+            return;
+        }
+
+        if (m_renderItf != nullptr)
+        {
+            m_renderItf = nullptr;
+        }
+
+        m_renderItf = renderItf;
+    }
 
 protected:
     // Internals
@@ -271,18 +222,20 @@ protected:
     MEDIA_WA_TABLE *     m_waTable  = nullptr;
 
     // States
-    PMOS_INTERFACE       m_pOsInterface = nullptr;
+    PMOS_INTERFACE       m_osInterface   = nullptr;
     PRENDERHAL_INTERFACE m_vprenderHal   = nullptr;
-    PMHW_VEBOX_INTERFACE m_veboxInterface = nullptr;
     MhwCpInterface *     m_cpInterface    = nullptr;
-    PMHW_SFC_INTERFACE   m_sfcInterface   = nullptr;
-    std::shared_ptr<mhw::vebox::Itf> m_veboxItf = nullptr;
+    std::shared_ptr<mhw::vebox::Itf>  m_veboxItf  = nullptr;
+    std::shared_ptr<mhw::sfc::Itf>    m_sfcItf    = nullptr;
+    std::shared_ptr<mhw::mi::Itf>     m_miItf     = nullptr;
+    std::shared_ptr<mhw::render::Itf> m_renderItf = nullptr;
 
     // StatusTable indicating if command is done by gpu or not
     VPHAL_STATUS_TABLE       m_statusTable = {};
     vp::VpPlatformInterface &m_vpPlatformInterface;  //!< vp platform interface. Should be destroyed during deconstruction.
+    MediaUserSettingSharedPtr m_userSettingPtr = nullptr;  //!< usersettingInstance
 
 MEDIA_CLASS_DEFINE_END(VpPipelineAdapterBase)
 };
 
-#endif  // __VP_PIPELINE_ADAPTER_BASE_H__
\ No newline at end of file
+#endif  // __VP_PIPELINE_ADAPTER_BASE_H__
