@@ -321,6 +321,18 @@ public:
         return true;
     }
 
+    virtual bool IsRenderMMCLimitationCheckNeeded()
+    {
+        return false;
+    }
+
+    bool IsRenderDisabled()
+    {
+        return m_isRenderDisabled;
+    }
+
+    void DisableRender();
+
 protected:
     PMOS_INTERFACE m_pOsInterface = nullptr;
     VP_KERNEL_BINARY m_vpKernelBinary = {};                 //!< vp kernels
@@ -341,6 +353,8 @@ protected:
     std::map<DelayLoadedKernelType, bool>  m_vpDelayLoadedFeatureSet;
     std::map<std::string, VP_KERNEL_BINARY_ENTRY> m_vpL0KernelBinaryList;
 
+    bool m_isRenderDisabled = false;
+
     MEDIA_CLASS_DEFINE_END(vp__VpPlatformInterface)
 };
 
